/*!
* Vuetify v3.1.3
* Forged by John Leider
* Released under the MIT License.
*/
!function(e,t){"object"==typeof exports&&"undefined"!=typeof module?t(exports,require("vue")):"function"==typeof define&&define.amd?define(["exports","vue"],t):t((e="undefined"!=typeof globalThis?globalThis:e||self).Vuetify={},e.Vue)}(this,(function(e,t){"use strict"
const l="undefined"!=typeof window,a=l&&"IntersectionObserver"in window,o=l&&("ontouchstart"in window||window.navigator.maxTouchPoints>0),n=l&&"undefined"!=typeof CSS&&CSS.supports("selector(:focus-visible)")
function r(e){const a=t.ref(),o=t.ref()
if(l){const l=new ResizeObserver((t=>{null==e||e(t,l),t.length&&(o.value=t[0].contentRect)}))
t.onBeforeUnmount((()=>{l.disconnect()})),t.watch(a,((e,t)=>{t&&(l.unobserve(t),o.value=void 0),e&&l.observe(e)}),{flush:"post"})}return{resizeRef:a,contentRect:t.readonly(o)}}function i(e,t,l){!function(e,t){if(t.has(e))throw new TypeError("Cannot initialize the same private elements twice on an object")}(e,t),t.set(e,l)}function s(e,t,l){return function(e,t,l){if(t.set)t.set.call(e,l)
else{if(!t.writable)throw new TypeError("attempted to set read only private field")
t.value=l}}(e,c(e,t,"set"),l),l}function u(e,t){return function(e,t){if(t.get)return t.get.call(e)
return t.value}(e,c(e,t,"get"))}function c(e,t,l){if(!t.has(e))throw new TypeError("attempted to "+l+" private field on non-instance")
return t.get(e)}function d(e,t,l){const a=t.length-1
if(a<0)return void 0===e?l:e
for(let o=0;o<a;o++){if(null==e)return l
e=e[t[o]]}return null==e||void 0===e[t[a]]?l:e[t[a]]}function v(e,t){if(e===t)return!0
if(e instanceof Date&&t instanceof Date&&e.getTime()!==t.getTime())return!1
if(e!==Object(e)||t!==Object(t))return!1
const l=Object.keys(e)
return l.length===Object.keys(t).length&&l.every((l=>v(e[l],t[l])))}function p(e,t,l){return null!=e&&t&&"string"==typeof t?void 0!==e[t]?e[t]:d(e,(t=(t=t.replace(/\[(\w+)\]/g,".$1")).replace(/^\./,"")).split("."),l):l}function f(e,t,l){if(null==t)return void 0===e?l:e
if(e!==Object(e)){if("function"!=typeof t)return l
const a=t(e,l)
return void 0===a?l:a}if("string"==typeof t)return p(e,t,l)
if(Array.isArray(t))return d(e,t,l)
if("function"!=typeof t)return l
const a=t(e,l)
return void 0===a?l:a}function m(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0
return Array.from({length:e},((e,l)=>t+l))}function g(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"px"
return null==e||""===e?void 0:isNaN(+e)?String(e):isFinite(+e)?`${Number(e)}${t}`:void 0}function h(e){return null!==e&&"object"==typeof e&&!Array.isArray(e)}const y=Object.freeze({enter:13,tab:9,delete:46,esc:27,space:32,up:38,down:40,left:37,right:39,end:35,home:36,del:46,backspace:8,insert:45,pageup:33,pagedown:34,shift:16}),b=Object.freeze({enter:"Enter",tab:"Tab",delete:"Delete",esc:"Escape",space:"Space",up:"ArrowUp",down:"ArrowDown",left:"ArrowLeft",right:"ArrowRight",end:"End",home:"Home",del:"Delete",backspace:"Backspace",insert:"Insert",pageup:"PageUp",pagedown:"PageDown",shift:"Shift"})
function V(e){return Object.keys(e)}function S(e,t){const l=Object.create(null),a=Object.create(null)
for(const o in e)t.some((e=>e instanceof RegExp?e.test(o):e===o))?l[o]=e[o]:a[o]=e[o]
return[l,a]}function w(e,t){const l={...e}
return t.forEach((e=>delete l[e])),l}function k(e){return S(e,["class","style","id",/^data-/])}function x(e){return null==e?[]:Array.isArray(e)?e:[e]}function C(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,l=arguments.length>2&&void 0!==arguments[2]?arguments[2]:1
return Math.max(t,Math.min(l,e))}function N(e,t){let l=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"0"
return e+l.repeat(Math.max(0,t-e.length))}function _(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:1e3
if(e<t)return`${e} B`
const l=1024===t?["Ki","Mi","Gi"]:["k","M","G"]
let a=-1
for(;Math.abs(e)>=t&&a<l.length-1;)e/=t,++a
return`${e.toFixed(1)} ${l[a]}B`}function I(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},l=arguments.length>2?arguments[2]:void 0
const a={}
for(const t in e)a[t]=e[t]
for(const o in t){const n=e[o],r=t[o]
h(n)&&h(r)?a[o]=I(n,r,l):Array.isArray(n)&&Array.isArray(r)&&l?a[o]=l(n,r):a[o]=r}return a}function B(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:""
if(B.cache.has(e))return B.cache.get(e)
const t=e.replace(/[^a-z]/gi,"-").replace(/\B([A-Z])/g,"-$1").toLowerCase()
return B.cache.set(e,t),t}function $(e,t){if(!t||"object"!=typeof t)return[]
if(Array.isArray(t))return t.map((t=>$(e,t))).flat(1)
if(Array.isArray(t.children))return t.children.map((t=>$(e,t))).flat(1)
if(t.component){if(Object.getOwnPropertySymbols(t.component.provides).includes(e))return[t.component]
if(t.component.subTree)return $(e,t.component.subTree).flat(1)}return[]}B.cache=new Map
var A=new WeakMap,E=new WeakMap
class R{constructor(e){i(this,A,{writable:!0,value:[]}),i(this,E,{writable:!0,value:0}),this.size=e}push(e){u(this,A)[u(this,E)]=e,s(this,E,(u(this,E)+1)%this.size)}values(){return u(this,A).slice(u(this,E)).concat(u(this,A).slice(0,u(this,E)))}}function T(e){const l=t.reactive({}),a=t.computed(e)
return t.watchEffect((()=>{for(const e in a.value)l[e]=a.value[e]}),{flush:"sync"}),t.toRefs(l)}function L(e,t){return e.includes(t)}const P=/^on[^a-z]/,O=e=>P.test(e),F=[Function,Array]
function M(e,l){return!!(e[l="on"+t.capitalize(l)]||e[`${l}Once`]||e[`${l}Capture`]||e[`${l}OnceCapture`]||e[`${l}CaptureOnce`])}function z(e){for(var t=arguments.length,l=new Array(t>1?t-1:0),a=1;a<t;a++)l[a-1]=arguments[a]
if(Array.isArray(e))for(const t of e)t(...l)
else"function"==typeof e&&e(...l)}const D=["top","bottom"],j=["start","end","left","right"]
function H(e,t){let[l,a]=e.split(" ")
return a||(a=L(D,l)?"start":L(j,l)?"top":"center"),{side:W(l,t),align:W(a,t)}}function W(e,t){return"start"===e?t?"right":"left":"end"===e?t?"left":"right":e}function U(e){return{side:{center:"center",top:"bottom",bottom:"top",left:"right",right:"left"}[e.side],align:e.align}}function Y(e){return{side:e.side,align:{center:"center",top:"bottom",bottom:"top",left:"right",right:"left"}[e.align]}}function X(e){return{side:e.align,align:e.side}}function G(e){return L(D,e.side)?"y":"x"}class q{constructor(e){let{x:t,y:l,width:a,height:o}=e
this.x=t,this.y=l,this.width=a,this.height=o}get top(){return this.y}get bottom(){return this.y+this.height}get left(){return this.x}get right(){return this.x+this.width}}function K(e,t){return{x:{before:Math.max(0,t.left-e.left),after:Math.max(0,e.right-t.right)},y:{before:Math.max(0,t.top-e.top),after:Math.max(0,e.bottom-t.bottom)}}}function Z(e){const t=e.getBoundingClientRect(),l=getComputedStyle(e),a=l.transform
if(a){let o,n,r,i,s
if(a.startsWith("matrix3d("))o=a.slice(9,-1).split(/, /),n=+o[0],r=+o[5],i=+o[12],s=+o[13]
else{if(!a.startsWith("matrix("))return new q(t)
o=a.slice(7,-1).split(/, /),n=+o[0],r=+o[3],i=+o[4],s=+o[5]}const u=l.transformOrigin,c=t.x-i-(1-n)*parseFloat(u),d=t.y-s-(1-r)*parseFloat(u.slice(u.indexOf(" ")+1)),v=n?t.width/n:e.offsetWidth+1,p=r?t.height/r:e.offsetHeight+1
return new q({x:c,y:d,width:v,height:p})}return new q(t)}function J(e,t,l){if(void 0===e.animate)return{finished:Promise.resolve()}
const a=e.animate(t,l)
return void 0===a.finished&&(a.finished=new Promise((e=>{a.onfinish=()=>{e(a)}}))),a}function Q(e,t,l){if(l&&(t={__isVue:!0,$parent:l,$options:t}),t){if(t.$_alreadyWarned=t.$_alreadyWarned||[],t.$_alreadyWarned.includes(e))return
t.$_alreadyWarned.push(e)}return`[Vuetify] ${e}`+(t?function(e){if(e.__isVue&&e.$parent){const t=[]
let l=0
for(;e;){if(t.length>0){const a=t[t.length-1]
if(a.constructor===e.constructor){l++,e=e.$parent
continue}l>0&&(t[t.length-1]=[a,l],l=0)}t.push(e),e=e.$parent}return"\n\nfound in\n\n"+t.map(((e,t)=>`${0===t?"---\x3e ":" ".repeat(5+2*t)}${Array.isArray(e)?`${ae(e[0])}... (${e[1]} recursive calls)`:ae(e)}`)).join("\n")}return`\n\n(found in ${ae(e)})`}(t):"")}function ee(e,t,l){const a=Q(e,t,l)
null!=a&&console.warn(a)}function te(e,t,l){const a=Q(e,t,l)
null!=a&&console.error(a)}const le=/(?:^|[-_])(\w)/g
function ae(e,t){if(e.$root===e)return"<Root>"
const l="function"==typeof e&&null!=e.cid?e.options:e.__isVue?e.$options||e.constructor.options:e||{}
let a=l.name||l._componentTag
const o=l.__file
if(!a&&o){const e=o.match(/([^/\\]+)\.vue$/)
a=null==e?void 0:e[1]}return(a?`<${n=a,n.replace(le,(e=>e.toUpperCase())).replace(/[-_]/g,"")}>`:"<Anonymous>")+(o&&!1!==t?` at ${o}`:"")
var n}const oe=[[3.2406,-1.5372,-.4986],[-.9689,1.8758,.0415],[.0557,-.204,1.057]],ne=e=>e<=.0031308?12.92*e:1.055*e**(1/2.4)-.055,re=[[.4124,.3576,.1805],[.2126,.7152,.0722],[.0193,.1192,.9505]],ie=e=>e<=.04045?e/12.92:((e+.055)/1.055)**2.4
function se(e){const t=Array(3),l=ne,a=oe
for(let o=0;o<3;++o)t[o]=Math.round(255*C(l(a[o][0]*e[0]+a[o][1]*e[1]+a[o][2]*e[2])))
return{r:t[0],g:t[1],b:t[2]}}function ue(e){let{r:t,g:l,b:a}=e
const o=[0,0,0],n=ie,r=re
t=n(t/255),l=n(l/255),a=n(a/255)
for(let e=0;e<3;++e)o[e]=r[e][0]*t+r[e][1]*l+r[e][2]*a
return o}const ce=.20689655172413793,de=e=>e>ce**3?Math.cbrt(e):e/(3*ce**2)+4/29,ve=e=>e>ce?e**3:3*ce**2*(e-4/29)
function pe(e){const t=de,l=t(e[1])
return[116*l-16,500*(t(e[0]/.95047)-l),200*(l-t(e[2]/1.08883))]}function fe(e){const t=ve,l=(e[0]+16)/116
return[.95047*t(l+e[1]/500),t(l),1.08883*t(l-e[2]/200)]}function me(e){return!!e&&/^(#|var\(--|(rgb|hsl)a?\()/.test(e)}function ge(e){if("number"==typeof e)return(isNaN(e)||e<0||e>16777215)&&ee(`'${e}' is not a valid hex color`),{r:(16711680&e)>>16,g:(65280&e)>>8,b:255&e}
if("string"==typeof e){let t=e.startsWith("#")?e.slice(1):e;[3,4].includes(t.length)?t=t.split("").map((e=>e+e)).join(""):[6,8].includes(t.length)||ee(`'${e}' is not a valid hex(a) color`)
const l=parseInt(t,16)
return(isNaN(l)||l<0||l>4294967295)&&ee(`'${e}' is not a valid hex(a) color`),xe(t)}throw new TypeError(`Colors can only be numbers or strings, recieved ${null==e?e:e.constructor.name} instead`)}function he(e){const{h:t,s:l,v:a,a:o}=e,n=e=>{const o=(e+t/60)%6
return a-a*l*Math.max(Math.min(o,4-o,1),0)},r=[n(5),n(3),n(1)].map((e=>Math.round(255*e)))
return{r:r[0],g:r[1],b:r[2],a:o}}function ye(e){if(!e)return{h:0,s:1,v:1,a:1}
const t=e.r/255,l=e.g/255,a=e.b/255,o=Math.max(t,l,a),n=Math.min(t,l,a)
let r=0
o!==n&&(o===t?r=60*(0+(l-a)/(o-n)):o===l?r=60*(2+(a-t)/(o-n)):o===a&&(r=60*(4+(t-l)/(o-n)))),r<0&&(r+=360)
const i=[r,0===o?0:(o-n)/o,o]
return{h:i[0],s:i[1],v:i[2],a:e.a}}function be(e){const{h:t,s:l,v:a,a:o}=e,n=a-a*l/2
return{h:t,s:1===n||0===n?0:(a-n)/Math.min(n,1-n),l:n,a:o}}function Ve(e){const{h:t,s:l,l:a,a:o}=e,n=a+l*Math.min(a,1-a)
return{h:t,s:0===n?0:2-2*a/n,v:n,a:o}}function Se(e){return function(e){let{r:t,g:l,b:a,a:o}=e
return void 0===o?`rgb(${t}, ${l}, ${a})`:`rgba(${t}, ${l}, ${a}, ${o})`}(he(e))}function we(e){const t=Math.round(e).toString(16)
return("00".substr(0,2-t.length)+t).toUpperCase()}function ke(e){let{r:t,g:l,b:a,a:o}=e
return`#${[we(t),we(l),we(a),void 0!==o?we(Math.round(255*o)):"FF"].join("")}`}function xe(e){let[t,l,a,o]=function(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:1
const l=[]
let a=0
for(;a<e.length;)l.push(e.substr(a,t)),a+=t
return l}(e,2).map((e=>parseInt(e,16)))
return o=void 0===o?o:Math.round(o/255*100)/100,{r:t,g:l,b:a,a:o}}function Ce(e){return ye(xe(e))}function Ne(e){return ke(he(e))}function _e(e,t){const l=pe(ue(e))
return l[0]=l[0]+10*t,se(fe(l))}function Ie(e,t){const l=pe(ue(e))
return l[0]=l[0]-10*t,se(fe(l))}function Be(e){return ue(ge(e))[1]}function $e(e,t){const l=Be(e),a=Be(t)
return(Math.max(l,a)+.05)/(Math.min(l,a)+.05)}function Ae(e,l){const a=t.getCurrentInstance()
if(!a)throw new Error(`[Vuetify] ${e} ${l||"must be called from inside a setup function"}`)
return a}function Ee(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"composables"
const t=Ae(e).type
return B((null==t?void 0:t.aliasName)||(null==t?void 0:t.name))}let Re=0,Te=new WeakMap
function Le(){const e=Ae("getUid")
if(Te.has(e))return Te.get(e)
{const t=Re++
return Te.set(e,t),t}}Le.reset=()=>{Re=0,Te=new WeakMap}
const Pe=Symbol.for("vuetify:defaults")
function Oe(e){return t.ref(e)}function Fe(){const e=t.inject(Pe)
if(!e)throw new Error("[Vuetify] Could not find defaults instance")
return e}function Me(e,l){const a=Fe(),o=t.ref(e),n=t.computed((()=>{const e=t.unref(null==l?void 0:l.scoped),n=t.unref(null==l?void 0:l.reset),r=t.unref(null==l?void 0:l.root)
let i=I(o.value,{prev:a.value})
if(e)return i
if(n||r){const e=Number(n||1/0)
for(let t=0;t<=e&&i.prev;t++)i=i.prev
return i}return I(i.prev,i)}))
return t.provide(Pe,n),n}function ze(e,l){let a
function o(){a=t.effectScope(),a.run((()=>l.length?l((()=>{var e
null==(e=a)||e.stop(),o()})):l()))}t.watch(e,(e=>{if(e&&!a)o()
else if(!e){var t
null==(t=a)||t.stop(),a=void 0}}),{immediate:!0}),t.onScopeDispose((()=>{var e
null==(e=a)||e.stop()}))}function De(e,t){return l=>Object.keys(e).reduce(((a,o)=>{const n="object"==typeof e[o]&&null!=e[o]&&!Array.isArray(e[o])?e[o]:{type:e[o]}
return a[o]=l&&o in l?{...n,default:l[o]}:n,t&&!a[o].source&&(a[o].source=t),a}),{})}const je=function(e){return e._setup=e._setup??e.setup,e.name?(e._setup&&(e.props=e.props??{},e.props=De(e.props,B(e.name))(),e.props._as=String,e.setup=function(l,a){const o=Fe()
if(!o.value)return e._setup(l,a)
const n=t.getCurrentInstance(),r=t.computed((()=>o.value[l._as??e.name])),i=new Proxy(l,{get(e,t){var l,a
return function(e,t){var l,a
return void 0!==(null==(l=e.props)?void 0:l[t])||void 0!==(null==(a=e.props)?void 0:a[B(t)])}(n.vnode,t)?Reflect.get(e,t):(null==(l=r.value)?void 0:l[t])??(null==(a=o.value.global)?void 0:a[t])??e[t]}}),s=t.shallowRef()
t.watchEffect((()=>{if(r.value){const e=Object.entries(r.value).filter((e=>{let[t]=e
return t.startsWith(t[0].toUpperCase())}))
e.length&&(s.value=Object.fromEntries(e))}}))
const u=e._setup(i,a)
return ze(s,(()=>{var e
Me(I((null==(e=function(e){const{provides:t}=Ae("injectSelf")
if(t&&e in t)return t[e]}(Pe))?void 0:e.value)??{},s.value))})),u}),e):(ee("The component is missing an explicit name, unable to generate default prop value"),e)}
function He(){let e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0]
return l=>(e?je:t.defineComponent)(l)}function We(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"div",a=arguments.length>2?arguments[2]:void 0
return je({name:a??t.capitalize(t.camelize(e.replace(/__/g,"-"))),props:{tag:{type:String,default:l}},setup(l,a){let{slots:o}=a
return()=>{var a
return t.h(l.tag,{class:e},null==(a=o.default)?void 0:a.call(o))}}})}function Ue(e){if("function"!=typeof e.getRootNode){for(;e.parentNode;)e=e.parentNode
return e!==document?null:document}const t=e.getRootNode()
return t!==document&&t.getRootNode({composed:!0})!==document?null:t}const Ye="cubic-bezier(0.4, 0, 0.2, 1)"
function Xe(e){for(;e;){if(qe(e))return e
e=e.parentElement}return document.scrollingElement}function Ge(e,t){const l=[]
if(t&&e&&!t.contains(e))return l
for(;e&&(qe(e)&&l.push(e),e!==t);)e=e.parentElement
return l}function qe(e){if(!e||e.nodeType!==Node.ELEMENT_NODE)return!1
const t=window.getComputedStyle(e)
return"scroll"===t.overflowY||"auto"===t.overflowY&&e.scrollHeight>e.clientHeight}function Ke(e){Ae("useRender").render=e}const Ze=Symbol.for("vuetify:layout"),Je=Symbol.for("vuetify:layout-item"),Qe=De({overlaps:{type:Array,default:()=>[]},fullHeight:Boolean},"layout"),et=De({name:{type:String},order:{type:[Number,String],default:0},absolute:Boolean},"layout-item")
function tt(){const e=t.inject(Ze)
if(!e)throw new Error("[Vuetify] Could not find injected layout")
return{getLayoutItem:e.getLayoutItem,mainRect:e.mainRect,mainStyles:e.mainStyles}}function lt(e){const l=t.inject(Ze)
if(!l)throw new Error("[Vuetify] Could not find injected layout")
const a=e.id??`layout-item-${Le()}`,o=Ae("useLayoutItem")
t.provide(Je,{id:a})
const n=t.ref(!1)
t.onDeactivated((()=>n.value=!0)),t.onActivated((()=>n.value=!1))
const{layoutItemStyles:r,layoutItemScrimStyles:i}=l.register(o,{...e,active:t.computed((()=>!n.value&&e.active.value)),id:a})
return t.onBeforeUnmount((()=>l.unregister(a))),{layoutItemStyles:r,layoutRect:l.layoutRect,layoutItemScrimStyles:i}}function at(e){const l=t.inject(Ze,null),a=t.computed((()=>l?l.rootZIndex.value-100:1e3)),o=t.ref([]),n=t.reactive(new Map),i=t.reactive(new Map),s=t.reactive(new Map),u=t.reactive(new Map),c=t.reactive(new Map),{resizeRef:d,contentRect:v}=r(),p=t.computed((()=>{const t=new Map,l=e.overlaps??[]
for(const e of l.filter((e=>e.includes(":")))){const[l,a]=e.split(":")
if(!o.value.includes(l)||!o.value.includes(a))continue
const r=n.get(l),s=n.get(a),u=i.get(l),c=i.get(a)
r&&s&&u&&c&&(t.set(a,{position:r.value,amount:parseInt(u.value,10)}),t.set(l,{position:s.value,amount:-parseInt(c.value,10)}))}return t})),f=t.computed((()=>{const e=[...new Set([...s.values()].map((e=>e.value)))].sort(((e,t)=>e-t)),t=[]
for(const l of e){const e=o.value.filter((e=>{var t
return(null==(t=s.get(e))?void 0:t.value)===l}))
t.push(...e)}return((e,t,l,a)=>{let o={top:0,left:0,right:0,bottom:0}
const n=[{id:"",layer:{...o}}]
for(const r of e){const e=t.get(r),i=l.get(r),s=a.get(r)
if(!e||!i||!s)continue
const u={...o,[e.value]:parseInt(o[e.value],10)+(s.value?parseInt(i.value,10):0)}
n.push({id:r,layer:u}),o=u}return n})(t,n,i,u)})),m=t.computed((()=>!Array.from(c.values()).some((e=>e.value)))),h=t.computed((()=>f.value[f.value.length-1].layer)),y=t.computed((()=>({"--v-layout-left":g(h.value.left),"--v-layout-right":g(h.value.right),"--v-layout-top":g(h.value.top),"--v-layout-bottom":g(h.value.bottom),...m.value?void 0:{transition:"none"}}))),b=t.computed((()=>f.value.slice(1).map(((e,t)=>{let{id:l}=e
const{layer:a}=f.value[t],o=i.get(l),r=n.get(l)
return{id:l,...a,size:Number(o.value),position:r.value}})))),V=e=>b.value.find((t=>t.id===e)),S=Ae("createLayout"),w=t.ref(!1)
t.onMounted((()=>{w.value=!0})),t.provide(Ze,{register:(e,l)=>{let{id:r,order:d,position:v,layoutSize:g,elementSize:h,active:y,disableTransitions:V,absolute:k}=l
s.set(r,d),n.set(r,v),i.set(r,g),u.set(r,y),V&&c.set(r,V)
const x=$(Je,null==S?void 0:S.vnode).indexOf(e)
x>-1?o.value.splice(x,0,r):o.value.push(r)
const C=t.computed((()=>b.value.findIndex((e=>e.id===r)))),N=t.computed((()=>a.value+2*f.value.length-2*C.value))
return{layoutItemStyles:t.computed((()=>{const e="left"===v.value||"right"===v.value,t="right"===v.value,l="bottom"===v.value,o={[v.value]:0,zIndex:N.value,transform:`translate${e?"X":"Y"}(${(y.value?0:-110)*(t||l?-1:1)}%)`,position:k.value||1e3!==a.value?"absolute":"fixed",...m.value?void 0:{transition:"none"}}
if(!w.value)return o
const n=b.value[C.value]
if(!n)throw new Error(`[Vuetify] Could not find layout item "${r}"`)
const i=p.value.get(r)
return i&&(n[i.position]+=i.amount),{...o,height:e?`calc(100% - ${n.top}px - ${n.bottom}px)`:h.value?`${h.value}px`:void 0,left:t?void 0:`${n.left}px`,right:t?`${n.right}px`:void 0,top:"bottom"!==v.value?`${n.top}px`:void 0,bottom:"top"!==v.value?`${n.bottom}px`:void 0,width:e?h.value?`${h.value}px`:void 0:`calc(100% - ${n.left}px - ${n.right}px)`}})),layoutItemScrimStyles:t.computed((()=>({zIndex:N.value-1}))),zIndex:N}},unregister:e=>{s.delete(e),n.delete(e),i.delete(e),u.delete(e),c.delete(e),o.value=o.value.filter((t=>t!==e))},mainRect:h,mainStyles:y,getLayoutItem:V,items:b,layoutRect:v,rootZIndex:a})
return{layoutClasses:t.computed((()=>["v-layout",{"v-layout--full-height":e.fullHeight}])),layoutStyles:t.computed((()=>({zIndex:a.value,position:l?"relative":void 0,overflow:l?"hidden":void 0}))),getLayoutItem:V,items:b,layoutRect:v,layoutRef:d}}const ot=2.4,nt=.2126729,rt=.7151522,it=.072175,st=.03,ut=12.82051282051282,ct=.06
function dt(e,t){const l=(e.r/255)**ot,a=(e.g/255)**ot,o=(e.b/255)**ot,n=(t.r/255)**ot,r=(t.g/255)**ot,i=(t.b/255)**ot
let s,u=l*nt+a*rt+o*it,c=n*nt+r*rt+i*it
if(u<=st&&(u+=(st-u)**1.45),c<=st&&(c+=(st-c)**1.45),Math.abs(c-u)<5e-4)return 0
if(c>u){const e=1.25*(c**.55-u**.58)
s=e<.001?0:e<.078?e-e*ut*ct:e-ct}else{const e=1.25*(c**.62-u**.57)
s=e>-.001?0:e>-.078?e-e*ut*ct:e+ct}return 100*s}const vt=Symbol.for("vuetify:theme"),pt=De({theme:String},"theme"),ft={defaultTheme:"light",variations:{colors:[],lighten:0,darken:0},themes:{light:{dark:!1,colors:{background:"#FFFFFF",surface:"#FFFFFF","surface-variant":"#424242","on-surface-variant":"#EEEEEE",primary:"#6200EE","primary-darken-1":"#3700B3",secondary:"#03DAC6","secondary-darken-1":"#018786",error:"#B00020",info:"#2196F3",success:"#4CAF50",warning:"#FB8C00"},variables:{"border-color":"#000000","border-opacity":.12,"high-emphasis-opacity":.87,"medium-emphasis-opacity":.6,"disabled-opacity":.38,"idle-opacity":.04,"hover-opacity":.04,"focus-opacity":.12,"selected-opacity":.08,"activated-opacity":.12,"pressed-opacity":.12,"dragged-opacity":.08,"theme-kbd":"#212529","theme-on-kbd":"#FFFFFF","theme-code":"#F5F5F5","theme-on-code":"#000000"}},dark:{dark:!0,colors:{background:"#121212",surface:"#212121","surface-variant":"#BDBDBD","on-surface-variant":"#424242",primary:"#BB86FC","primary-darken-1":"#3700B3",secondary:"#03DAC5","secondary-darken-1":"#03DAC5",error:"#CF6679",info:"#2196F3",success:"#4CAF50",warning:"#FB8C00"},variables:{"border-color":"#FFFFFF","border-opacity":.12,"high-emphasis-opacity":.87,"medium-emphasis-opacity":.6,"disabled-opacity":.38,"idle-opacity":.1,"hover-opacity":.04,"focus-opacity":.12,"selected-opacity":.08,"activated-opacity":.12,"pressed-opacity":.16,"dragged-opacity":.08,"theme-kbd":"#212529","theme-on-kbd":"#FFFFFF","theme-code":"#343434","theme-on-code":"#CCCCCC"}}}}
function mt(e){const a=t.reactive(function(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:ft
if(!e)return{...ft,isDisabled:!0}
const t={}
for(const[o,n]of Object.entries(e.themes??{})){var l,a
const e=n.dark||"dark"===o?null==(l=ft.themes)?void 0:l.dark:null==(a=ft.themes)?void 0:a.light
t[o]=I(e,n)}return I(ft,{...e,themes:t})}(e)),o=t.ref(a.defaultTheme),n=t.ref(a.themes),r=t.computed((()=>{const e={}
for(const[t,l]of Object.entries(n.value)){const o=e[t]={...l,colors:{...l.colors}}
if(a.variations)for(const e of a.variations.colors){const t=o.colors[e]
if(t)for(const l of["lighten","darken"]){const n="lighten"===l?_e:Ie
for(const r of m(a.variations[l],1))o.colors[`${e}-${l}-${r}`]=ke(n(ge(t),r))}}for(const e of Object.keys(o.colors)){if(/^on-[a-z]/.test(e)||o.colors[`on-${e}`])continue
const t=`on-${e}`,l=ge(o.colors[e]),a=Math.abs(dt(ge(0),l)),n=Math.abs(dt(ge(16777215),l))
o.colors[t]=n>Math.min(a,50)?"#fff":"#000"}}return e})),i=t.computed((()=>r.value[o.value])),s=t.computed((()=>{const e=[]
i.value.dark&&yt(e,":root",["color-scheme: dark"])
for(const[t,l]of Object.entries(r.value)){const{variables:a,dark:o}=l
yt(e,`.v-theme--${t}`,["color-scheme: "+(o?"dark":"normal"),...bt(l),...Object.keys(a).map((e=>{const t=a[e],l="string"==typeof t&&t.startsWith("#")?ge(t):void 0
return`--v-${e}: ${(l?`${l.r}, ${l.g}, ${l.b}`:void 0)??t}`}))])}const t=[],l=[],a=new Set(Object.values(r.value).flatMap((e=>Object.keys(e.colors))))
for(const e of a)/^on-[a-z]/.test(e)?yt(l,`.${e}`,[`color: rgb(var(--v-theme-${e})) !important`]):(yt(t,`.bg-${e}`,[`--v-theme-overlay-multiplier: var(--v-theme-${e}-overlay-multiplier)`,`background: rgb(var(--v-theme-${e})) !important`,`color: rgb(var(--v-theme-on-${e})) !important`]),yt(l,`.text-${e}`,[`color: rgb(var(--v-theme-${e})) !important`]),yt(l,`.border-${e}`,[`--v-border-color: var(--v-theme-${e})`]))
return e.push(...t,...l),e.map(((e,t)=>0===t?e:`    ${e}`)).join("")}))
const u=t.computed((()=>a.isDisabled?void 0:`v-theme--${o.value}`))
return{install:function(e){const o=e._context.provides.usehead
if(o)o.addHeadObjs(t.computed((()=>{const e={children:s.value,type:"text/css",id:"vuetify-theme-stylesheet"}
return a.cspNonce&&(e.nonce=a.cspNonce),{style:[e]}}))),l&&t.watchEffect((()=>o.updateDOM()))
else{let e=l?document.getElementById("vuetify-theme-stylesheet"):null
function o(){if(!a.isDisabled){if("undefined"!=typeof document&&!e){const t=document.createElement("style")
t.type="text/css",t.id="vuetify-theme-stylesheet",a.cspNonce&&t.setAttribute("nonce",a.cspNonce),e=t,document.head.appendChild(e)}e&&(e.innerHTML=s.value)}}t.watch(s,o,{immediate:!0})}},isDisabled:a.isDisabled,name:o,themes:n,current:i,computedThemes:r,themeClasses:u,styles:s,global:{name:o,current:i}}}function gt(e){Ae("provideTheme")
const l=t.inject(vt,null)
if(!l)throw new Error("Could not find Vuetify theme injection")
const a=t.computed((()=>e.theme??(null==l?void 0:l.name.value))),o=t.computed((()=>l.isDisabled?void 0:`v-theme--${a.value}`)),n={...l,name:a,themeClasses:o}
return t.provide(vt,n),n}function ht(){Ae("useTheme")
const e=t.inject(vt,null)
if(!e)throw new Error("Could not find Vuetify theme injection")
return e}function yt(e,t,l){e.push(`${t} {\n`,...l.map((e=>`  ${e};\n`)),"}\n")}function bt(e){const t=e.dark?2:1,l=e.dark?1:2,a=[]
for(const[o,n]of Object.entries(e.colors)){const e=ge(n)
a.push(`--v-theme-${o}: ${e.r},${e.g},${e.b}`),o.startsWith("on-")||a.push(`--v-theme-${o}-overlay-multiplier: ${Be(n)>.18?t:l}`)}return a}function Vt(e,l,a){let o=arguments.length>3&&void 0!==arguments[3]?arguments[3]:e=>e,n=arguments.length>4&&void 0!==arguments[4]?arguments[4]:e=>e
const r=Ae("useProxiedModel"),i=t.ref(void 0!==e[l]?e[l]:a),s=B(l),u=s!==l,c=u?t.computed((()=>{var t,a,o,n
return e[l],!(!(null!=(t=r.vnode.props)&&t.hasOwnProperty(l)||null!=(a=r.vnode.props)&&a.hasOwnProperty(s))||!(null!=(o=r.vnode.props)&&o.hasOwnProperty(`onUpdate:${l}`)||null!=(n=r.vnode.props)&&n.hasOwnProperty(`onUpdate:${s}`)))})):t.computed((()=>{var t,a
return e[l],!(null==(t=r.vnode.props)||!t.hasOwnProperty(l)||null==(a=r.vnode.props)||!a.hasOwnProperty(`onUpdate:${l}`))}))
ze((()=>!c.value),(()=>{t.watch((()=>e[l]),(e=>{i.value=e}))}))
const d=t.computed({get:()=>o(c.value?e[l]:i.value),set(t){const a=n(t);(c.value?e[l]:i.value)!==a&&o(c.value?e[l]:i.value)!==t&&(i.value=a,null==r||r.emit(`update:${l}`,a))}})
return Object.defineProperty(d,"externalValue",{get:()=>c.value?e[l]:i.value}),d}var St={badge:"Badge",close:"Close",dataIterator:{noResultsText:"No matching records found",loadingText:"Loading items..."},dataTable:{itemsPerPageText:"Rows per page:",ariaLabel:{sortDescending:"Sorted descending.",sortAscending:"Sorted ascending.",sortNone:"Not sorted.",activateNone:"Activate to remove sorting.",activateDescending:"Activate to sort descending.",activateAscending:"Activate to sort ascending."},sortBy:"Sort by"},dataFooter:{itemsPerPageText:"Items per page:",itemsPerPageAll:"All",nextPage:"Next page",prevPage:"Previous page",firstPage:"First page",lastPage:"Last page",pageText:"{0}-{1} of {2}"},datePicker:{itemsSelected:"{0} selected",nextMonthAriaLabel:"Next month",nextYearAriaLabel:"Next year",prevMonthAriaLabel:"Previous month",prevYearAriaLabel:"Previous year"},noDataText:"No data available",carousel:{prev:"Previous visual",next:"Next visual",ariaLabel:{delimiter:"Carousel slide {0} of {1}"}},calendar:{moreEvents:"{0} more"},input:{clear:"Clear {0}",prependAction:"{0} prepended action",appendAction:"{0} appended action"},fileInput:{counter:"{0} files",counterSize:"{0} files ({1} in total)"},timePicker:{am:"AM",pm:"PM"},pagination:{ariaLabel:{root:"Pagination Navigation",next:"Next page",previous:"Previous page",page:"Go to page {0}",currentPage:"Page {0}, Current page",first:"First page",last:"Last page"}},rating:{ariaLabel:{item:"Rating {0} of {1}"}}}
const wt="$vuetify.",kt=(e,t)=>e.replace(/\{(\d+)\}/g,((e,l)=>String(t[+l]))),xt=(e,t,l)=>function(a){for(var o=arguments.length,n=new Array(o>1?o-1:0),r=1;r<o;r++)n[r-1]=arguments[r]
if(!a.startsWith(wt))return kt(a,n)
const i=a.replace(wt,""),s=e.value&&l.value[e.value],u=t.value&&l.value[t.value]
let c=p(s,i,null)
return c||(ee(`Translation key "${a}" not found in "${e.value}", trying fallback locale`),c=p(u,i,null)),c||(te(`Translation key "${a}" not found in fallback`),c=a),"string"!=typeof c&&(te(`Translation key "${a}" has a non-string value`),c=a),kt(c,n)}
function Ct(e,t){return(l,a)=>new Intl.NumberFormat([e.value,t.value],a).format(l)}function Nt(e,l,a){const o=Vt(e,l,e[l]??a.value)
return o.value=e[l]??a.value,t.watch(a,(t=>{null==e[l]&&(o.value=a.value)})),o}function _t(e){return t=>{const l=Nt(t,"locale",e.current),a=Nt(t,"fallback",e.fallback),o=Nt(t,"messages",e.messages)
return{name:"vuetify",current:l,fallback:a,messages:o,t:xt(l,a,o),n:Ct(l,a),provide:_t({current:l,fallback:a,messages:o})}}}const It={af:!1,ar:!0,bg:!1,ca:!1,ckb:!1,cs:!1,de:!1,el:!1,en:!1,es:!1,et:!1,fa:!1,fi:!1,fr:!1,hr:!1,hu:!1,he:!0,id:!1,it:!1,ja:!1,ko:!1,lv:!1,lt:!1,nl:!1,no:!1,pl:!1,pt:!1,ro:!1,ru:!1,sk:!1,sl:!1,srCyrl:!1,srLatn:!1,sv:!1,th:!1,tr:!1,az:!1,uk:!1,vi:!1,zhHans:!1,zhHant:!1},Bt=Symbol.for("vuetify:locale")
function $t(e){const l=null!=e&&e.adapter&&null!=(null==e?void 0:e.adapter).name?null==e?void 0:e.adapter:function(e){const l=t.ref((null==e?void 0:e.locale)??"en"),a=t.ref((null==e?void 0:e.fallback)??"en"),o=t.ref({en:St,...null==e?void 0:e.messages})
return{name:"vuetify",current:l,fallback:a,messages:o,t:xt(l,a,o),n:Ct(l,a),provide:_t({current:l,fallback:a,messages:o})}}(e)
const a=function(e,l){const a=t.ref((null==l?void 0:l.rtl)??It),o=t.computed((()=>a.value[e.current.value]??!1))
return{isRtl:o,rtl:a,rtlClasses:t.computed((()=>"v-locale--is-"+(o.value?"rtl":"ltr")))}}(l,e)
return{...l,...a}}function At(){const e=t.inject(Bt)
if(!e)throw new Error("[Vuetify] Could not find injected locale instance")
return e}function Et(e){const l=t.inject(Bt)
if(!l)throw new Error("[Vuetify] Could not find injected locale instance")
const a=l.provide(e),o=function(e,l,a){const o=t.computed((()=>a.rtl??l.value[e.current.value]??!1))
return{isRtl:o,rtl:l,rtlClasses:t.computed((()=>"v-locale--is-"+(o.value?"rtl":"ltr")))}}(a,l.rtl,e),n={...a,...o}
return t.provide(Bt,n),n}function Rt(){const e=t.inject(Bt)
if(!e)throw new Error("[Vuetify] Could not find injected rtl instance")
return{isRtl:e.isRtl,rtlClasses:e.rtlClasses}}const Tt=je({name:"VApp",props:{...Qe({fullHeight:!0}),...pt()},setup(e,l){let{slots:a}=l
const o=gt(e),{layoutClasses:n,layoutStyles:r,getLayoutItem:i,items:s,layoutRef:u}=at(e),{rtlClasses:c}=Rt()
return Ke((()=>{var e
return t.createVNode("div",{ref:u,class:["v-application",o.themeClasses.value,n.value,c.value],style:r.value},[t.createVNode("div",{class:"v-application__wrap"},[null==(e=a.default)?void 0:e.call(a)])])})),{getLayoutItem:i,items:s,theme:o}}}),Lt=t.defineComponent({name:"VDefaultsProvider",props:{defaults:Object,reset:[Number,String],root:Boolean,scoped:Boolean},setup(e,l){let{slots:a}=l
const{defaults:o,reset:n,root:r,scoped:i}=t.toRefs(e)
return Me(o,{reset:n,root:r,scoped:i}),()=>{var e
return null==(e=a.default)?void 0:e.call(a)}}})
function Pt(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"top center 0",a=arguments.length>2?arguments[2]:void 0
return je({name:e,props:{group:Boolean,hideOnLeave:Boolean,leaveAbsolute:Boolean,mode:{type:String,default:a},origin:{type:String,default:l}},setup(l,a){let{slots:o}=a
return()=>{const a=l.group?t.TransitionGroup:t.Transition
return t.h(a,{name:e,mode:l.mode,onBeforeEnter(e){e.style.transformOrigin=l.origin},onLeave(e){if(l.leaveAbsolute){const{offsetTop:t,offsetLeft:l,offsetWidth:a,offsetHeight:o}=e
e._transitionInitialStyles={position:e.style.position,top:e.style.top,left:e.style.left,width:e.style.width,height:e.style.height},e.style.position="absolute",e.style.top=`${t}px`,e.style.left=`${l}px`,e.style.width=`${a}px`,e.style.height=`${o}px`}l.hideOnLeave&&e.style.setProperty("display","none","important")},onAfterLeave(e){if(l.leaveAbsolute&&null!=e&&e._transitionInitialStyles){const{position:t,top:l,left:a,width:o,height:n}=e._transitionInitialStyles
delete e._transitionInitialStyles,e.style.position=t||"",e.style.top=l||"",e.style.left=a||"",e.style.width=o||"",e.style.height=n||""}}},o.default)}}})}function Ot(e,l){let a=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"in-out"
return je({name:e,props:{mode:{type:String,default:a}},setup(a,o){let{slots:n}=o
return()=>t.h(t.Transition,{name:e,...l},n.default)}})}function Ft(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"",l=arguments.length>1&&void 0!==arguments[1]&&arguments[1]
const a=l?"width":"height",o=t.camelize(`offset-${a}`)
return{onBeforeEnter(e){e._parent=e.parentNode,e._initialStyle={transition:e.style.transition,overflow:e.style.overflow,[a]:e.style[a]}},onEnter(t){const l=t._initialStyle
t.style.setProperty("transition","none","important"),t.style.overflow="hidden"
const n=`${t[o]}px`
t.style[a]="0",t.offsetHeight,t.style.transition=l.transition,e&&t._parent&&t._parent.classList.add(e),requestAnimationFrame((()=>{t.style[a]=n}))},onAfterEnter:r,onEnterCancelled:r,onLeave(e){e._initialStyle={transition:"",overflow:e.style.overflow,[a]:e.style[a]},e.style.overflow="hidden",e.style[a]=`${e[o]}px`,e.offsetHeight,requestAnimationFrame((()=>e.style[a]="0"))},onAfterLeave:n,onLeaveCancelled:n}
function n(t){e&&t._parent&&t._parent.classList.remove(e),r(t)}function r(e){const t=e._initialStyle[a]
e.style.overflow=e._initialStyle.overflow,null!=t&&(e.style[a]=t),delete e._initialStyle}}const Mt=je({name:"VDialogTransition",props:{target:Object},setup(e,l){let{slots:a}=l
const o={onBeforeEnter(e){e.style.pointerEvents="none",e.style.visibility="hidden"},async onEnter(t,l){var a
await new Promise((e=>requestAnimationFrame(e))),await new Promise((e=>requestAnimationFrame(e))),t.style.visibility=""
const{x:o,y:n,sx:r,sy:i,speed:s}=Dt(e.target,t),u=J(t,[{transform:`translate(${o}px, ${n}px) scale(${r}, ${i})`,opacity:0},{}],{duration:225*s,easing:"cubic-bezier(0.0, 0, 0.2, 1)"})
null==(a=zt(t))||a.forEach((e=>{J(e,[{opacity:0},{opacity:0,offset:.33},{}],{duration:450*s,easing:Ye})})),u.finished.then((()=>l()))},onAfterEnter(e){e.style.removeProperty("pointer-events")},onBeforeLeave(e){e.style.pointerEvents="none"},async onLeave(t,l){var a
await new Promise((e=>requestAnimationFrame(e)))
const{x:o,y:n,sx:r,sy:i,speed:s}=Dt(e.target,t)
J(t,[{},{transform:`translate(${o}px, ${n}px) scale(${r}, ${i})`,opacity:0}],{duration:125*s,easing:"cubic-bezier(0.4, 0, 1, 1)"}).finished.then((()=>l())),null==(a=zt(t))||a.forEach((e=>{J(e,[{},{opacity:0,offset:.2},{opacity:0}],{duration:250*s,easing:Ye})}))},onAfterLeave(e){e.style.removeProperty("pointer-events")}}
return()=>e.target?t.createVNode(t.Transition,t.mergeProps({name:"dialog-transition"},o,{css:!1}),a):t.createVNode(t.Transition,{name:"dialog-transition"},a)}})
function zt(e){var t
const l=null==(t=e.querySelector(":scope > .v-card, :scope > .v-sheet, :scope > .v-list"))?void 0:t.children
return l&&[...l]}function Dt(e,t){const l=e.getBoundingClientRect(),a=Z(t),[o,n]=getComputedStyle(t).transformOrigin.split(" ").map((e=>parseFloat(e))),[r,i]=getComputedStyle(t).getPropertyValue("--v-overlay-anchor-origin").split(" ")
let s=l.left+l.width/2
"left"===r||"left"===i?s-=l.width/2:"right"!==r&&"right"!==i||(s+=l.width/2)
let u=l.top+l.height/2
"top"===r||"top"===i?u-=l.height/2:"bottom"!==r&&"bottom"!==i||(u+=l.height/2)
const c=l.width/a.width,d=l.height/a.height,v=Math.max(1,c,d),p=c/v||0,f=d/v||0,m=a.width*a.height/(window.innerWidth*window.innerHeight),g=m>.12?Math.min(1.5,10*(m-.12)+1):1
return{x:s-(o+a.left),y:u-(n+a.top),sx:p,sy:f,speed:g}}const jt=Pt("fab-transition","center center","out-in"),Ht=Pt("dialog-bottom-transition"),Wt=Pt("dialog-top-transition"),Ut=Pt("fade-transition"),Yt=Pt("scale-transition"),Xt=Pt("scroll-x-transition"),Gt=Pt("scroll-x-reverse-transition"),qt=Pt("scroll-y-transition"),Kt=Pt("scroll-y-reverse-transition"),Zt=Pt("slide-x-transition"),Jt=Pt("slide-x-reverse-transition"),Qt=Pt("slide-y-transition"),el=Pt("slide-y-reverse-transition"),tl=Ot("expand-transition",Ft()),ll=Ot("expand-x-transition",Ft("",!0)),al=De({height:[Number,String],maxHeight:[Number,String],maxWidth:[Number,String],minHeight:[Number,String],minWidth:[Number,String],width:[Number,String]},"dimension")
function ol(e){return{dimensionStyles:t.computed((()=>({height:g(e.height),maxHeight:g(e.maxHeight),maxWidth:g(e.maxWidth),minHeight:g(e.minHeight),minWidth:g(e.minWidth),width:g(e.width)})))}}const nl=je({name:"VResponsive",props:{aspectRatio:[String,Number],contentClass:String,...al()},setup(e,l){let{slots:a}=l
const{aspectStyles:o}=function(e){return{aspectStyles:t.computed((()=>{const t=Number(e.aspectRatio)
return t?{paddingBottom:String(1/t*100)+"%"}:void 0}))}}(e),{dimensionStyles:n}=ol(e)
return Ke((()=>{var l
return t.createVNode("div",{class:"v-responsive",style:n.value},[t.createVNode("div",{class:"v-responsive__sizer",style:o.value},null),null==(l=a.additional)?void 0:l.call(a),a.default&&t.createVNode("div",{class:["v-responsive__content",e.contentClass]},[a.default()])])})),{}}})
function rl(e,t){var l
const a=null==(l=e._observe)?void 0:l[t.instance.$.uid]
a&&(a.observer.unobserve(e),delete e._observe[t.instance.$.uid])}const il={mounted:function(e,t){if(!a)return
const l=t.modifiers||{},o=t.value,{handler:n,options:r}="object"==typeof o?o:{handler:o,options:{}},i=new IntersectionObserver((function(){var a
let o=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],r=arguments.length>1?arguments[1]:void 0
const i=null==(a=e._observe)?void 0:a[t.instance.$.uid]
if(!i)return
const s=o.some((e=>e.isIntersecting))
!n||l.quiet&&!i.init||l.once&&!s&&!i.init||n(s,o,r),s&&l.once?rl(e,t):i.init=!0}),r)
e._observe=Object(e._observe),e._observe[t.instance.$.uid]={init:!1,observer:i},i.observe(e)},unmounted:rl},sl=De({transition:{type:[Boolean,String,Object],default:"fade-transition",validator:e=>!0!==e}},"transition"),ul=(e,l)=>{let{slots:a}=l
const{transition:o,...n}=e,{component:r=t.Transition,...i}="object"==typeof o?o:{}
return t.h(r,t.mergeProps("string"==typeof o?{name:o}:i,n),a)},cl=je({name:"VImg",directives:{intersect:il},props:{aspectRatio:[String,Number],alt:String,cover:Boolean,eager:Boolean,gradient:String,lazySrc:String,options:{type:Object,default:()=>({root:void 0,rootMargin:void 0,threshold:void 0})},sizes:String,src:{type:[String,Object],default:""},srcset:String,width:[String,Number],...sl()},emits:{loadstart:e=>!0,load:e=>!0,error:e=>!0},setup(e,l){let{emit:o,slots:n}=l
const r=t.ref(""),i=t.ref(),s=t.ref(e.eager?"loading":"idle"),u=t.ref(),c=t.ref(),d=t.computed((()=>e.src&&"object"==typeof e.src?{src:e.src.src,srcset:e.srcset||e.src.srcset,lazySrc:e.lazySrc||e.src.lazySrc,aspect:Number(e.aspectRatio||e.src.aspect||0)}:{src:e.src,srcset:e.srcset,lazySrc:e.lazySrc,aspect:Number(e.aspectRatio||0)})),v=t.computed((()=>d.value.aspect||u.value/c.value||0))
function p(l){if((!e.eager||!l)&&(!a||l||e.eager)){if(s.value="loading",d.value.lazySrc){const e=new Image
e.src=d.value.lazySrc,b(e,null)}d.value.src&&t.nextTick((()=>{var e,t
if(o("loadstart",(null==(e=i.value)?void 0:e.currentSrc)||d.value.src),null!=(t=i.value)&&t.complete){if(i.value.naturalWidth||m(),"error"===s.value)return
v.value||b(i.value,null),f()}else v.value||b(i.value),h()}))}}function f(){var e
h(),s.value="loaded",o("load",(null==(e=i.value)?void 0:e.currentSrc)||d.value.src)}function m(){var e
s.value="error",o("error",(null==(e=i.value)?void 0:e.currentSrc)||d.value.src)}function h(){const e=i.value
e&&(r.value=e.currentSrc||e.src)}t.watch((()=>e.src),(()=>{p("idle"!==s.value)})),t.watch(v,((e,t)=>{!e&&t&&i.value&&b(i.value)})),t.onBeforeMount((()=>p()))
let y=-1
function b(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:100
const l=()=>{clearTimeout(y)
const{naturalHeight:a,naturalWidth:o}=e
a||o?(u.value=o,c.value=a):e.complete||"loading"!==s.value||null==t?(e.currentSrc.endsWith(".svg")||e.currentSrc.startsWith("data:image/svg+xml"))&&(u.value=1,c.value=1):y=window.setTimeout(l,t)}
l()}const V=t.computed((()=>({"v-img__img--cover":e.cover,"v-img__img--contain":!e.cover}))),S=()=>{var l
if(!d.value.src||"idle"===s.value)return null
const a=t.createVNode("img",{class:["v-img__img",V.value],src:d.value.src,srcset:d.value.srcset,alt:"",sizes:e.sizes,ref:i,onLoad:f,onError:m},null),o=null==(l=n.sources)?void 0:l.call(n)
return t.createVNode(ul,{transition:e.transition,appear:!0},{default:()=>[t.withDirectives(o?t.createVNode("picture",{class:"v-img__picture"},[o,a]):a,[[t.vShow,"loaded"===s.value]])]})},w=()=>t.createVNode(ul,{transition:e.transition},{default:()=>[d.value.lazySrc&&"loaded"!==s.value&&t.createVNode("img",{class:["v-img__img","v-img__img--preload",V.value],src:d.value.lazySrc,alt:""},null)]}),k=()=>n.placeholder?t.createVNode(ul,{transition:e.transition,appear:!0},{default:()=>[("loading"===s.value||"error"===s.value&&!n.error)&&t.createVNode("div",{class:"v-img__placeholder"},[n.placeholder()])]}):null,x=()=>n.error?t.createVNode(ul,{transition:e.transition,appear:!0},{default:()=>["error"===s.value&&t.createVNode("div",{class:"v-img__error"},[n.error()])]}):null,C=()=>e.gradient?t.createVNode("div",{class:"v-img__gradient",style:{backgroundImage:`linear-gradient(${e.gradient})`}},null):null,N=t.ref(!1)
{const e=t.watch(v,(t=>{t&&(requestAnimationFrame((()=>{requestAnimationFrame((()=>{N.value=!0}))})),e())}))}return Ke((()=>t.withDirectives(t.createVNode(nl,{class:["v-img",{"v-img--booting":!N.value}],style:{width:g("auto"===e.width?u.value:e.width)},aspectRatio:v.value,"aria-label":e.alt,role:e.alt?"img":void 0},{additional:()=>t.createVNode(t.Fragment,null,[t.createVNode(S,null,null),t.createVNode(w,null,null),t.createVNode(C,null,null),t.createVNode(k,null,null),t.createVNode(x,null,null)]),default:n.default}),[[t.resolveDirective("intersect"),{handler:p,options:e.options},null,{once:!0}]]))),{currentSrc:r,image:i,state:s,naturalWidth:u,naturalHeight:c}}}),dl=De({tag:{type:String,default:"div"}},"tag"),vl=He()({name:"VToolbarTitle",props:{text:String,...dl()},setup(e,l){let{slots:a}=l
return Ke((()=>{var l
const o=!!(a.default||a.text||e.text)
return t.createVNode(e.tag,{class:"v-toolbar-title"},{default:()=>[o&&t.createVNode("div",{class:"v-toolbar-title__placeholder"},[a.text?a.text():e.text,null==(l=a.default)?void 0:l.call(a)])]})})),{}}}),pl=De({border:[Boolean,Number,String]},"border")
function fl(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=t.computed((()=>{const a=t.isRef(e)?e.value:e.border,o=[]
if(!0===a||""===a)o.push(`${l}--border`)
else if("string"==typeof a||0===a)for(const e of String(a).split(" "))o.push(`border-${e}`)
return o}))
return{borderClasses:a}}const ml=De({elevation:{type:[Number,String],validator(e){const t=parseInt(e)
return!isNaN(t)&&t>=0&&t<=24}}},"elevation")
function gl(e){return{elevationClasses:t.computed((()=>{const l=t.isRef(e)?e.value:e.elevation,a=[]
return null==l||a.push(`elevation-${l}`),a}))}}const hl=De({rounded:{type:[Boolean,Number,String],default:void 0}},"rounded")
function yl(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=t.computed((()=>{const a=t.isRef(e)?e.value:e.rounded,o=[]
if(!0===a||""===a)o.push(`${l}--rounded`)
else if("string"==typeof a||0===a)for(const e of String(a).split(" "))o.push(`rounded-${e}`)
return o}))
return{roundedClasses:a}}function bl(e){return T((()=>{const t=[],l={}
return e.value.background&&(me(e.value.background)?l.backgroundColor=e.value.background:t.push(`bg-${e.value.background}`)),e.value.text&&(me(e.value.text)?(l.color=e.value.text,l.caretColor=e.value.text):t.push(`text-${e.value.text}`)),{colorClasses:t,colorStyles:l}}))}function Vl(e,l){const a=t.computed((()=>({text:t.isRef(e)?e.value:l?e[l]:null}))),{colorClasses:o,colorStyles:n}=bl(a)
return{textColorClasses:o,textColorStyles:n}}function Sl(e,l){const a=t.computed((()=>({background:t.isRef(e)?e.value:l?e[l]:null}))),{colorClasses:o,colorStyles:n}=bl(a)
return{backgroundColorClasses:o,backgroundColorStyles:n}}const wl=[null,"prominent","default","comfortable","compact"],kl=De({absolute:Boolean,collapse:Boolean,color:String,density:{type:String,default:"default",validator:e=>wl.includes(e)},extended:Boolean,extensionHeight:{type:[Number,String],default:48},flat:Boolean,floating:Boolean,height:{type:[Number,String],default:64},image:String,title:String,...pl(),...ml(),...hl(),...dl({tag:"header"}),...pt()},"v-toolbar"),xl=He()({name:"VToolbar",props:kl(),setup(e,l){var a
let{slots:o}=l
const{backgroundColorClasses:n,backgroundColorStyles:r}=Sl(t.toRef(e,"color")),{borderClasses:i}=fl(e),{elevationClasses:s}=gl(e),{roundedClasses:u}=yl(e),{themeClasses:c}=gt(e),d=t.ref(!!(e.extended||null!=(a=o.extension)&&a.call(o))),v=t.computed((()=>parseInt(Number(e.height)+("prominent"===e.density?Number(e.height):0)-("comfortable"===e.density?8:0)-("compact"===e.density?16:0),10))),p=t.computed((()=>d.value?parseInt(Number(e.extensionHeight)+("prominent"===e.density?Number(e.extensionHeight):0)-("comfortable"===e.density?4:0)-("compact"===e.density?8:0),10):0))
return Me({VBtn:{variant:"text"}}),Ke((()=>{var l,a,f,m,h
const y=!(!e.title&&!o.title),b=!(!o.image&&!e.image),V=null==(l=o.extension)?void 0:l.call(o)
return d.value=!(!e.extended&&!V),t.createVNode(e.tag,{class:["v-toolbar",{"v-toolbar--absolute":e.absolute,"v-toolbar--collapse":e.collapse,"v-toolbar--flat":e.flat,"v-toolbar--floating":e.floating,[`v-toolbar--density-${e.density}`]:!0},n.value,i.value,s.value,u.value,c.value],style:[r.value]},{default:()=>[b&&t.createVNode("div",{key:"image",class:"v-toolbar__image"},[t.createVNode(Lt,{defaults:{VImg:{cover:!0,src:e.image}}},{default:()=>[o.image?null==(a=o.image)?void 0:a.call(o):t.createVNode(cl,null,null)]})]),t.createVNode(Lt,{defaults:{VTabs:{height:g(v.value)}}},{default:()=>[t.createVNode("div",{class:"v-toolbar__content",style:{height:g(v.value)}},[o.prepend&&t.createVNode("div",{class:"v-toolbar__prepend"},[null==(f=o.prepend)?void 0:f.call(o)]),y&&t.createVNode(vl,{key:"title",text:e.title},{text:o.title}),null==(m=o.default)?void 0:m.call(o),o.append&&t.createVNode("div",{class:"v-toolbar__append"},[null==(h=o.append)?void 0:h.call(o)])])]}),t.createVNode(Lt,{defaults:{VTabs:{height:g(p.value)}}},{default:()=>[t.createVNode(tl,null,{default:()=>[d.value&&t.createVNode("div",{class:"v-toolbar__extension",style:{height:g(p.value)}},[V])]})]})]})})),{contentHeight:v,extensionHeight:p}}})
const Cl=He()({name:"VAppBar",props:{modelValue:{type:Boolean,default:!0},location:{type:String,default:"top",validator:e=>["top","bottom"].includes(e)},...kl(),...et(),height:{type:[Number,String],default:64}},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=t.ref(),n=Vt(e,"modelValue"),r=t.computed((()=>{var e,t
return((null==(e=o.value)?void 0:e.contentHeight)??0)+((null==(t=o.value)?void 0:t.extensionHeight)??0)})),{layoutItemStyles:i}=lt({id:e.name,order:t.computed((()=>parseInt(e.order,10))),position:t.toRef(e,"location"),layoutSize:r,elementSize:r,active:n,absolute:t.toRef(e,"absolute")})
return Ke((()=>{const[l]=function(e){return S(e,Object.keys((null==xl?void 0:xl.props)??{}))}(e)
return t.createVNode(xl,t.mergeProps({ref:o,class:["v-app-bar",{"v-app-bar--bottom":"bottom"===e.location}],style:{...i.value,height:void 0}},l),a)})),{}}}),Nl=[null,"default","comfortable","compact"],_l=De({density:{type:String,default:"default",validator:e=>Nl.includes(e)}},"density")
function Il(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=t.computed((()=>`${l}--density-${e.density}`))
return{densityClasses:a}}const Bl=["elevated","flat","tonal","outlined","text","plain"]
function $l(e,l){return t.createVNode(t.Fragment,null,[e&&t.createVNode("span",{key:"overlay",class:`${l}__overlay`},null),t.createVNode("span",{key:"underlay",class:`${l}__underlay`},null)])}const Al=De({color:String,variant:{type:String,default:"elevated",validator:e=>Bl.includes(e)}},"variant")
function El(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=t.computed((()=>{const{variant:a}=t.unref(e)
return`${l}--variant-${a}`})),{colorClasses:o,colorStyles:n}=bl(t.computed((()=>{const{variant:l,color:a}=t.unref(e)
return{[["elevated","flat"].includes(l)?"background":"text"]:a}})))
return{colorClasses:o,colorStyles:n,variantClasses:a}}const Rl=je({name:"VBtnGroup",props:{divided:Boolean,...pl(),..._l(),...ml(),...hl(),...dl(),...pt(),...Al()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{densityClasses:n}=Il(e),{borderClasses:r}=fl(e),{elevationClasses:i}=gl(e),{roundedClasses:s}=yl(e)
Me({VBtn:{height:"auto",color:t.toRef(e,"color"),density:t.toRef(e,"density"),flat:!0,variant:t.toRef(e,"variant")}}),Ke((()=>t.createVNode(e.tag,{class:["v-btn-group",{"v-btn-group--divided":e.divided},o.value,r.value,n.value,i.value,s.value]},a)))}}),Tl=De({modelValue:{type:null,default:void 0},multiple:Boolean,mandatory:[Boolean,String],max:Number,selectedClass:String,disabled:Boolean},"group"),Ll=De({value:null,disabled:Boolean,selectedClass:String},"group-item")
function Pl(e,l){let a=!(arguments.length>2&&void 0!==arguments[2])||arguments[2]
const o=Ae("useGroupItem")
if(!o)throw new Error("[Vuetify] useGroupItem composable must be used inside a component setup function")
const n=Le()
t.provide(Symbol.for(`${l.description}:id`),n)
const r=t.inject(l,null)
if(!r){if(!a)return r
throw new Error(`[Vuetify] Could not find useGroup injection with symbol ${l.description}`)}const i=t.toRef(e,"value"),s=t.computed((()=>r.disabled.value||e.disabled))
r.register({id:n,value:i,disabled:s},o),t.onBeforeUnmount((()=>{r.unregister(n)}))
const u=t.computed((()=>r.isSelected(n))),c=t.computed((()=>u.value&&[r.selectedClass.value,e.selectedClass]))
return t.watch(u,(e=>{o.emit("group:selected",{value:e})})),{id:n,isSelected:u,toggle:()=>r.select(n,!u.value),select:e=>r.select(n,e),selectedClass:c,value:i,disabled:s,group:r}}function Ol(e,l){let a=!1
const o=t.reactive([]),n=Vt(e,"modelValue",[],(e=>null==e?[]:Fl(o,x(e))),(t=>{const l=function(e,t){const l=[]
for(let a=0;a<e.length;a++){const o=e[a]
t.includes(o.id)&&l.push(null!=o.value?o.value:a)}return l}(o,t)
return e.multiple?l:l[0]})),r=Ae("useGroup")
function i(){const t=o.find((e=>!e.disabled))
t&&"force"===e.mandatory&&!n.value.length&&(n.value=[t.id])}function s(t){if(e.multiple&&ee('This method is not supported when using "multiple" prop'),n.value.length){const e=n.value[0],l=o.findIndex((t=>t.id===e))
let a=(l+t)%o.length,r=o[a]
for(;r.disabled&&a!==l;)a=(a+t)%o.length,r=o[a]
if(r.disabled)return
n.value=[o[a].id]}else{const e=o.find((e=>!e.disabled))
e&&(n.value=[e.id])}}t.onMounted((()=>{i()})),t.onBeforeUnmount((()=>{a=!0}))
const u={register:function(e,t){const a=e,n=$(Symbol.for(`${l.description}:id`),null==r?void 0:r.vnode).indexOf(t)
n>-1?o.splice(n,0,a):o.push(a)},unregister:function(e){if(a)return
i()
const t=o.findIndex((t=>t.id===e))
o.splice(t,1)},selected:n,select:function(t,l){const a=o.find((e=>e.id===t))
if(!l||null==a||!a.disabled)if(e.multiple){const a=n.value.slice(),o=a.findIndex((e=>e===t)),r=~o
if(l=l??!r,r&&e.mandatory&&a.length<=1)return
if(!r&&null!=e.max&&a.length+1>e.max)return
o<0&&l?a.push(t):o>=0&&!l&&a.splice(o,1),n.value=a}else{const a=n.value.includes(t)
if(e.mandatory&&a)return
n.value=l??!a?[t]:[]}},disabled:t.toRef(e,"disabled"),prev:()=>s(o.length-1),next:()=>s(1),isSelected:e=>n.value.includes(e),selectedClass:t.computed((()=>e.selectedClass)),items:t.computed((()=>o)),getItemIndex:e=>function(e,t){const l=Fl(e,[t])
return l.length?e.findIndex((e=>e.id===l[0])):-1}(o,e)}
return t.provide(l,u),u}function Fl(e,t){const l=[]
for(let a=0;a<e.length;a++){const o=e[a]
null!=o.value?null!=t.find((e=>v(e,o.value)))&&l.push(o.id):t.includes(a)&&l.push(o.id)}return l}const Ml=Symbol.for("vuetify:v-btn-toggle"),zl=He()({name:"VBtnToggle",props:Tl(),emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{isSelected:o,next:n,prev:r,select:i,selected:s}=Ol(e,Ml)
return Ke((()=>{var e
return t.createVNode(Rl,{class:"v-btn-toggle"},{default:()=>[null==(e=a.default)?void 0:e.call(a,{isSelected:o,next:n,prev:r,select:i,selected:s})]})})),{next:n,prev:r,select:i}}}),Dl={collapse:"mdi-chevron-up",complete:"mdi-check",cancel:"mdi-close-circle",close:"mdi-close",delete:"mdi-close-circle",clear:"mdi-close-circle",success:"mdi-check-circle",info:"mdi-information",warning:"mdi-alert-circle",error:"mdi-close-circle",prev:"mdi-chevron-left",next:"mdi-chevron-right",checkboxOn:"mdi-checkbox-marked",checkboxOff:"mdi-checkbox-blank-outline",checkboxIndeterminate:"mdi-minus-box",delimiter:"mdi-circle",sortAsc:"mdi-arrow-up",sortDesc:"mdi-arrow-down",expand:"mdi-chevron-down",menu:"mdi-menu",subgroup:"mdi-menu-down",dropdown:"mdi-menu-down",radioOn:"mdi-radiobox-marked",radioOff:"mdi-radiobox-blank",edit:"mdi-pencil",ratingEmpty:"mdi-star-outline",ratingFull:"mdi-star",ratingHalf:"mdi-star-half-full",loading:"mdi-cached",first:"mdi-page-first",last:"mdi-page-last",unfold:"mdi-unfold-more-horizontal",file:"mdi-paperclip",plus:"mdi-plus",minus:"mdi-minus"},jl={component:e=>t.h(ql,{...e,class:"mdi"})},Hl=[String,Function,Object],Wl=Symbol.for("vuetify:icons"),Ul=De({icon:{type:Hl},tag:{type:String,required:!0}},"icon"),Yl=je({name:"VComponentIcon",props:Ul(),setup(e,l){let{slots:a}=l
return()=>{var l
return t.createVNode(e.tag,null,{default:()=>[e.icon?t.createVNode(e.icon,null,null):null==(l=a.default)?void 0:l.call(a)]})}}}),Xl=je({name:"VSvgIcon",inheritAttrs:!1,props:Ul(),setup(e,l){let{attrs:a}=l
return()=>t.createVNode(e.tag,t.mergeProps(a,{style:null}),{default:()=>[t.createVNode("svg",{class:"v-icon__svg",xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",role:"img","aria-hidden":"true"},[t.createVNode("path",{d:e.icon},null)])]})}}),Gl=je({name:"VLigatureIcon",props:Ul(),setup:e=>()=>t.createVNode(e.tag,null,{default:()=>[e.icon]})}),ql=je({name:"VClassIcon",props:Ul(),setup:e=>()=>t.createVNode(e.tag,{class:e.icon},null)}),Kl={svg:{component:Xl},class:{component:ql}}
function Zl(e){return I({defaultSet:"mdi",sets:{...Kl,mdi:jl},aliases:Dl},e)}const Jl=["x-small","small","default","large","x-large"],Ql=De({size:{type:[String,Number],default:"default"}},"size")
function ea(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
return T((()=>{let l,a
return L(Jl,e.size)?l=`${t}--size-${e.size}`:e.size&&(a={width:g(e.size),height:g(e.size)}),{sizeClasses:l,sizeStyles:a}}))}const ta=De({color:String,start:Boolean,end:Boolean,icon:Hl,...Ql(),...dl({tag:"i"}),...pt()},"v-icon"),la=je({name:"VIcon",props:ta(),setup(e,l){let a,{attrs:o,slots:n}=l
n.default&&(a=t.computed((()=>{var e,l
const a=null==(e=n.default)?void 0:e.call(n)
if(a)return null==(l=a.filter((e=>e.type===t.Text&&e.children&&"string"==typeof e.children))[0])?void 0:l.children})))
const{themeClasses:r}=gt(e),{iconData:i}=(e=>{const l=t.inject(Wl)
if(!l)throw new Error("Missing Vuetify Icons provide!")
return{iconData:t.computed((()=>{const a=t.isRef(e)?e.value:e.icon
if(!a)return{component:Yl}
let o=a
var n
if("string"==typeof o&&(o=o.trim(),o.startsWith("$")&&(o=null==(n=l.aliases)?void 0:n[o.slice(1)])),!o)throw new Error(`Could not find aliased icon "${a}"`)
if("string"!=typeof o)return{component:Yl,icon:o}
const r=Object.keys(l.sets).find((e=>"string"==typeof o&&o.startsWith(`${e}:`))),i=r?o.slice(r.length+1):o
return{component:l.sets[r??l.defaultSet].component,icon:i}}))}})(a||e),{sizeClasses:s}=ea(e),{textColorClasses:u,textColorStyles:c}=Vl(t.toRef(e,"color"))
return Ke((()=>{var l
return t.createVNode(i.value.component,{tag:e.tag,icon:i.value.icon,class:["v-icon","notranslate",r.value,s.value,u.value,{"v-icon--clickable":!!o.onClick,"v-icon--start":e.start,"v-icon--end":e.end}],style:[s.value?void 0:{fontSize:g(e.size),height:g(e.size),width:g(e.size)},c.value],role:o.onClick?"button":void 0,"aria-hidden":!o.onClick},{default:()=>[null==(l=n.default)?void 0:l.call(n)]})})),{}}})
function aa(e){const l=t.ref(),o=t.ref(!1)
if(a){const a=new IntersectionObserver((t=>{null==e||e(t,a),o.value=!!t.find((e=>e.isIntersecting))}))
t.onBeforeUnmount((()=>{a.disconnect()})),t.watch(l,((e,t)=>{t&&(a.unobserve(t),o.value=!1),e&&a.observe(e)}),{flush:"post"})}return{intersectionRef:l,isIntersecting:o}}const oa=je({name:"VProgressCircular",props:{bgColor:String,color:String,indeterminate:[Boolean,String],modelValue:{type:[Number,String],default:0},rotate:{type:[Number,String],default:0},width:{type:[Number,String],default:4},...Ql(),...dl({tag:"div"}),...pt()},setup(e,l){let{slots:a}=l
const o=2*Math.PI*20,n=t.ref(),{themeClasses:i}=gt(e),{sizeClasses:s,sizeStyles:u}=ea(e),{textColorClasses:c,textColorStyles:d}=Vl(t.toRef(e,"color")),{textColorClasses:v,textColorStyles:p}=Vl(t.toRef(e,"bgColor")),{intersectionRef:f,isIntersecting:m}=aa(),{resizeRef:h,contentRect:y}=r(),b=t.computed((()=>Math.max(0,Math.min(100,parseFloat(e.modelValue))))),V=t.computed((()=>Number(e.width))),S=t.computed((()=>u.value?Number(e.size):y.value?y.value.width:Math.max(V.value,32))),w=t.computed((()=>20/(1-V.value/S.value)*2)),k=t.computed((()=>V.value/S.value*w.value)),x=t.computed((()=>g((100-b.value)/100*o)))
return t.watchEffect((()=>{f.value=n.value,h.value=n.value})),Ke((()=>t.createVNode(e.tag,{ref:n,class:["v-progress-circular",{"v-progress-circular--indeterminate":!!e.indeterminate,"v-progress-circular--visible":m.value,"v-progress-circular--disable-shrink":"disable-shrink"===e.indeterminate},i.value,s.value,c.value],style:[u.value,d.value],role:"progressbar","aria-valuemin":"0","aria-valuemax":"100","aria-valuenow":e.indeterminate?void 0:b.value},{default:()=>[t.createVNode("svg",{style:{transform:`rotate(calc(-90deg + ${Number(e.rotate)}deg))`},xmlns:"http://www.w3.org/2000/svg",viewBox:`0 0 ${w.value} ${w.value}`},[t.createVNode("circle",{class:["v-progress-circular__underlay",v.value],style:p.value,fill:"transparent",cx:"50%",cy:"50%",r:20,"stroke-width":k.value,"stroke-dasharray":o,"stroke-dashoffset":0},null),t.createVNode("circle",{class:"v-progress-circular__overlay",fill:"transparent",cx:"50%",cy:"50%",r:20,"stroke-width":k.value,"stroke-dasharray":o,"stroke-dashoffset":x.value},null)]),a.default&&t.createVNode("div",{class:"v-progress-circular__content"},[a.default({value:b.value})])]}))),{}}}),na=Symbol("rippleStop")
function ra(e,t){e.style.transform=t,e.style.webkitTransform=t}function ia(e,t){e.style.opacity=`calc(${t} * var(--v-theme-overlay-multiplier))`}function sa(e){return"TouchEvent"===e.constructor.name}function ua(e){return"KeyboardEvent"===e.constructor.name}const ca={show(e,t){var l
let a=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{}
if(null==t||null==(l=t._ripple)||!l.enabled)return
const o=document.createElement("span"),n=document.createElement("span")
o.appendChild(n),o.className="v-ripple__container",a.class&&(o.className+=` ${a.class}`)
const{radius:r,scale:i,x:s,y:u,centerX:c,centerY:d}=function(e,t){var l
let a=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},o=0,n=0
if(!ua(e)){const l=t.getBoundingClientRect(),a=sa(e)?e.touches[e.touches.length-1]:e
o=a.clientX-l.left,n=a.clientY-l.top}let r=0,i=.3
null!=(l=t._ripple)&&l.circle?(i=.15,r=t.clientWidth/2,r=a.center?r:r+Math.sqrt((o-r)**2+(n-r)**2)/4):r=Math.sqrt(t.clientWidth**2+t.clientHeight**2)/2
const s=(t.clientWidth-2*r)/2+"px",u=(t.clientHeight-2*r)/2+"px",c=a.center?s:o-r+"px",d=a.center?u:n-r+"px"
return{radius:r,scale:i,x:c,y:d,centerX:s,centerY:u}}(e,t,a),v=2*r+"px"
n.className="v-ripple__animation",n.style.width=v,n.style.height=v,t.appendChild(o)
const p=window.getComputedStyle(t)
p&&"static"===p.position&&(t.style.position="relative",t.dataset.previousPosition="static"),n.classList.add("v-ripple__animation--enter"),n.classList.add("v-ripple__animation--visible"),ra(n,`translate(${s}, ${u}) scale3d(${i},${i},${i})`),ia(n,0),n.dataset.activated=String(performance.now()),setTimeout((()=>{n.classList.remove("v-ripple__animation--enter"),n.classList.add("v-ripple__animation--in"),ra(n,`translate(${c}, ${d}) scale3d(1,1,1)`),ia(n,.08)}),0)},hide(e){var t
if(null==e||null==(t=e._ripple)||!t.enabled)return
const l=e.getElementsByClassName("v-ripple__animation")
if(0===l.length)return
const a=l[l.length-1]
if(a.dataset.isHiding)return
a.dataset.isHiding="true"
const o=performance.now()-Number(a.dataset.activated),n=Math.max(250-o,0)
setTimeout((()=>{a.classList.remove("v-ripple__animation--in"),a.classList.add("v-ripple__animation--out"),ia(a,0),setTimeout((()=>{1===e.getElementsByClassName("v-ripple__animation").length&&e.dataset.previousPosition&&(e.style.position=e.dataset.previousPosition,delete e.dataset.previousPosition),a.parentNode&&e.removeChild(a.parentNode)}),300)}),n)}}
function da(e){return void 0===e||!!e}function va(e){const t={},l=e.currentTarget
if(null!=l&&l._ripple&&!l._ripple.touched&&!e[na]){if(e[na]=!0,sa(e))l._ripple.touched=!0,l._ripple.isTouch=!0
else if(l._ripple.isTouch)return
if(t.center=l._ripple.centered||ua(e),l._ripple.class&&(t.class=l._ripple.class),sa(e)){if(l._ripple.showTimerCommit)return
l._ripple.showTimerCommit=()=>{ca.show(e,l,t)},l._ripple.showTimer=window.setTimeout((()=>{var e
null!=l&&null!=(e=l._ripple)&&e.showTimerCommit&&(l._ripple.showTimerCommit(),l._ripple.showTimerCommit=null)}),80)}else ca.show(e,l,t)}}function pa(e){e[na]=!0}function fa(e){const t=e.currentTarget
if(t&&t._ripple){if(window.clearTimeout(t._ripple.showTimer),"touchend"===e.type&&t._ripple.showTimerCommit)return t._ripple.showTimerCommit(),t._ripple.showTimerCommit=null,void(t._ripple.showTimer=window.setTimeout((()=>{fa(e)})))
window.setTimeout((()=>{t._ripple&&(t._ripple.touched=!1)})),ca.hide(t)}}function ma(e){const t=e.currentTarget
t&&t._ripple&&(t._ripple.showTimerCommit&&(t._ripple.showTimerCommit=null),window.clearTimeout(t._ripple.showTimer))}let ga=!1
function ha(e){ga||e.keyCode!==y.enter&&e.keyCode!==y.space||(ga=!0,va(e))}function ya(e){ga=!1,fa(e)}function ba(e){ga&&(ga=!1,fa(e))}function Va(e,t,l){const{value:a,modifiers:o}=t,n=da(a)
if(n||ca.hide(e),e._ripple=e._ripple??{},e._ripple.enabled=n,e._ripple.centered=o.center,e._ripple.circle=o.circle,h(a)&&a.class&&(e._ripple.class=a.class),n&&!l){if(o.stop)return e.addEventListener("touchstart",pa,{passive:!0}),void e.addEventListener("mousedown",pa)
e.addEventListener("touchstart",va,{passive:!0}),e.addEventListener("touchend",fa,{passive:!0}),e.addEventListener("touchmove",ma,{passive:!0}),e.addEventListener("touchcancel",fa),e.addEventListener("mousedown",va),e.addEventListener("mouseup",fa),e.addEventListener("mouseleave",fa),e.addEventListener("keydown",ha),e.addEventListener("keyup",ya),e.addEventListener("blur",ba),e.addEventListener("dragstart",fa,{passive:!0})}else!n&&l&&Sa(e)}function Sa(e){e.removeEventListener("mousedown",va),e.removeEventListener("touchstart",va),e.removeEventListener("touchend",fa),e.removeEventListener("touchmove",ma),e.removeEventListener("touchcancel",fa),e.removeEventListener("mouseup",fa),e.removeEventListener("mouseleave",fa),e.removeEventListener("keydown",ha),e.removeEventListener("keyup",ya),e.removeEventListener("dragstart",fa),e.removeEventListener("blur",ba)}const wa={mounted:function(e,t){Va(e,t,!1)},unmounted:function(e){delete e._ripple,Sa(e)},updated:function(e,t){if(t.value===t.oldValue)return
Va(e,t,da(t.oldValue))}},ka={center:"center",top:"bottom",bottom:"top",left:"right",right:"left"},xa=De({location:String},"location")
function Ca(e){let l=arguments.length>1&&void 0!==arguments[1]&&arguments[1],a=arguments.length>2?arguments[2]:void 0
const{isRtl:o}=Rt(),n=t.computed((()=>{if(!e.location)return{}
const{side:t,align:n}=H(e.location.split(" ").length>1?e.location:`${e.location} center`,o.value)
function r(e){return a?a(e):0}const i={}
return"center"!==t&&(l?i[ka[t]]=`calc(100% - ${r(t)}px)`:i[t]=0),"center"!==n?l?i[ka[n]]=`calc(100% - ${r(n)}px)`:i[n]=0:("center"===t?i.top=i.left="50%":i[{top:"left",bottom:"left",left:"top",right:"top"}[t]]="50%",i.transform={top:"translateX(-50%)",bottom:"translateX(-50%)",left:"translateY(-50%)",right:"translateY(-50%)",center:"translate(-50%, -50%)"}[t]),i}))
return{locationStyles:n}}const Na=je({name:"VProgressLinear",props:{absolute:Boolean,active:{type:Boolean,default:!0},bgColor:String,bgOpacity:[Number,String],bufferValue:{type:[Number,String],default:0},clickable:Boolean,color:String,height:{type:[Number,String],default:4},indeterminate:Boolean,max:{type:[Number,String],default:100},modelValue:{type:[Number,String],default:0},reverse:Boolean,stream:Boolean,striped:Boolean,roundedBar:Boolean,...xa({location:"top"}),...hl(),...dl(),...pt()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),{isRtl:n}=Rt(),{themeClasses:r}=gt(e),{locationStyles:i}=Ca(e),{textColorClasses:s,textColorStyles:u}=Vl(e,"color"),{backgroundColorClasses:c,backgroundColorStyles:d}=Sl(t.computed((()=>e.bgColor||e.color))),{backgroundColorClasses:v,backgroundColorStyles:p}=Sl(e,"color"),{roundedClasses:f}=yl(e),{intersectionRef:m,isIntersecting:h}=aa(),y=t.computed((()=>parseInt(e.max,10))),b=t.computed((()=>parseInt(e.height,10))),V=t.computed((()=>parseFloat(e.bufferValue)/y.value*100)),S=t.computed((()=>parseFloat(o.value)/y.value*100)),w=t.computed((()=>n.value!==e.reverse)),k=t.computed((()=>e.indeterminate?"fade-transition":"slide-x-transition")),x=t.computed((()=>null==e.bgOpacity?e.bgOpacity:parseFloat(e.bgOpacity)))
function C(e){if(!m.value)return
const{left:t,right:l,width:a}=m.value.getBoundingClientRect(),n=w.value?a-e.clientX+(l-a):e.clientX-t
o.value=Math.round(n/a*y.value)}return Ke((()=>t.createVNode(e.tag,{ref:m,class:["v-progress-linear",{"v-progress-linear--absolute":e.absolute,"v-progress-linear--active":e.active&&h.value,"v-progress-linear--reverse":w.value,"v-progress-linear--rounded":e.rounded,"v-progress-linear--rounded-bar":e.roundedBar,"v-progress-linear--striped":e.striped},f.value,r.value],style:{bottom:"bottom"===e.location?0:void 0,top:"top"===e.location?0:void 0,height:e.active?g(b.value):0,"--v-progress-linear-height":g(b.value),...i.value},role:"progressbar","aria-hidden":e.active?"false":"true","aria-valuemin":"0","aria-valuemax":e.max,"aria-valuenow":e.indeterminate?void 0:S.value,onClick:e.clickable&&C},{default:()=>[e.stream&&t.createVNode("div",{key:"stream",class:["v-progress-linear__stream",s.value],style:{...u.value,[w.value?"left":"right"]:g(-b.value),borderTop:`${g(b.value/2)} dotted`,opacity:x.value,top:`calc(50% - ${g(b.value/4)})`,width:g(100-V.value,"%"),"--v-progress-linear-stream-to":g(b.value*(w.value?1:-1))}},null),t.createVNode("div",{class:["v-progress-linear__background",c.value],style:[d.value,{opacity:x.value,width:g(e.stream?V.value:100,"%")}]},null),t.createVNode(t.Transition,{name:k.value},{default:()=>[e.indeterminate?t.createVNode("div",{class:"v-progress-linear__indeterminate"},[["long","short"].map((e=>t.createVNode("div",{key:e,class:["v-progress-linear__indeterminate",e,v.value],style:p.value},null)))]):t.createVNode("div",{class:["v-progress-linear__determinate",v.value],style:[p.value,{width:g(S.value,"%")}]},null)]}),a.default&&t.createVNode("div",{class:"v-progress-linear__content"},[a.default({value:S.value,buffer:V.value})])]}))),{}}}),_a=De({loading:[Boolean,String]},"loader")
function Ia(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=t.computed((()=>({[`${l}--loading`]:e.loading})))
return{loaderClasses:a}}function Ba(e,l){var a
let{slots:o}=l
return t.createVNode("div",{class:`${e.name}__loader`},[(null==(a=o.default)?void 0:a.call(o,{color:e.color,isActive:e.active}))||t.createVNode(Na,{active:e.active,color:e.color,height:"2",indeterminate:!0},null)])}const $a=["static","relative","fixed","absolute","sticky"],Aa=De({position:{type:String,validator:e=>$a.includes(e)}},"position")
function Ea(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=t.computed((()=>e.position?`${l}--${e.position}`:void 0))
return{positionClasses:a}}function Ra(){var e,t
return null==(e=Ae("useRouter"))||null==(t=e.proxy)?void 0:t.$router}function Ta(e,l){const a=t.resolveDynamicComponent("RouterLink"),o=t.computed((()=>!(!e.href&&!e.to))),n=t.computed((()=>(null==o?void 0:o.value)||M(l,"click")||M(e,"click")))
if("string"==typeof a)return{isLink:o,isClickable:n,href:t.toRef(e,"href")}
const r=e.to?a.useLink(e):void 0
return{isLink:o,isClickable:n,route:null==r?void 0:r.route,navigate:null==r?void 0:r.navigate,isActive:r&&t.computed((()=>{var t,l
return e.exact?null==(t=r.isExactActive)?void 0:t.value:null==(l=r.isActive)?void 0:l.value})),href:t.computed((()=>e.to?null==r?void 0:r.route.value.href:e.href))}}const La=De({href:String,replace:Boolean,to:[String,Object],exact:Boolean},"router")
let Pa=!1
const Oa=je({name:"VBtn",directives:{Ripple:wa},props:{active:{type:Boolean,default:void 0},symbol:{type:null,default:Ml},flat:Boolean,icon:[Boolean,String,Function,Object],prependIcon:Hl,appendIcon:Hl,block:Boolean,stacked:Boolean,ripple:{type:Boolean,default:!0},...pl(),...hl(),..._l(),...al(),...ml(),...Ll(),..._a(),...xa(),...Aa(),...La(),...Ql(),...dl({tag:"button"}),...pt(),...Al({variant:"elevated"})},emits:{"group:selected":e=>!0},setup(e,l){let{attrs:a,slots:o}=l
const{themeClasses:n}=gt(e),{borderClasses:r}=fl(e),{colorClasses:i,colorStyles:s,variantClasses:u}=El(e),{densityClasses:c}=Il(e),{dimensionStyles:d}=ol(e),{elevationClasses:v}=gl(e),{loaderClasses:p}=Ia(e),{locationStyles:f}=Ca(e),{positionClasses:m}=Ea(e),{roundedClasses:g}=yl(e),{sizeClasses:h,sizeStyles:y}=ea(e),b=Pl(e,e.symbol,!1),V=Ta(e,a),S=t.computed((()=>{return void 0!==e.active?e.active:V.isLink.value?null==(t=V.isActive)?void 0:t.value:null==b?void 0:b.isSelected.value
var t})),w=t.computed((()=>(null==b?void 0:b.disabled.value)||e.disabled)),k=t.computed((()=>"elevated"===e.variant&&!(e.disabled||e.flat||e.border))),x=t.computed((()=>{if(void 0!==e.value)return Object(e.value)===e.value?JSON.stringify(e.value,null,0):e.value}))
return function(e,l){t.watch((()=>{var t
return null==(t=e.isActive)?void 0:t.value}),(a=>{e.isLink.value&&a&&l&&t.nextTick((()=>{l(!0)}))}),{immediate:!0})}(V,null==b?void 0:b.select),Ke((()=>{var l,a,C,N,_,I
const B=V.isLink.value?"a":e.tag,$=!(!e.prependIcon&&!o.prepend),A=!(!e.appendIcon&&!o.append),E=!(!e.icon||!0===e.icon),R=(null==b?void 0:b.isSelected.value)&&(!V.isLink.value||(null==(l=V.isActive)?void 0:l.value))||!b||(null==(a=V.isActive)?void 0:a.value)
return t.withDirectives(t.createVNode(B,{type:"a"===B?void 0:"button",class:["v-btn",null==b?void 0:b.selectedClass.value,{"v-btn--active":S.value,"v-btn--block":e.block,"v-btn--disabled":w.value,"v-btn--elevated":k.value,"v-btn--flat":e.flat,"v-btn--icon":!!e.icon,"v-btn--loading":e.loading,"v-btn--stacked":e.stacked},n.value,r.value,R?i.value:void 0,c.value,v.value,p.value,m.value,g.value,h.value,u.value],style:[R?s.value:void 0,d.value,f.value,y.value],disabled:w.value||void 0,href:V.href.value,onClick:e=>{var t
w.value||(null==(t=V.navigate)||t.call(V,e),null==b||b.toggle())},value:x.value},{default:()=>[$l(!0,"v-btn"),!e.icon&&$&&t.createVNode(Lt,{key:"prepend",defaults:{VIcon:{icon:e.prependIcon}}},{default:()=>[t.createVNode("span",{class:"v-btn__prepend"},[(null==(C=o.prepend)?void 0:C.call(o))??t.createVNode(la,null,null)])]}),t.createVNode("span",{class:"v-btn__content","data-no-activator":""},[t.createVNode(Lt,{key:"content",defaults:{VIcon:{icon:E?e.icon:void 0}}},{default:()=>[(null==(N=o.default)?void 0:N.call(o))??(E&&t.createVNode(la,{key:"icon"},null))]})]),!e.icon&&A&&t.createVNode(Lt,{key:"append",defaults:{VIcon:{icon:e.appendIcon}}},{default:()=>[t.createVNode("span",{class:"v-btn__append"},[(null==(_=o.append)?void 0:_.call(o))??t.createVNode(la,null,null)])]}),!!e.loading&&t.createVNode("span",{key:"loader",class:"v-btn__loader"},[(null==(I=o.loader)?void 0:I.call(o))??t.createVNode(oa,{color:"boolean"==typeof e.loading?void 0:e.loading,indeterminate:!0,size:"23",width:"2"},null)])]}),[[t.resolveDirective("ripple"),!w.value&&e.ripple,null]])})),{}}}),Fa=je({name:"VAppBarNavIcon",props:{icon:{type:Hl,default:"$menu"}},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(Oa,{class:"v-app-bar-nav-icon",icon:e.icon},a))),{}}}),Ma=je({name:"VToolbarItems",props:Al({variant:"text"}),setup(e,l){let{slots:a}=l
return Me({VBtn:{color:t.toRef(e,"color"),height:"inherit",variant:t.toRef(e,"variant")}}),Ke((()=>{var e
return t.createVNode("div",{class:"v-toolbar-items"},[null==(e=a.default)?void 0:e.call(a)])})),{}}}),za=je({name:"VAppBarTitle",props:{...vl.props},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(vl,t.mergeProps(e,{class:"v-app-bar-title"}),a))),{}}}),Da=We("v-alert-title"),ja=["success","info","warning","error"],Ha=je({name:"VAlert",props:{border:{type:[Boolean,String],validator:e=>"boolean"==typeof e||["top","end","bottom","start"].includes(e)},borderColor:String,closable:Boolean,closeIcon:{type:Hl,default:"$close"},closeLabel:{type:String,default:"$vuetify.close"},icon:{type:[Boolean,String,Function,Object],default:null},modelValue:{type:Boolean,default:!0},prominent:Boolean,title:String,text:String,type:{type:String,validator:e=>ja.includes(e)},..._l(),...al(),...ml(),...xa(),...Aa(),...hl(),...dl(),...pt(),...Al({variant:"flat"})},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),n=t.computed((()=>{if(!1!==e.icon)return e.type?e.icon??`$${e.type}`:e.icon})),r=t.computed((()=>({color:e.color??e.type,variant:e.variant}))),{themeClasses:i}=gt(e),{colorClasses:s,colorStyles:u,variantClasses:c}=El(r),{densityClasses:d}=Il(e),{dimensionStyles:v}=ol(e),{elevationClasses:p}=gl(e),{locationStyles:f}=Ca(e),{positionClasses:m}=Ea(e),{roundedClasses:g}=yl(e),{textColorClasses:h,textColorStyles:y}=Vl(t.toRef(e,"borderColor")),{t:b}=At(),V=t.computed((()=>({"aria-label":b(e.closeLabel),onClick(e){o.value=!1}})))
return()=>{var l,r
const b=!(!a.prepend&&!n.value),S=!(!a.title&&!e.title),w=!(!e.text&&!a.text),k=!(!a.close&&!e.closable)
return o.value&&t.createVNode(e.tag,{class:["v-alert",e.border&&{"v-alert--border":!!e.border,[`v-alert--border-${!0===e.border?"start":e.border}`]:!0},{"v-alert--prominent":e.prominent},i.value,s.value,d.value,p.value,m.value,g.value,c.value],style:[u.value,v.value,f.value],role:"alert"},{default:()=>[$l(!1,"v-alert"),e.border&&t.createVNode("div",{key:"border",class:["v-alert__border",h.value],style:y.value},null),b&&t.createVNode(Lt,{key:"prepend",defaults:{VIcon:{density:e.density,icon:n.value,size:e.prominent?44:28}}},{default:()=>[t.createVNode("div",{class:"v-alert__prepend"},[a.prepend?a.prepend():n.value&&t.createVNode(la,null,null)])]}),t.createVNode("div",{class:"v-alert__content"},[S&&t.createVNode(Da,{key:"title"},{default:()=>[a.title?a.title():e.title]}),w&&(a.text?a.text():e.text),null==(l=a.default)?void 0:l.call(a)]),a.append&&t.createVNode("div",{key:"append",class:"v-alert__append"},[a.append()]),k&&t.createVNode(Lt,{key:"close",defaults:{VBtn:{icon:e.closeIcon,size:"x-small",variant:"text"}}},{default:()=>[t.createVNode("div",{class:"v-alert__close"},[(null==(r=a.close)?void 0:r.call(a,{props:V.value}))??t.createVNode(Oa,V.value,null)])]})]})}}})
function Wa(e){const{t:l}=At()
return{InputIcon:function(a){let{name:o}=a
const n={prepend:"prependAction",prependInner:"prependAction",append:"appendAction",appendInner:"appendAction",clear:"clear"}[o],r=e[`onClick:${o}`],i=r&&n?l(`$vuetify.input.${n}`,e.label??""):void 0
return t.createVNode(la,{icon:e[`${o}Icon`],"aria-label":i,onClick:r},null)}}}const Ua=je({name:"VLabel",props:{text:String,clickable:Boolean,...pt()},setup(e,l){let{slots:a}=l
return Ke((()=>{var l
return t.createVNode("label",{class:["v-label",{"v-label--clickable":e.clickable}]},[e.text,null==(l=a.default)?void 0:l.call(a)])})),{}}}),Ya=je({name:"VFieldLabel",props:{floating:Boolean},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(Ua,{class:["v-field-label",{"v-field-label--floating":e.floating}],"aria-hidden":e.floating||void 0},a))),{}}}),Xa=De({focused:Boolean},"focus")
function Ga(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee()
const a=Vt(e,"focused"),o=t.computed((()=>({[`${l}--focused`]:a.value})))
function n(){a.value=!0}function r(){a.value=!1}return{focusClasses:o,isFocused:a,focus:n,blur:r}}const qa=["underlined","outlined","filled","solo","plain"],Ka=De({appendInnerIcon:Hl,bgColor:String,clearable:Boolean,clearIcon:{type:Hl,default:"$clear"},active:Boolean,color:String,dirty:Boolean,disabled:Boolean,error:Boolean,label:String,persistentClear:Boolean,prependInnerIcon:Hl,reverse:Boolean,singleLine:Boolean,variant:{type:String,default:"filled",validator:e=>qa.includes(e)},"onClick:clear":F,"onClick:appendInner":F,"onClick:prependInner":F,...pt(),..._a()},"v-field"),Za=He()({name:"VField",inheritAttrs:!1,props:{id:String,...Xa(),...Ka()},emits:{"click:control":e=>!0,"update:focused":e=>!0,"update:modelValue":e=>!0},setup(e,l){let{attrs:a,emit:o,slots:n}=l
const{themeClasses:r}=gt(e),{loaderClasses:i}=Ia(e),{focusClasses:s,isFocused:u,focus:c,blur:d}=Ga(e),{InputIcon:v}=Wa(e),p=t.computed((()=>e.dirty||e.active)),f=t.computed((()=>!(e.singleLine||!e.label&&!n.label))),m=Le(),h=t.computed((()=>e.id||`input-${m}`)),y=t.computed((()=>`${h.value}-messages`)),b=t.ref(),V=t.ref(),S=t.ref(),{backgroundColorClasses:w,backgroundColorStyles:k}=Sl(t.toRef(e,"bgColor")),{textColorClasses:x,textColorStyles:C}=Vl(t.computed((()=>p.value&&u.value&&!e.error&&!e.disabled?e.color:void 0)))
t.watch(p,(e=>{if(f.value){const t=b.value.$el,l=V.value.$el
requestAnimationFrame((()=>{const a=Z(t),o=l.getBoundingClientRect(),n=o.x-a.x,r=o.y-a.y-(a.height/2-o.height/2),i=o.width/.75,s=Math.abs(i-a.width)>1?{maxWidth:g(i)}:void 0,u=getComputedStyle(t),c=getComputedStyle(l),d=1e3*parseFloat(u.transitionDuration)||150,v=parseFloat(c.getPropertyValue("--v-field-label-scale")),p=c.getPropertyValue("color")
t.style.visibility="visible",l.style.visibility="hidden",J(t,{transform:`translate(${n}px, ${r}px) scale(${v})`,color:p,...s},{duration:d,easing:Ye,direction:e?"normal":"reverse"}).finished.then((()=>{t.style.removeProperty("visibility"),l.style.removeProperty("visibility")}))}))}}),{flush:"post"})
const N=t.computed((()=>({isActive:p,isFocused:u,controlRef:S,blur:d,focus:c})))
function _(e){e.target!==document.activeElement&&e.preventDefault(),o("click:control",e)}return Ke((()=>{var l,o,u
const m="outlined"===e.variant,g=n["prepend-inner"]||e.prependInnerIcon,S=!(!e.clearable&&!n.clear),I=!!(n["append-inner"]||e.appendInnerIcon||S),B=n.label?n.label({label:e.label,props:{for:h.value}}):e.label
return t.createVNode("div",t.mergeProps({class:["v-field",{"v-field--active":p.value,"v-field--appended":I,"v-field--disabled":e.disabled,"v-field--dirty":e.dirty,"v-field--error":e.error,"v-field--has-background":!!e.bgColor,"v-field--persistent-clear":e.persistentClear,"v-field--prepended":g,"v-field--reverse":e.reverse,"v-field--single-line":e.singleLine,"v-field--no-label":!B,[`v-field--variant-${e.variant}`]:!0},r.value,w.value,s.value,i.value],style:[k.value,C.value],onClick:_},a),[t.createVNode("div",{class:"v-field__overlay"},null),t.createVNode(Ba,{name:"v-field",active:!!e.loading,color:e.error?"error":e.color},{default:n.loader}),g&&t.createVNode("div",{key:"prepend",class:"v-field__prepend-inner"},[e.prependInnerIcon&&t.createVNode(v,{key:"prepend-icon",name:"prependInner"},null),null==(l=n["prepend-inner"])?void 0:l.call(n,N.value)]),t.createVNode("div",{class:"v-field__field","data-no-activator":""},[["solo","filled"].includes(e.variant)&&f.value&&t.createVNode(Ya,{key:"floating-label",ref:V,class:[x.value],floating:!0,for:h.value},{default:()=>[B]}),t.createVNode(Ya,{ref:b,for:h.value},{default:()=>[B]}),null==(o=n.default)?void 0:o.call(n,{...N.value,props:{id:h.value,class:"v-field__input","aria-describedby":y.value},focus:c,blur:d})]),S&&t.createVNode(ll,{key:"clear"},{default:()=>[t.withDirectives(t.createVNode("div",{class:"v-field__clearable"},[n.clear?n.clear():t.createVNode(v,{name:"clear"},null)]),[[t.vShow,e.dirty]])]}),I&&t.createVNode("div",{key:"append",class:"v-field__append-inner"},[null==(u=n["append-inner"])?void 0:u.call(n,N.value),e.appendInnerIcon&&t.createVNode(v,{key:"append-icon",name:"appendInner"},null)]),t.createVNode("div",{class:["v-field__outline",x.value]},[m&&t.createVNode(t.Fragment,null,[t.createVNode("div",{class:"v-field__outline__start"},null),f.value&&t.createVNode("div",{class:"v-field__outline__notch"},[t.createVNode(Ya,{ref:V,floating:!0,for:h.value},{default:()=>[B]})]),t.createVNode("div",{class:"v-field__outline__end"},null)]),["plain","underlined"].includes(e.variant)&&f.value&&t.createVNode(Ya,{ref:V,floating:!0,for:h.value},{default:()=>[B]})])])})),{controlRef:S}}})
function Ja(e){return S(e,Object.keys(Za.props).filter((e=>!O(e))))}const Qa=je({name:"VMessages",props:{active:Boolean,color:String,messages:{type:[Array,String],default:()=>[]},...sl({transition:{component:Qt,leaveAbsolute:!0,group:!0}})},setup(e,l){let{slots:a}=l
const o=t.computed((()=>x(e.messages))),{textColorClasses:n,textColorStyles:r}=Vl(t.computed((()=>e.color)))
return Ke((()=>t.createVNode(ul,{transition:e.transition,tag:"div",class:["v-messages",n.value],style:r.value,role:"alert","aria-live":"polite"},{default:()=>[e.active&&o.value.map(((e,l)=>t.createVNode("div",{class:"v-messages__message",key:`${l}-${o.value}`},[a.message?a.message({message:e}):e])))]}))),{}}}),eo=Symbol.for("vuetify:form"),to=De({disabled:Boolean,fastFail:Boolean,readonly:Boolean,modelValue:{type:Boolean,default:null},validateOn:{type:String,default:"input"}},"form")
function lo(){return t.inject(eo,null)}const ao=De({disabled:Boolean,error:Boolean,errorMessages:{type:[Array,String],default:()=>[]},maxErrors:{type:[Number,String],default:1},name:String,label:String,readonly:Boolean,rules:{type:Array,default:()=>[]},modelValue:null,validateOn:String,validationValue:null,...Xa()},"validation")
function oo(e){let l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:Ee(),a=arguments.length>2&&void 0!==arguments[2]?arguments[2]:Le()
const o=Vt(e,"modelValue"),n=t.computed((()=>void 0===e.validationValue?o.value:e.validationValue)),r=lo(),i=t.ref([]),s=t.ref(!0),u=t.computed((()=>!(!x(""===o.value?null:o.value).length&&!x(""===n.value?null:n.value).length))),c=t.computed((()=>!!(e.disabled||null!=r&&r.isDisabled.value))),d=t.computed((()=>!!(e.readonly||null!=r&&r.isReadonly.value))),v=t.computed((()=>e.errorMessages.length?x(e.errorMessages).slice(0,Math.max(0,+e.maxErrors)):i.value)),p=t.computed((()=>!e.error&&!v.value.length&&(!e.rules.length||(!s.value||null)))),f=t.ref(!1),m=t.computed((()=>({[`${l}--error`]:!1===p.value,[`${l}--dirty`]:u.value,[`${l}--disabled`]:c.value,[`${l}--readonly`]:d.value}))),g=t.computed((()=>e.name??t.unref(a)))
t.onBeforeMount((()=>{null==r||r.register({id:g.value,validate:V,reset:y,resetValidation:b})})),t.onBeforeUnmount((()=>{null==r||r.unregister(g.value)}))
const h=t.computed((()=>e.validateOn||(null==r?void 0:r.validateOn.value)||"input"))
function y(){b(),o.value=null}function b(){s.value=!0,i.value=[]}async function V(){const t=[]
f.value=!0
for(const l of e.rules){if(t.length>=(e.maxErrors??1))break
const a="function"==typeof l?l:()=>l,o=await a(n.value)
!0!==o&&("string"==typeof o?t.push(o):console.warn(`${o} is not a valid value. Rule functions must return boolean true or a string.`))}return i.value=t,f.value=!1,s.value=!1,i.value}return t.onMounted((()=>null==r?void 0:r.update(g.value,p.value,v.value))),ze((()=>"input"===h.value),(()=>{t.watch(n,(()=>{if(null!=n.value)V()
else if(e.focused){const l=t.watch((()=>e.focused),(e=>{e||V(),l()}))}}))})),ze((()=>"blur"===h.value),(()=>{t.watch((()=>e.focused),(e=>{e||V()}))})),t.watch(p,(()=>{null==r||r.update(g.value,p.value,v.value)})),{errorMessages:v,isDirty:u,isDisabled:c,isReadonly:d,isPristine:s,isValid:p,isValidating:f,reset:y,resetValidation:b,validate:V,validationClasses:m}}const no=De({id:String,appendIcon:Hl,prependIcon:Hl,hideDetails:[Boolean,String],messages:{type:[Array,String],default:()=>[]},direction:{type:String,default:"horizontal",validator:e=>["horizontal","vertical"].includes(e)},"onClick:prepend":F,"onClick:append":F,..._l(),...ao()},"v-input"),ro=He()({name:"VInput",props:{...no()},emits:{"update:modelValue":e=>!0},setup(e,l){let{attrs:a,slots:o,emit:n}=l
const{densityClasses:r}=Il(e),{InputIcon:i}=Wa(e),s=Le(),u=t.computed((()=>e.id||`input-${s}`)),c=t.computed((()=>`${u.value}-messages`)),{errorMessages:d,isDirty:v,isDisabled:p,isReadonly:f,isPristine:m,isValid:g,isValidating:h,reset:y,resetValidation:b,validate:V,validationClasses:S}=oo(e,"v-input",u),w=t.computed((()=>({id:u,messagesId:c,isDirty:v,isDisabled:p,isReadonly:f,isPristine:m,isValid:g,isValidating:h,reset:y,resetValidation:b,validate:V})))
return Ke((()=>{var l,a,n,s,u
const v=!(!o.prepend&&!e.prependIcon),p=!(!o.append&&!e.appendIcon),f=!!(null!=(l=e.messages)&&l.length||d.value.length),m=!e.hideDetails||"auto"===e.hideDetails&&(f||!!o.details)
return t.createVNode("div",{class:["v-input",`v-input--${e.direction}`,r.value,S.value]},[v&&t.createVNode("div",{key:"prepend",class:"v-input__prepend"},[null==(a=o.prepend)?void 0:a.call(o,w.value),e.prependIcon&&t.createVNode(i,{key:"prepend-icon",name:"prepend"},null)]),o.default&&t.createVNode("div",{class:"v-input__control"},[null==(n=o.default)?void 0:n.call(o,w.value)]),p&&t.createVNode("div",{key:"append",class:"v-input__append"},[e.appendIcon&&t.createVNode(i,{key:"append-icon",name:"append"},null),null==(s=o.append)?void 0:s.call(o,w.value)]),m&&t.createVNode("div",{class:"v-input__details"},[t.createVNode(Qa,{id:c.value,active:f,messages:d.value.length>0?d.value:e.messages},{message:o.message}),null==(u=o.details)?void 0:u.call(o,w.value)])])})),{reset:y,resetValidation:b,validate:V}}})
function io(e){return S(e,Object.keys(ro.props).filter((e=>!O(e))))}const so=je({name:"VCounter",functional:!0,props:{active:Boolean,max:[Number,String],value:{type:[Number,String],default:0},...sl({transition:{component:Qt}})},setup(e,l){let{slots:a}=l
const o=t.computed((()=>e.max?`${e.value} / ${e.max}`:String(e.value)))
return Ke((()=>t.createVNode(ul,{transition:e.transition},{default:()=>[t.withDirectives(t.createVNode("div",{class:"v-counter"},[a.default?a.default({counter:o.value,max:e.max,value:e.value}):o.value]),[[t.vShow,e.active]])]}))),{}}}),uo=Symbol("Forwarded refs")
function co(e){for(var t=arguments.length,l=new Array(t>1?t-1:0),a=1;a<t;a++)l[a-1]=arguments[a]
return e[uo]=l,new Proxy(e,{get(e,t){if(Reflect.has(e,t))return Reflect.get(e,t)
for(const e of l)if(e.value&&Reflect.has(e.value,t)){const l=Reflect.get(e.value,t)
return"function"==typeof l?l.bind(e.value):l}},getOwnPropertyDescriptor(e,t){const a=Reflect.getOwnPropertyDescriptor(e,t)
if(a)return a
if("symbol"!=typeof t&&!t.startsWith("__")){for(const e of l){if(!e.value)continue
const l=Reflect.getOwnPropertyDescriptor(e.value,t)
if(l)return l
if("_"in e.value&&"setupState"in e.value._){const l=Reflect.getOwnPropertyDescriptor(e.value._.setupState,t)
if(l)return l}}for(const e of l){let l=e.value&&Object.getPrototypeOf(e.value)
for(;l;){const e=Reflect.getOwnPropertyDescriptor(l,t)
if(e)return e
l=Object.getPrototypeOf(l)}}for(const e of l){const l=e.value&&e.value[uo]
if(!l)continue
const a=l.slice()
for(;a.length;){const e=a.shift(),l=Reflect.getOwnPropertyDescriptor(e.value,t)
if(l)return l
const o=e.value&&e.value[uo]
o&&a.push(...o)}}}}})}const vo=["color","file","time","date","datetime-local","week","month"],po=De({autofocus:Boolean,counter:[Boolean,Number,String],counterValue:Function,hint:String,persistentHint:Boolean,prefix:String,placeholder:String,persistentPlaceholder:Boolean,persistentCounter:Boolean,suffix:String,type:{type:String,default:"text"},...no(),...Ka()},"v-text-field"),fo=He()({name:"VTextField",directives:{Intersect:il},inheritAttrs:!1,props:po(),emits:{"click:control":e=>!0,"click:input":e=>!0,"update:focused":e=>!0,"update:modelValue":e=>!0},setup(e,l){let{attrs:a,emit:o,slots:n}=l
const r=Vt(e,"modelValue"),{isFocused:i,focus:s,blur:u}=Ga(e),c=t.computed((()=>"function"==typeof e.counterValue?e.counterValue(r.value):(r.value??"").toString().length)),d=t.computed((()=>a.maxlength?a.maxlength:!e.counter||"number"!=typeof e.counter&&"string"!=typeof e.counter?void 0:e.counter))
function v(t,l){var a,o
e.autofocus&&t&&(null==(a=l[0].target)||null==(o=a.focus)||o.call(a))}const p=t.ref(),f=t.ref(),m=t.ref(),g=t.computed((()=>vo.includes(e.type)||e.persistentPlaceholder||i.value)),h=t.computed((()=>e.messages.length?e.messages:i.value||e.persistentHint?e.hint:""))
function y(){var e
m.value!==document.activeElement&&(null==(e=m.value)||e.focus())
i.value||s()}function b(e){y(),o("click:control",e)}function V(l){l.stopPropagation(),y(),t.nextTick((()=>{r.value=null,z(e["onClick:clear"],l)}))}function S(e){r.value=e.target.value}return Ke((()=>{const l=!!(n.counter||e.counter||e.counterValue),s=!(!l&&!n.details),[w,x]=k(a),[{modelValue:C,...N}]=io(e),[_]=Ja(e)
return t.createVNode(ro,t.mergeProps({ref:p,modelValue:r.value,"onUpdate:modelValue":e=>r.value=e,class:["v-text-field",{"v-text-field--prefixed":e.prefix,"v-text-field--suffixed":e.suffix,"v-text-field--flush-details":["plain","underlined"].includes(e.variant)}],"onClick:prepend":e["onClick:prepend"],"onClick:append":e["onClick:append"]},w,N,{focused:i.value,messages:h.value}),{...n,default:l=>{let{id:a,isDisabled:s,isDirty:c,isReadonly:d,isValid:p}=l
return t.createVNode(Za,t.mergeProps({ref:f,onMousedown:e=>{e.target!==m.value&&e.preventDefault()},"onClick:control":b,"onClick:clear":V,"onClick:prependInner":e["onClick:prependInner"],"onClick:appendInner":e["onClick:appendInner"],role:"textbox"},_,{id:a.value,active:g.value||c.value,dirty:c.value||e.dirty,focused:i.value,error:!1===p.value}),{...n,default:l=>{let{props:{class:a,...i}}=l
const c=t.withDirectives(t.createVNode("input",t.mergeProps({ref:m,value:r.value,onInput:S,autofocus:e.autofocus,readonly:d.value,disabled:s.value,name:e.name,placeholder:e.placeholder,size:1,type:e.type,onFocus:y,onBlur:u},i,x),null),[[t.resolveDirective("intersect"),{handler:v},null,{once:!0}]])
return t.createVNode(t.Fragment,null,[e.prefix&&t.createVNode("span",{class:"v-text-field__prefix"},[e.prefix]),n.default?t.createVNode("div",{class:a,onClick:e=>o("click:input",e),"data-no-activator":""},[n.default(),c]):t.cloneVNode(c,{class:a}),e.suffix&&t.createVNode("span",{class:"v-text-field__suffix"},[e.suffix])])}})},details:s?a=>{var o
return t.createVNode(t.Fragment,null,[null==(o=n.details)?void 0:o.call(n,a),l&&t.createVNode(t.Fragment,null,[t.createVNode("span",null,null),t.createVNode(so,{active:e.persistentCounter||i.value,value:c.value,max:d.value},n.counter)])])}:void 0})})),co({},p,f,m)}})
function mo(e){return S(e,Object.keys(fo.props))}const go=Symbol.for("vuetify:selection-control-group"),ho=De({color:String,disabled:Boolean,error:Boolean,id:String,inline:Boolean,falseIcon:Hl,trueIcon:Hl,ripple:{type:Boolean,default:!0},multiple:{type:Boolean,default:null},name:String,readonly:Boolean,modelValue:null,type:String,valueComparator:{type:Function,default:v},...pt(),..._l()},"v-selection-control-group"),yo=je({name:"VSelectionControlGroup",props:{defaultsTarget:{type:String,default:"VSelectionControl"},...ho()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),n=Le(),r=t.computed((()=>e.id||`v-selection-control-group-${n}`)),i=t.computed((()=>e.name||r.value)),s=new Set
return t.provide(go,{modelValue:o,forceUpdate:()=>{s.forEach((e=>e()))},onForceUpdate:e=>{s.add(e),t.onScopeDispose((()=>{s.delete(e)}))}}),Me({[e.defaultsTarget]:{color:t.toRef(e,"color"),disabled:t.toRef(e,"disabled"),density:t.toRef(e,"density"),error:t.toRef(e,"error"),inline:t.toRef(e,"inline"),modelValue:o,multiple:t.computed((()=>!!e.multiple||null==e.multiple&&Array.isArray(o.value))),name:i,falseIcon:t.toRef(e,"falseIcon"),trueIcon:t.toRef(e,"trueIcon"),readonly:t.toRef(e,"readonly"),ripple:t.toRef(e,"ripple"),type:t.toRef(e,"type"),valueComparator:t.toRef(e,"valueComparator")}}),Ke((()=>{var l
return t.createVNode("div",{class:["v-selection-control-group",{"v-selection-control-group--inline":e.inline}],role:"radio"===e.type?"radiogroup":void 0},[null==(l=a.default)?void 0:l.call(a)])})),{}}}),bo=De({label:String,trueValue:null,falseValue:null,value:null,...ho()},"v-selection-control")
const Vo=He()({name:"VSelectionControl",directives:{Ripple:wa},inheritAttrs:!1,props:bo(),emits:{"update:modelValue":e=>!0},setup(e,l){let{attrs:a,slots:o}=l
const{group:r,densityClasses:i,icon:s,model:u,textColorClasses:c,textColorStyles:d,trueValue:v}=function(e){const l=t.inject(go,void 0),{densityClasses:a}=Il(e),o=Vt(e,"modelValue"),n=t.computed((()=>void 0!==e.trueValue?e.trueValue:void 0===e.value||e.value)),r=t.computed((()=>void 0!==e.falseValue&&e.falseValue)),i=t.computed((()=>!!e.multiple||null==e.multiple&&Array.isArray(o.value))),s=t.computed({get(){const t=l?l.modelValue.value:o.value
return i.value?t.some((t=>e.valueComparator(t,n.value))):e.valueComparator(t,n.value)},set(t){if(e.readonly)return
const a=t?n.value:r.value
let s=a
i.value&&(s=t?[...x(o.value),a]:x(o.value).filter((t=>!e.valueComparator(t,n.value)))),l?l.modelValue.value=s:o.value=s}}),{textColorClasses:u,textColorStyles:c}=Vl(t.computed((()=>!s.value||e.error||e.disabled?void 0:e.color))),d=t.computed((()=>s.value?e.trueIcon:e.falseIcon))
return{group:l,densityClasses:a,trueValue:n,falseValue:r,model:s,textColorClasses:u,textColorStyles:c,icon:d}}(e),p=Le(),f=t.computed((()=>e.id||`input-${p}`)),m=t.ref(!1),g=t.ref(!1),h=t.ref()
function y(e){m.value=!0,(!n||n&&e.target.matches(":focus-visible"))&&(g.value=!0)}function b(){m.value=!1,g.value=!1}function V(l){e.readonly&&r&&t.nextTick((()=>r.forceUpdate())),u.value=l.target.checked}return null==r||r.onForceUpdate((()=>{h.value&&(h.value.checked=u.value)})),Ke((()=>{var l,n
const r=o.label?o.label({label:e.label,props:{for:f.value}}):e.label,[p,S]=k(a)
return t.createVNode("div",t.mergeProps({class:["v-selection-control",{"v-selection-control--dirty":u.value,"v-selection-control--disabled":e.disabled,"v-selection-control--error":e.error,"v-selection-control--focused":m.value,"v-selection-control--focus-visible":g.value,"v-selection-control--inline":e.inline},i.value]},p),[t.createVNode("div",{class:["v-selection-control__wrapper",c.value],style:d.value},[null==(l=o.default)?void 0:l.call(o),t.withDirectives(t.createVNode("div",{class:["v-selection-control__input"]},[s.value&&t.createVNode(la,{key:"icon",icon:s.value},null),t.createVNode("input",t.mergeProps({ref:h,checked:u.value,disabled:e.disabled,id:f.value,onBlur:b,onFocus:y,onInput:V,"aria-disabled":e.readonly,type:e.type,value:v.value,name:e.name,"aria-checked":"checkbox"===e.type?u.value:void 0},S),null),null==(n=o.input)?void 0:n.call(o,{model:u,textColorClasses:c,textColorStyles:d,props:{onFocus:y,onBlur:b,id:f.value}})]),[[t.resolveDirective("ripple"),e.ripple&&[!e.disabled&&!e.readonly,null,["center","circle"]]]])]),r&&t.createVNode(Ua,{for:f.value,clickable:!0},{default:()=>[r]})])})),{isFocused:m,input:h}}})
function So(e){return S(e,Object.keys(Vo.props))}const wo=De({indeterminate:Boolean,indeterminateIcon:{type:Hl,default:"$checkboxIndeterminate"},...bo({falseIcon:"$checkboxOff",trueIcon:"$checkboxOn"})},"v-checkbox-btn"),ko=je({name:"VCheckboxBtn",props:wo(),emits:{"update:modelValue":e=>!0,"update:indeterminate":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"indeterminate"),n=Vt(e,"modelValue")
function r(e){o.value&&(o.value=!1)}const i=t.computed((()=>e.indeterminate?e.indeterminateIcon:e.falseIcon)),s=t.computed((()=>e.indeterminate?e.indeterminateIcon:e.trueIcon))
return Ke((()=>t.createVNode(Vo,t.mergeProps(e,{modelValue:n.value,"onUpdate:modelValue":[e=>n.value=e,r],class:"v-checkbox-btn",type:"checkbox",inline:!0,falseIcon:i.value,trueIcon:s.value,"aria-checked":e.indeterminate?"mixed":void 0}),a))),{}}})
const xo=je({name:"VCheckbox",inheritAttrs:!1,props:{...no(),...wo()},emits:{"update:focused":e=>!0},setup(e,l){let{attrs:a,slots:o}=l
const{isFocused:n,focus:r,blur:i}=Ga(e),s=Le(),u=t.computed((()=>e.id||`checkbox-${s}`))
return Ke((()=>{const[l,s]=k(a),[c,d]=io(e),[v,p]=function(e){return S(e,Object.keys(ko.props))}(e)
return t.createVNode(ro,t.mergeProps({class:"v-checkbox"},l,c,{id:u.value,focused:n.value}),{...o,default:e=>{let{id:l,messagesId:a,isDisabled:n,isReadonly:u}=e
return t.createVNode(ko,t.mergeProps(v,{id:l.value,"aria-describedby":a.value,disabled:n.value,readonly:u.value},s,{onFocus:r,onBlur:i}),o)}})})),{}}}),Co=De({start:Boolean,end:Boolean,icon:Hl,image:String,..._l(),...hl(),...Ql(),...dl(),...pt(),...Al({variant:"flat"})},"v-avatar"),No=je({name:"VAvatar",props:Co(),setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{colorClasses:n,colorStyles:r,variantClasses:i}=El(e),{densityClasses:s}=Il(e),{roundedClasses:u}=yl(e),{sizeClasses:c,sizeStyles:d}=ea(e)
return Ke((()=>{var l
return t.createVNode(e.tag,{class:["v-avatar",{"v-avatar--start":e.start,"v-avatar--end":e.end},o.value,n.value,s.value,u.value,c.value,i.value],style:[r.value,d.value]},{default:()=>[e.image?t.createVNode(cl,{key:"image",src:e.image,alt:"",cover:!0},null):e.icon?t.createVNode(la,{key:"icon",icon:e.icon},null):null==(l=a.default)?void 0:l.call(a),$l(!1,"v-avatar")]})})),{}}}),_o=Symbol.for("vuetify:v-chip-group"),Io=je({name:"VChipGroup",props:{column:Boolean,filter:Boolean,valueComparator:{type:Function,default:v},...Tl({selectedClass:"v-chip--selected"}),...dl(),...pt(),...Al({variant:"tonal"})},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{isSelected:n,select:r,next:i,prev:s,selected:u}=Ol(e,_o)
return Me({VChip:{color:t.toRef(e,"color"),disabled:t.toRef(e,"disabled"),filter:t.toRef(e,"filter"),variant:t.toRef(e,"variant")}}),Ke((()=>{var l
return t.createVNode(e.tag,{class:["v-chip-group",{"v-chip-group--column":e.column},o.value]},{default:()=>[null==(l=a.default)?void 0:l.call(a,{isSelected:n,select:r,next:i,prev:s,selected:u.value})]})})),{}}}),Bo=je({name:"VChip",directives:{Ripple:wa},props:{activeClass:String,appendAvatar:String,appendIcon:Hl,closable:Boolean,closeIcon:{type:Hl,default:"$delete"},closeLabel:{type:String,default:"$vuetify.close"},draggable:Boolean,filter:Boolean,filterIcon:{type:String,default:"$complete"},label:Boolean,link:{type:Boolean,default:void 0},pill:Boolean,prependAvatar:String,prependIcon:Hl,ripple:{type:Boolean,default:!0},text:String,modelValue:{type:Boolean,default:!0},onClick:F,onClickOnce:F,...pl(),..._l(),...ml(),...Ll(),...hl(),...La(),...Ql(),...dl({tag:"span"}),...pt(),...Al({variant:"tonal"})},emits:{"click:close":e=>!0,"update:modelValue":e=>!0,"group:selected":e=>!0,click:e=>!0},setup(e,l){let{attrs:a,emit:o,slots:n}=l
const{borderClasses:r}=fl(e),{colorClasses:i,colorStyles:s,variantClasses:u}=El(e),{densityClasses:c}=Il(e),{elevationClasses:d}=gl(e),{roundedClasses:v}=yl(e),{sizeClasses:p}=ea(e),{themeClasses:f}=gt(e),m=Vt(e,"modelValue"),g=Pl(e,_o,!1),h=Ta(e,a),y=t.computed((()=>!1!==e.link&&h.isLink.value)),b=t.computed((()=>!e.disabled&&!1!==e.link&&(!!g||e.link||h.isClickable.value)))
function V(e){m.value=!1,o("click:close",e)}function S(e){var t
o("click",e),b.value&&(null==(t=h.navigate)||t.call(h,e),null==g||g.toggle())}function w(e){"Enter"!==e.key&&" "!==e.key||(e.preventDefault(),S(e))}return()=>{var l
const a=h.isLink.value?"a":e.tag,o=!!(n.append||e.appendIcon||e.appendAvatar),k=!(!n.close&&!e.closable),x=!(!n.filter&&!e.filter)&&g,C=!!(n.prepend||e.prependIcon||e.prependAvatar),N=!g||g.isSelected.value
return m.value&&t.withDirectives(t.createVNode(a,{class:["v-chip",{"v-chip--disabled":e.disabled,"v-chip--label":e.label,"v-chip--link":b.value,"v-chip--filter":x,"v-chip--pill":e.pill},f.value,r.value,N?i.value:void 0,c.value,d.value,v.value,p.value,u.value,null==g?void 0:g.selectedClass.value],style:[N?s.value:void 0],disabled:e.disabled||void 0,draggable:e.draggable,href:h.href.value,tabindex:b.value?0:void 0,onClick:S,onKeydown:b.value&&!y.value&&w},{default:()=>[$l(b.value,"v-chip"),x&&t.createVNode(Lt,{key:"filter",defaults:{VIcon:{icon:e.filterIcon}}},{default:()=>[t.createVNode(ll,null,{default:()=>[t.withDirectives(t.createVNode("div",{class:"v-chip__filter"},[n.filter?n.filter():t.createVNode(la,null,null)]),[[t.vShow,g.isSelected.value]])]})]}),C&&t.createVNode(Lt,{key:"prepend",defaults:{VAvatar:{image:e.prependAvatar},VIcon:{icon:e.prependIcon}}},{default:()=>[n.prepend?t.createVNode("div",{class:"v-chip__prepend"},[n.prepend()]):e.prependAvatar?t.createVNode(No,{start:!0},null):e.prependIcon?t.createVNode(la,{start:!0},null):void 0]}),(null==(l=n.default)?void 0:l.call(n,{isSelected:null==g?void 0:g.isSelected.value,selectedClass:null==g?void 0:g.selectedClass.value,select:null==g?void 0:g.select,toggle:null==g?void 0:g.toggle,value:null==g?void 0:g.value.value,disabled:e.disabled}))??e.text,o&&t.createVNode(Lt,{key:"append",defaults:{VAvatar:{image:e.appendAvatar},VIcon:{icon:e.appendIcon}}},{default:()=>[n.append?t.createVNode("div",{class:"v-chip__append"},[n.append()]):e.appendAvatar?t.createVNode(No,{end:!0},null):e.appendIcon?t.createVNode(la,{end:!0},null):void 0]}),k&&t.createVNode(Lt,{key:"close",defaults:{VIcon:{icon:e.closeIcon,size:"x-small"}}},{default:()=>[t.createVNode("div",{class:"v-chip__close",onClick:V},[n.close?n.close():t.createVNode(la,null,null)])]})]}),[[t.resolveDirective("ripple"),b.value&&e.ripple,null]])}}}),$o=je({name:"VDivider",props:{color:String,inset:Boolean,length:[Number,String],thickness:[Number,String],vertical:Boolean,...pt()},setup(e,l){let{attrs:a}=l
const{themeClasses:o}=gt(e),{textColorClasses:n,textColorStyles:r}=Vl(t.toRef(e,"color")),i=t.computed((()=>{const t={}
return e.length&&(t[e.vertical?"maxHeight":"maxWidth"]=g(e.length)),e.thickness&&(t[e.vertical?"borderRightWidth":"borderTopWidth"]=g(e.thickness)),t}))
return Ke((()=>t.createVNode("hr",{class:[{"v-divider":!0,"v-divider--inset":e.inset,"v-divider--vertical":e.vertical},o.value,n.value],style:[i.value,r.value],"aria-orientation":a.role&&"separator"!==a.role?void 0:e.vertical?"vertical":"horizontal",role:`${a.role||"separator"}`},null))),{}}}),Ao=Symbol.for("vuetify:list")
function Eo(){const e=t.inject(Ao,{hasPrepend:t.ref(!1),updateHasPrepend:()=>null}),l={hasPrepend:t.ref(!1),updateHasPrepend:e=>{e&&(l.hasPrepend.value=e)}}
return t.provide(Ao,l),e}function Ro(){return t.inject(Ao,null)}const To={open:e=>{let{id:t,value:l,opened:a,parents:o}=e
if(l){const e=new Set
e.add(t)
let l=o.get(t)
for(;null!=l;)e.add(l),l=o.get(l)
return e}return a.delete(t),a},select:()=>null},Lo={open:e=>{let{id:t,value:l,opened:a,parents:o}=e
if(l){let e=o.get(t)
for(a.add(t);null!=e&&e!==t;)a.add(e),e=o.get(e)
return a}return a.delete(t),a},select:()=>null},Po={open:Lo.open,select:e=>{let{id:t,value:l,opened:a,parents:o}=e
if(!l)return a
const n=[]
let r=o.get(t)
for(;null!=r;)n.push(r),r=o.get(r)
return new Set(n)}},Oo=e=>{const t={select:t=>{let{id:l,value:a,selected:o}=t
if(e&&!a){const e=Array.from(o.entries()).reduce(((e,t)=>{let[l,a]=t
return"on"===a?[...e,l]:e}),[])
if(1===e.length&&e[0]===l)return o}return o.set(l,a?"on":"off"),o},in:(e,l,a)=>{let o=new Map
for(const n of e||[])o=t.select({id:n,value:!0,selected:new Map(o),children:l,parents:a})
return o},out:e=>{const t=[]
for(const[l,a]of e.entries())"on"===a&&t.push(l)
return t}}
return t},Fo=e=>{const t=Oo(e)
return{select:e=>{let{selected:l,id:a,...o}=e
const n=l.has(a)?new Map([[a,l.get(a)]]):new Map
return t.select({...o,id:a,selected:n})},in:(e,l,a)=>{let o=new Map
return null!=e&&e.length&&(o=t.in(e.slice(0,1),l,a)),o},out:(e,l,a)=>t.out(e,l,a)}},Mo=Symbol.for("vuetify:nested"),zo={id:t.ref(),root:{register:()=>null,unregister:()=>null,parents:t.ref(new Map),children:t.ref(new Map),open:()=>null,openOnSelect:()=>null,select:()=>null,opened:t.ref(new Set),selected:t.ref(new Map),selectedValues:t.ref([])}},Do=De({selectStrategy:[String,Function],openStrategy:[String,Object],opened:Array,selected:Array,mandatory:Boolean},"nested"),jo=e=>{let l=!1
const a=t.ref(new Map),o=t.ref(new Map),n=Vt(e,"opened",e.opened,(e=>new Set(e)),(e=>[...e.values()])),r=t.computed((()=>{if("object"==typeof e.selectStrategy)return e.selectStrategy
switch(e.selectStrategy){case"single-leaf":return(e=>{const t=Fo(e)
return{select:e=>{let{id:l,selected:a,children:o,...n}=e
return o.has(l)?a:t.select({id:l,selected:a,children:o,...n})},in:t.in,out:t.out}})(e.mandatory)
case"leaf":return(e=>{const t=Oo(e)
return{select:e=>{let{id:l,selected:a,children:o,...n}=e
return o.has(l)?a:t.select({id:l,selected:a,children:o,...n})},in:t.in,out:t.out}})(e.mandatory)
case"independent":return Oo(e.mandatory)
case"single-independent":return Fo(e.mandatory)
case"classic":default:return(e=>{const t={select:t=>{let{id:l,value:a,selected:o,children:n,parents:r}=t
const i=new Map(o),s=[l]
for(;s.length;){const e=s.shift()
o.set(e,a?"on":"off"),n.has(e)&&s.push(...n.get(e))}let u=r.get(l)
for(;u;){const e=n.get(u),t=e.every((e=>"on"===o.get(e))),l=e.every((e=>!o.has(e)||"off"===o.get(e)))
o.set(u,t?"on":l?"off":"indeterminate"),u=r.get(u)}return e&&!a&&0===Array.from(o.entries()).reduce(((e,t)=>{let[l,a]=t
return"on"===a?[...e,l]:e}),[]).length?i:o},in:(e,l,a)=>{let o=new Map
for(const n of e||[])o=t.select({id:n,value:!0,selected:new Map(o),children:l,parents:a})
return o},out:(e,t)=>{const l=[]
for(const[a,o]of e.entries())"on"!==o||t.has(a)||l.push(a)
return l}}
return t})(e.mandatory)}})),i=t.computed((()=>{if("object"==typeof e.openStrategy)return e.openStrategy
switch(e.openStrategy){case"list":return Po
case"single":return To
case"multiple":default:return Lo}})),s=Vt(e,"selected",e.selected,(e=>r.value.in(e,a.value,o.value)),(e=>r.value.out(e,a.value,o.value)))
function u(e){const t=[]
let l=e
for(;null!=l;)t.unshift(l),l=o.value.get(l)
return t}t.onBeforeUnmount((()=>{l=!0}))
const c=Ae("nested"),d={id:t.ref(),root:{opened:n,selected:s,selectedValues:t.computed((()=>{const e=[]
for(const[t,l]of s.value.entries())"on"===l&&e.push(t)
return e})),register:(e,t,l)=>{t&&e!==t&&o.value.set(e,t),l&&a.value.set(e,[]),null!=t&&a.value.set(t,[...a.value.get(t)||[],e])},unregister:e=>{if(l)return
a.value.delete(e)
const t=o.value.get(e)
if(t){const l=a.value.get(t)??[]
a.value.set(t,l.filter((t=>t!==e)))}o.value.delete(e),n.value.delete(e)},open:(e,t,l)=>{c.emit("click:open",{id:e,value:t,path:u(e),event:l})
const r=i.value.open({id:e,value:t,opened:new Set(n.value),children:a.value,parents:o.value,event:l})
r&&(n.value=r)},openOnSelect:(e,t,l)=>{const r=i.value.select({id:e,value:t,selected:new Map(s.value),opened:new Set(n.value),children:a.value,parents:o.value,event:l})
r&&(n.value=r)},select:(e,t,l)=>{c.emit("click:select",{id:e,value:t,path:u(e),event:l})
const n=r.value.select({id:e,value:t,selected:new Map(s.value),children:a.value,parents:o.value,event:l})
n&&(s.value=n),d.root.openOnSelect(e,t,l)},children:a,parents:o}}
return t.provide(Mo,d),d.root},Ho=(e,l)=>{const a=t.inject(Mo,zo),o=t.computed((()=>e.value??Symbol(Le()))),n={...a,id:o,open:(e,t)=>a.root.open(o.value,e,t),openOnSelect:(e,t)=>a.root.openOnSelect(o.value,e,t),isOpen:t.computed((()=>a.root.opened.value.has(o.value))),parent:t.computed((()=>a.root.parents.value.get(o.value))),select:(e,t)=>a.root.select(o.value,e,t),isSelected:t.computed((()=>"on"===a.root.selected.value.get(o.value))),isIndeterminate:t.computed((()=>"indeterminate"===a.root.selected.value.get(o.value))),isLeaf:t.computed((()=>!a.root.children.value.get(o.value))),isGroupActivator:a.isGroupActivator}
return!a.isGroupActivator&&a.root.register(o.value,a.id.value,l),t.onBeforeUnmount((()=>{!a.isGroupActivator&&a.root.unregister(o.value)})),l&&t.provide(Mo,n),n},Wo=je({name:"VListGroupActivator",setup(e,l){let{slots:a}=l
return(()=>{const e=t.inject(Mo,zo)
t.provide(Mo,{...e,isGroupActivator:!0})})(),()=>{var e
return null==(e=a.default)?void 0:e.call(a)}}}),Uo=De({activeColor:String,color:String,collapseIcon:{type:Hl,default:"$collapse"},expandIcon:{type:Hl,default:"$expand"},prependIcon:Hl,appendIcon:Hl,fluid:Boolean,subgroup:Boolean,value:null,...dl()},"v-list-group"),Yo=He()({name:"VListGroup",props:{title:String,...Uo()},setup(e,l){let{slots:a}=l
const{isOpen:o,open:n,id:r}=Ho(t.toRef(e,"value"),!0),i=t.computed((()=>`v-list-group--id-${String(r.value)}`)),s=Ro()
function u(e){n(!o.value,e)}const c=t.computed((()=>({onClick:u,class:"v-list-group__header",id:i.value}))),d=t.computed((()=>o.value?e.collapseIcon:e.expandIcon))
return Ke((()=>{var l
return t.createVNode(e.tag,{class:["v-list-group",{"v-list-group--prepend":null==s?void 0:s.hasPrepend.value,"v-list-group--fluid":e.fluid,"v-list-group--subgroup":e.subgroup,"v-list-group--open":o.value}]},{default:()=>[a.activator&&t.createVNode(Lt,{defaults:{VListItem:{active:o.value,activeColor:e.activeColor,color:e.color,prependIcon:e.prependIcon||e.subgroup&&d.value,appendIcon:e.appendIcon||!e.subgroup&&d.value,title:e.title,value:e.value}}},{default:()=>[t.createVNode(Wo,null,{default:()=>[a.activator({props:c.value,isOpen:o})]})]}),t.createVNode(tl,null,{default:()=>[t.withDirectives(t.createVNode("div",{class:"v-list-group__items",role:"group","aria-labelledby":i.value},[null==(l=a.default)?void 0:l.call(a)]),[[t.vShow,o.value]])]})]})})),{}}})
const Xo=We("v-list-item-subtitle"),Go=We("v-list-item-title"),qo=He()({name:"VListItem",directives:{Ripple:wa},props:{active:{type:Boolean,default:void 0},activeClass:String,activeColor:String,appendAvatar:String,appendIcon:Hl,disabled:Boolean,lines:String,link:{type:Boolean,default:void 0},nav:Boolean,prependAvatar:String,prependIcon:Hl,ripple:{type:Boolean,default:!0},subtitle:[String,Number,Boolean],title:[String,Number,Boolean],value:null,onClick:F,onClickOnce:F,...pl(),..._l(),...al(),...ml(),...hl(),...La(),...dl(),...pt(),...Al({variant:"text"})},emits:{click:e=>!0},setup(e,l){let{attrs:a,slots:o,emit:n}=l
const r=Ta(e,a),i=t.computed((()=>e.value??r.href.value)),{select:s,isSelected:u,isIndeterminate:c,isGroupActivator:d,root:v,parent:p,openOnSelect:f}=Ho(i,!1),m=Ro(),g=t.computed((()=>{var t
return!1!==e.active&&(e.active||(null==(t=r.isActive)?void 0:t.value)||u.value)})),h=t.computed((()=>!1!==e.link&&r.isLink.value)),y=t.computed((()=>!e.disabled&&!1!==e.link&&(e.link||r.isClickable.value||null!=e.value&&!!m))),b=t.computed((()=>e.rounded||e.nav)),V=t.computed((()=>({color:g.value?e.activeColor??e.color:e.color,variant:e.variant})))
t.watch((()=>{var e
return null==(e=r.isActive)?void 0:e.value}),(e=>{e&&null!=p.value&&v.open(p.value,!0),e&&f(e)}),{immediate:!0})
const{themeClasses:S}=gt(e),{borderClasses:w}=fl(e),{colorClasses:k,colorStyles:x,variantClasses:C}=El(V),{densityClasses:N}=Il(e),{dimensionStyles:_}=ol(e),{elevationClasses:I}=gl(e),{roundedClasses:B}=yl(b),$=t.computed((()=>e.lines?`v-list-item--${e.lines}-line`:void 0)),A=t.computed((()=>({isActive:g.value,select:s,isSelected:u.value,isIndeterminate:c.value})))
function E(t){var l
n("click",t),!d&&y.value&&(null==(l=r.navigate)||l.call(r,t),null!=e.value&&s(!u.value,t))}function R(e){"Enter"!==e.key&&" "!==e.key||(e.preventDefault(),E(e))}return Ke((()=>{var l,a,n
const i=h.value?"a":e.tag,s=!m||u.value||g.value,c=o.title||e.title,d=o.subtitle||e.subtitle,v=!!(o.append||e.appendAvatar||e.appendIcon),p=!!(o.prepend||e.prependAvatar||e.prependIcon)
return null==m||m.updateHasPrepend(p),t.withDirectives(t.createVNode(i,{class:["v-list-item",{"v-list-item--active":g.value,"v-list-item--disabled":e.disabled,"v-list-item--link":y.value,"v-list-item--nav":e.nav,"v-list-item--prepend":!p&&(null==m?void 0:m.hasPrepend.value),[`${e.activeClass}`]:e.activeClass&&g.value},S.value,w.value,s?k.value:void 0,N.value,I.value,$.value,B.value,C.value],style:[s?x.value:void 0,_.value],href:r.href.value,tabindex:y.value?0:void 0,onClick:E,onKeydown:y.value&&!h.value&&R},{default:()=>[$l(y.value||g.value,"v-list-item"),p&&t.createVNode("div",{key:"prepend",class:"v-list-item__prepend"},[e.prependAvatar&&t.createVNode(No,{key:"prepend-avatar",density:e.density,image:e.prependAvatar},null),e.prependIcon&&t.createVNode(la,{key:"prepend-icon",density:e.density,icon:e.prependIcon},null),o.prepend&&t.createVNode(Lt,{key:"prepend",defaults:{VAvatar:{density:e.density,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon},VListItemAction:{start:!0}}},{default:()=>[o.prepend(A.value)]})]),t.createVNode("div",{class:"v-list-item__content","data-no-activator":""},[c&&t.createVNode(Go,{key:"title"},{default:()=>[(null==(l=o.title)?void 0:l.call(o,{title:e.title}))??e.title]}),d&&t.createVNode(Xo,{key:"subtitle"},{default:()=>[(null==(a=o.subtitle)?void 0:a.call(o,{subtitle:e.subtitle}))??e.subtitle]}),null==(n=o.default)?void 0:n.call(o,A.value)]),v&&t.createVNode("div",{key:"append",class:"v-list-item__append"},[o.append&&t.createVNode(Lt,{key:"append",defaults:{VAvatar:{density:e.density,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon},VListItemAction:{end:!0}}},{default:()=>[o.append(A.value)]}),e.appendIcon&&t.createVNode(la,{key:"append-icon",density:e.density,icon:e.appendIcon},null),e.appendAvatar&&t.createVNode(No,{key:"append-avatar",density:e.density,image:e.appendAvatar},null)])]}),[[t.resolveDirective("ripple"),y.value&&e.ripple]])})),{}}}),Ko=je({name:"VListSubheader",props:{color:String,inset:Boolean,sticky:Boolean,title:String,...dl()},setup(e,l){let{slots:a}=l
const{textColorClasses:o,textColorStyles:n}=Vl(t.toRef(e,"color"))
return Ke((()=>{var l
const r=!(!a.default&&!e.title)
return t.createVNode(e.tag,{class:["v-list-subheader",{"v-list-subheader--inset":e.inset,"v-list-subheader--sticky":e.sticky},o.value],style:{textColorStyles:n}},{default:()=>[r&&t.createVNode("div",{class:"v-list-subheader__text"},[(null==(l=a.default)?void 0:l.call(a))??e.title])]})})),{}}}),Zo=He()({name:"VListChildren",props:{items:Array},setup(e,l){let{slots:a}=l
return Eo(),()=>{var l,o
return(null==(l=a.default)?void 0:l.call(a))??(null==(o=e.items)?void 0:o.map((e=>{let{children:l,props:o,type:n,raw:r}=e
var i,s
if("divider"===n)return(null==(i=a.divider)?void 0:i.call(a,{props:o}))??t.createVNode($o,o,null)
if("subheader"===n)return(null==(s=a.subheader)?void 0:s.call(a,{props:o}))??t.createVNode(Ko,o,{default:a.subheader})
const u={subtitle:a.subtitle?e=>{var t
return null==(t=a.subtitle)?void 0:t.call(a,{...e,item:r})}:void 0,prepend:a.prepend?e=>{var t
return null==(t=a.prepend)?void 0:t.call(a,{...e,item:r})}:void 0,append:a.append?e=>{var t
return null==(t=a.append)?void 0:t.call(a,{...e,item:r})}:void 0,default:a.default?e=>{var t
return null==(t=a.default)?void 0:t.call(a,{...e,item:r})}:void 0,title:a.title?e=>{var t
return null==(t=a.title)?void 0:t.call(a,{...e,item:r})}:void 0},[c,d]=function(e){return S(e,Object.keys(Yo.props))}(o)
return l?t.createVNode(Yo,t.mergeProps({value:null==o?void 0:o.value},c),{activator:e=>{let{props:l}=e
return a.header?a.header({...o,...l}):t.createVNode(qo,t.mergeProps(o,l),u)},default:()=>t.createVNode(Zo,{items:l},a)}):a.item?a.item(o):t.createVNode(qo,o,u)})))}}}),Jo=De({items:{type:Array,default:()=>[]},itemTitle:{type:[String,Array,Function],default:"title"},itemValue:{type:[String,Array,Function],default:"value"},itemChildren:{type:[Boolean,String,Array,Function],default:"children"},itemProps:{type:[Boolean,String,Array,Function],default:"props"},returnObject:Boolean},"item")
function Qo(e,t){const l=f(t,e.itemTitle,t),a=e.returnObject?t:f(t,e.itemValue,l),o=f(t,e.itemChildren),n={title:l,value:a,...!0===e.itemProps?"object"!=typeof t||null==t||Array.isArray(t)?void 0:"children"in t?S(t,["children"])[1]:t:f(t,e.itemProps)}
return{title:String(n.title??""),value:n.value,props:n,children:Array.isArray(o)?en(e,o):void 0,raw:t}}function en(e,t){const l=[]
for(const a of t)l.push(Qo(e,a))
return l}function tn(e){return{items:t.computed((()=>en(e,e.items))),transformIn:function(t){return t.map((t=>Qo(e,t)))},transformOut:function(e){return e.map((e=>{let{props:t}=e
return t.value}))}}}function ln(e,t){const l=f(t,e.itemType,"item"),a=function(e){return"string"==typeof e||"number"==typeof e||"boolean"==typeof e}(t)?t:f(t,e.itemTitle),o=f(t,e.itemValue,void 0),n=f(t,e.itemChildren),r={title:a,value:o,...!0===e.itemProps?S(t,["children"])[1]:f(t,e.itemProps)}
return{type:l,title:r.title,value:r.value,props:r,children:"item"===l&&n?an(e,n):void 0,raw:t}}function an(e,t){const l=[]
for(const a of t)l.push(ln(e,a))
return l}const on=He()({name:"VList",props:{activeColor:String,activeClass:String,bgColor:String,disabled:Boolean,lines:{type:[Boolean,String],default:"one"},nav:Boolean,...Do({selectStrategy:"single-leaf",openStrategy:"list"}),...pl(),..._l(),...al(),...ml(),itemType:{type:String,default:"type"},...Jo(),...hl(),...dl(),...pt(),...Al({variant:"text"})},emits:{"update:selected":e=>!0,"update:opened":e=>!0,"click:open":e=>!0,"click:select":e=>!0},setup(e,l){let{slots:a}=l
const{items:o}=function(e){return{items:t.computed((()=>an(e,e.items)))}}(e),{themeClasses:n}=gt(e),{backgroundColorClasses:r,backgroundColorStyles:i}=Sl(t.toRef(e,"bgColor")),{borderClasses:s}=fl(e),{densityClasses:u}=Il(e),{dimensionStyles:c}=ol(e),{elevationClasses:d}=gl(e),{roundedClasses:v}=yl(e),{open:p,select:f}=jo(e),m=t.computed((()=>e.lines?`v-list--${e.lines}-line`:void 0)),g=t.toRef(e,"activeColor"),h=t.toRef(e,"color")
Eo(),Me({VListGroup:{activeColor:g,color:h},VListItem:{activeClass:t.toRef(e,"activeClass"),activeColor:g,color:h,density:t.toRef(e,"density"),disabled:t.toRef(e,"disabled"),lines:t.toRef(e,"lines"),nav:t.toRef(e,"nav"),variant:t.toRef(e,"variant")}})
const y=t.ref(!1),b=t.ref()
function V(e){y.value=!0}function S(e){y.value=!1}function w(e){var t
y.value||e.relatedTarget&&null!=(t=b.value)&&t.contains(e.relatedTarget)||x()}function k(e){if(b.value){if("ArrowDown"===e.key)x("next")
else if("ArrowUp"===e.key)x("prev")
else if("Home"===e.key)x("first")
else{if("End"!==e.key)return
x("last")}e.preventDefault()}}function x(e){if(!b.value)return
const t=[...b.value.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')].filter((e=>!e.hasAttribute("disabled"))),l=t.indexOf(document.activeElement)
var a
if(e)if("first"===e){var o
null==(o=t[0])||o.focus()}else if("last"===e){var n
null==(n=t.at(-1))||n.focus()}else{let a,o=l
const n="next"===e?1:-1
do{o+=n,a=t[o]}while((!a||null==a.offsetParent)&&o<t.length&&o>=0)
a?a.focus():x("next"===e?"first":"last")}else b.value.contains(document.activeElement)||null==(a=t[0])||a.focus()}return Ke((()=>t.createVNode(e.tag,{ref:b,class:["v-list",{"v-list--disabled":e.disabled,"v-list--nav":e.nav},n.value,r.value,s.value,u.value,d.value,m.value,v.value],style:[i.value,c.value],role:"listbox","aria-activedescendant":void 0,onFocusin:V,onFocusout:S,onFocus:w,onKeydown:k},{default:()=>[t.createVNode(Zo,{items:o.value},a)]}))),{open:p,select:f,focus:x}}}),nn=We("v-list-img"),rn=je({name:"VListItemAction",props:{start:Boolean,end:Boolean,...dl()},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(e.tag,{class:["v-list-item-action",{"v-list-item-action--start":e.start,"v-list-item-action--end":e.end}]},a))),{}}}),sn=je({name:"VListItemMedia",props:{start:Boolean,end:Boolean,...dl()},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(e.tag,{class:["v-list-item-media",{"v-list-item-media--start":e.start,"v-list-item-media--end":e.end}]},a))),{}}}),un=De({closeDelay:[Number,String],openDelay:[Number,String]},"delay")
function cn(e,t){const a={},o=o=>()=>{if(!l)return Promise.resolve(!0)
const n="openDelay"===o
return a.closeDelay&&window.clearTimeout(a.closeDelay),delete a.closeDelay,a.openDelay&&window.clearTimeout(a.openDelay),delete a.openDelay,new Promise((l=>{const r=parseInt(e[o]??0,10)
a[o]=window.setTimeout((()=>{null==t||t(n),l(n)}),r)}))}
return{runCloseDelay:o("closeDelay"),runOpenDelay:o("openDelay")}}const dn=Symbol.for("vuetify:v-menu"),vn=De({activator:[String,Object],activatorProps:{type:Object,default:()=>({})},openOnClick:{type:Boolean,default:void 0},openOnHover:Boolean,openOnFocus:{type:Boolean,default:void 0},closeOnContentClick:Boolean,...un()},"v-overlay-activator")
function pn(e,a){let{isActive:o,isTop:r}=a
const i=t.ref()
let s=!1,u=!1,c=!0
const d=t.computed((()=>e.openOnFocus||null==e.openOnFocus&&e.openOnHover)),v=t.computed((()=>e.openOnClick||null==e.openOnClick&&!e.openOnHover&&!d.value)),{runOpenDelay:p,runCloseDelay:f}=cn(e,(t=>{t!==(e.openOnHover&&s||d.value&&u)||e.openOnHover&&o.value&&!r.value||(o.value!==t&&(c=!0),o.value=t)})),m=e=>{e.stopPropagation(),i.value=e.currentTarget||e.target,o.value=!o.value},g=e=>{s=!0,i.value=e.currentTarget||e.target,p()},h=e=>{s=!1,f()},y=e=>{n&&!e.target.matches(":focus-visible")||(u=!0,e.stopPropagation(),i.value=e.currentTarget||e.target,p())},b=e=>{u=!1,e.stopPropagation(),f()},V=t.computed((()=>{const t={}
return v.value&&(t.click=m),e.openOnHover&&(t.mouseenter=g,t.mouseleave=h),d.value&&(t.focus=y,t.blur=b),t})),S=t.computed((()=>{const l={}
if(e.openOnHover&&(l.mouseenter=()=>{s=!0,p()},l.mouseleave=()=>{s=!1,f()}),e.closeOnContentClick){const e=t.inject(dn,null)
l.click=()=>{o.value=!1,null==e||e.closeParents()}}return l})),w=t.computed((()=>{const t={}
return e.openOnHover&&(t.mouseenter=()=>{c&&(s=!0,c=!1,p())},t.mouseleave=()=>{s=!1,f()}),t}))
t.watch(r,(t=>{!t||(!e.openOnHover||s||d.value&&u)&&(!d.value||u||e.openOnHover&&s)||(o.value=!1)}))
const k=t.ref()
t.watchEffect((()=>{k.value&&t.nextTick((()=>{const e=k.value
var t
i.value=(null==(t=e)?void 0:t.$el)?e.$el:e}))}))
const x=Ae("useActivator")
let C
return t.watch((()=>!!e.activator),(a=>{a&&l?(C=t.effectScope(),C.run((()=>{!function(e,l,a){let{activatorEl:o,activatorEvents:n}=a
function r(){let t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:s(),l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:e.activatorProps
t&&(Object.entries(n.value).forEach((e=>{let[l,a]=e
t.addEventListener(l,a)})),Object.keys(l).forEach((e=>{null==l[e]?t.removeAttribute(e):t.setAttribute(e,l[e])})))}function i(){let t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:s(),l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:e.activatorProps
t&&(Object.entries(n.value).forEach((e=>{let[l,a]=e
t.removeEventListener(l,a)})),Object.keys(l).forEach((e=>{t.removeAttribute(e)})))}function s(){var t
let a,n=arguments.length>0&&void 0!==arguments[0]?arguments[0]:e.activator
if(n)if("parent"===n){var r,i
let e=null==l||null==(r=l.proxy)||null==(i=r.$el)?void 0:i.parentNode
for(;e.hasAttribute("data-no-activator");)e=e.parentNode
a=e}else a="string"==typeof n?document.querySelector(n):"$el"in n?n.$el:n
return o.value=(null==(t=a)?void 0:t.nodeType)===Node.ELEMENT_NODE?a:null,o.value}t.watch((()=>e.activator),((e,l)=>{if(l&&e!==l){const e=s(l)
e&&i(e)}e&&t.nextTick((()=>r()))}),{immediate:!0}),t.watch((()=>e.activatorProps),(()=>{r()})),t.onScopeDispose((()=>{i()}))}(e,x,{activatorEl:i,activatorEvents:V})}))):C&&C.stop()}),{flush:"post",immediate:!0}),t.onScopeDispose((()=>{var e
null==(e=C)||e.stop()})),{activatorEl:i,activatorRef:k,activatorEvents:V,contentEvents:S,scrimEvents:w}}const fn=De({eager:Boolean},"lazy")
function mn(e,l){const a=t.ref(!1),o=t.computed((()=>a.value||e.eager||l.value))
return t.watch(l,(()=>a.value=!0)),{isBooted:a,hasContent:o,onAfterLeave:function(){e.eager||(a.value=!1)}}}function gn(e,t){return{x:e.x+t.x,y:e.y+t.y}}function hn(e,t){if("top"===e.side||"bottom"===e.side){const{side:l,align:a}=e
return gn({x:"left"===a?0:"center"===a?t.width/2:"right"===a?t.width:a,y:"top"===l?0:"bottom"===l?t.height:l},t)}if("left"===e.side||"right"===e.side){const{side:l,align:a}=e
return gn({x:"left"===l?0:"right"===l?t.width:l,y:"top"===a?0:"center"===a?t.height/2:"bottom"===a?t.height:a},t)}return gn({x:t.width/2,y:t.height/2},t)}const yn={static:function(){},connected:function(e,l,a){(function(e){for(;e;){if("fixed"===window.getComputedStyle(e).position)return!0
e=e.offsetParent}return!1})(e.activatorEl.value)&&Object.assign(a.value,{position:"fixed"})
const{preferredAnchor:o,preferredOrigin:n}=T((()=>{const t=H(l.location,e.isRtl.value),a="overlap"===l.origin?t:"auto"===l.origin?U(t):H(l.origin,e.isRtl.value)
return t.side===a.side&&t.align===Y(a).align?{preferredAnchor:X(t),preferredOrigin:X(a)}:{preferredAnchor:t,preferredOrigin:a}})),[r,i,s,u]=["minWidth","minHeight","maxWidth","maxHeight"].map((e=>t.computed((()=>{const t=parseFloat(l[e])
return isNaN(t)?1/0:t})))),c=t.computed((()=>{if(Array.isArray(l.offset))return l.offset
if("string"==typeof l.offset){const e=l.offset.split(" ").map(parseFloat)
return e.length<2&&e.push(0),e}return"number"==typeof l.offset?[l.offset,0]:[0,0]}))
let d=!1
const v=new ResizeObserver((()=>{d&&p()}))
function p(){if(d=!1,requestAnimationFrame((()=>{requestAnimationFrame((()=>d=!0))})),!e.activatorEl.value||!e.contentEl.value)return
const t=e.activatorEl.value.getBoundingClientRect(),l=function(e){const t=Z(e)
return t.x-=parseFloat(e.style.left||0),t.y-=parseFloat(e.style.top||0),t}(e.contentEl.value),v=Ge(e.contentEl.value)
v.length||(v.push(document.documentElement),e.contentEl.value.style.top&&e.contentEl.value.style.left||(l.x+=parseFloat(document.documentElement.style.getPropertyValue("--v-body-scroll-x")||0),l.y+=parseFloat(document.documentElement.style.getPropertyValue("--v-body-scroll-y")||0)))
const p=v.reduce(((e,t)=>{const l=t.getBoundingClientRect(),a=new q({x:t===document.documentElement?0:l.x,y:t===document.documentElement?0:l.y,width:t.clientWidth,height:t.clientHeight})
return e?new q({x:Math.max(e.left,a.left),y:Math.max(e.top,a.top),width:Math.min(e.right,a.right)-Math.max(e.left,a.left),height:Math.min(e.bottom,a.bottom)-Math.max(e.top,a.top)}):a}),void 0)
p.x+=12,p.y+=12,p.width-=24,p.height-=24
let f={anchor:o.value,origin:n.value}
function m(e){const a=new q(l),o=hn(e.anchor,t),n=hn(e.origin,a)
let{x:r,y:i}=(v=n,{x:(d=o).x-v.x,y:d.y-v.y})
var d,v
switch(e.anchor.side){case"top":i-=c.value[0]
break
case"bottom":i+=c.value[0]
break
case"left":r-=c.value[0]
break
case"right":r+=c.value[0]}switch(e.anchor.align){case"top":i-=c.value[1]
break
case"bottom":i+=c.value[1]
break
case"left":r-=c.value[1]
break
case"right":r+=c.value[1]}a.x+=r,a.y+=i,a.width=Math.min(a.width,s.value),a.height=Math.min(a.height,u.value)
return{overflows:K(a,p),x:r,y:i}}let h=0,y=0
const b={x:0,y:0},V={x:!1,y:!1}
let S=-1
for(;;){if(S++>10){te("Infinite loop detected in connectedLocationStrategy")
break}const{x:e,y:t,overflows:a}=m(f)
h+=e,y+=t,l.x+=e,l.y+=t
{const e=G(f.anchor),t=a.x.before||a.x.after,l=a.y.before||a.y.after
let o=!1
if(["x","y"].forEach((n=>{if("x"===n&&t&&!V.x||"y"===n&&l&&!V.y){const t={anchor:{...f.anchor},origin:{...f.origin}},l="x"===n?"y"===e?Y:U:"y"===e?U:Y
t.anchor=l(t.anchor),t.origin=l(t.origin)
const{overflows:r}=m(t);(r[n].before<=a[n].before&&r[n].after<=a[n].after||r[n].before+r[n].after<(a[n].before+a[n].after)/2)&&(f=t,o=V[n]=!0)}})),o)continue}a.x.before&&(h+=a.x.before,l.x+=a.x.before),a.x.after&&(h-=a.x.after,l.x-=a.x.after),a.y.before&&(y+=a.y.before,l.y+=a.y.before),a.y.after&&(y-=a.y.after,l.y-=a.y.after)
{const e=K(l,p)
b.x=p.width-e.x.before-e.x.after,b.y=p.height-e.y.before-e.y.after,h+=e.x.before,l.x+=e.x.before,y+=e.y.before,l.y+=e.y.before}break}const w=G(f.anchor)
return Object.assign(a.value,{"--v-overlay-anchor-origin":`${f.anchor.side} ${f.anchor.align}`,transformOrigin:`${f.origin.side} ${f.origin.align}`,top:g(Vn(y)),left:g(Vn(h)),minWidth:g("y"===w?Math.min(r.value,t.width):r.value),maxWidth:g(Sn(C(b.x,r.value===1/0?0:r.value,s.value))),maxHeight:g(Sn(C(b.y,i.value===1/0?0:i.value,u.value)))}),{available:b,contentBox:l}}return t.watch([e.activatorEl,e.contentEl],((e,t)=>{let[l,a]=e,[o,n]=t
o&&v.unobserve(o),l&&v.observe(l),n&&v.unobserve(n),a&&v.observe(a)}),{immediate:!0}),t.onScopeDispose((()=>{v.disconnect()})),t.watch((()=>[o.value,n.value,l.offset,l.minWidth,l.minHeight,l.maxWidth,l.maxHeight]),(()=>p())),t.nextTick((()=>{const e=p()
if(!e)return
const{available:t,contentBox:l}=e
l.height>t.y&&requestAnimationFrame((()=>{p(),requestAnimationFrame((()=>{p()}))}))})),{updateLocation:p}}},bn=De({locationStrategy:{type:[String,Function],default:"static",validator:e=>"function"==typeof e||e in yn},location:{type:String,default:"bottom"},origin:{type:String,default:"auto"},offset:[Number,String,Array]},"v-overlay-location-strategies")
function Vn(e){return Math.round(e*devicePixelRatio)/devicePixelRatio}function Sn(e){return Math.ceil(e*devicePixelRatio)/devicePixelRatio}let wn=!0
const kn=[]
let xn=-1
function Cn(){cancelAnimationFrame(xn),xn=requestAnimationFrame((()=>{const e=kn.shift()
e&&e(),kn.length?Cn():wn=!0}))}const Nn={none:null,close:function(e){In(e.activatorEl.value??e.contentEl.value,(function(t){e.isActive.value=!1}))},block:function(e,l){var a
const o=null==(a=e.root.value)?void 0:a.offsetParent,n=[...new Set([...Ge(e.activatorEl.value,l.contained?o:void 0),...Ge(e.contentEl.value,l.contained?o:void 0)])].filter((e=>!e.classList.contains("v-overlay-scroll-blocked"))),r=window.innerWidth-document.documentElement.offsetWidth,i=(s=o||document.documentElement,qe(s)&&s)
var s
i&&e.root.value.classList.add("v-overlay--scroll-blocked")
n.forEach(((e,t)=>{e.style.setProperty("--v-body-scroll-x",g(-e.scrollLeft)),e.style.setProperty("--v-body-scroll-y",g(-e.scrollTop)),e.style.setProperty("--v-scrollbar-offset",g(r)),e.classList.add("v-overlay-scroll-blocked")})),t.onScopeDispose((()=>{n.forEach(((e,t)=>{const l=parseFloat(e.style.getPropertyValue("--v-body-scroll-x")),a=parseFloat(e.style.getPropertyValue("--v-body-scroll-y"))
e.style.removeProperty("--v-body-scroll-x"),e.style.removeProperty("--v-body-scroll-y"),e.style.removeProperty("--v-scrollbar-offset"),e.classList.remove("v-overlay-scroll-blocked"),e.scrollLeft=-l,e.scrollTop=-a})),i&&e.root.value.classList.remove("v-overlay--scroll-blocked")}))},reposition:function(e,l,a){let o=!1,n=-1,r=-1
function i(t){var l
l=()=>{var l,a
const n=performance.now()
null==(l=(a=e.updateLocation).value)||l.call(a,t)
const r=performance.now()-n
o=r/(1e3/60)>2},!wn||kn.length?(kn.push(l),Cn()):(wn=!1,l(),Cn())}r=requestIdleCallback((()=>{a.run((()=>{In(e.activatorEl.value??e.contentEl.value,(e=>{o?(cancelAnimationFrame(n),n=requestAnimationFrame((()=>{n=requestAnimationFrame((()=>{i(e)}))}))):i(e)}))}))})),t.onScopeDispose((()=>{cancelIdleCallback(r),cancelAnimationFrame(n)}))}},_n=De({scrollStrategy:{type:[String,Function],default:"block",validator:e=>"function"==typeof e||e in Nn}},"v-overlay-scroll-strategies")
function In(e,l){const a=[document,...Ge(e)]
a.forEach((e=>{e.addEventListener("scroll",l,{passive:!0})})),t.onScopeDispose((()=>{a.forEach((e=>{e.removeEventListener("scroll",l)}))}))}const Bn=Symbol.for("vuetify:display"),$n={mobileBreakpoint:"lg",thresholds:{xs:0,sm:600,md:960,lg:1280,xl:1920,xxl:2560}}
function An(e){return l&&!e?window.innerWidth:0}function En(e){return l&&!e?window.innerHeight:0}function Rn(e,a){const{thresholds:n,mobileBreakpoint:r}=function(){return I($n,arguments.length>0&&void 0!==arguments[0]?arguments[0]:$n)}(e),i=t.ref(En(a)),s=function(){const e=l?window.navigator.userAgent:"ssr"
function t(t){return Boolean(e.match(t))}const a=t(/android/i),n=t(/iphone|ipad|ipod/i),r=t(/cordova/i),i=t(/electron/i),s=t(/chrome/i),u=t(/edge/i),c=t(/firefox/i),d=t(/opera/i),v=t(/win/i),p=t(/mac/i),f=t(/linux/i),m=t(/ssr/i)
return{android:a,ios:n,cordova:r,electron:i,chrome:s,edge:u,firefox:c,opera:d,win:v,mac:p,linux:f,touch:o,ssr:m}}(),u=t.reactive({}),c=t.ref(An(a))
function d(){i.value=En(),c.value=An()}return t.watchEffect((()=>{const e=c.value<n.sm,t=c.value<n.md&&!e,l=c.value<n.lg&&!(t||e),a=c.value<n.xl&&!(l||t||e),o=c.value<n.xxl&&!(a||l||t||e),d=c.value>=n.xxl,v=e?"xs":t?"sm":l?"md":a?"lg":o?"xl":"xxl",p="number"==typeof r?r:n[r],f=s.ssr?s.android||s.ios||s.opera:c.value<p
u.xs=e,u.sm=t,u.md=l,u.lg=a,u.xl=o,u.xxl=d,u.smAndUp=!e,u.mdAndUp=!(e||t),u.lgAndUp=!(e||t||l),u.xlAndUp=!(e||t||l||a),u.smAndDown=!(l||a||o||d),u.mdAndDown=!(a||o||d),u.lgAndDown=!(o||d),u.xlAndDown=!d,u.name=v,u.height=i.value,u.width=c.value,u.mobile=f,u.mobileBreakpoint=r,u.platform=s,u.thresholds=n})),l&&window.addEventListener("resize",d,{passive:!0}),{...t.toRefs(u),update:d,ssr:!!a}}function Tn(){const e=t.inject(Bn)
if(!e)throw new Error("Could not find Vuetify display injection")
return e}function Ln(){if(!l)return t.ref(!1)
const{ssr:e}=Tn()
if(e){const e=t.ref(!1)
return t.onMounted((()=>{e.value=!0})),e}return t.ref(!0)}function Pn(){const e=Ae("useScopeId").vnode.scopeId
return{scopeId:e?{[e]:""}:void 0}}const On=Symbol.for("vuetify:stack"),Fn=t.reactive([])
function Mn(){return!0}function zn(e,t,l){if(!e||!1===Dn(e,l))return!1
const a=Ue(t)
if("undefined"!=typeof ShadowRoot&&a instanceof ShadowRoot&&a.host===e.target)return!1
const o=("object"==typeof l.value&&l.value.include||(()=>[]))()
return o.push(t),!o.some((t=>null==t?void 0:t.contains(e.target)))}function Dn(e,t){return("object"==typeof t.value&&t.value.closeConditional||Mn)(e)}function jn(e,t){const l=Ue(e)
t(document),"undefined"!=typeof ShadowRoot&&l instanceof ShadowRoot&&t(l)}const Hn={mounted(e,t){const l=l=>function(e,t,l){const a="function"==typeof l.value?l.value:l.value.handler
t._clickOutside.lastMousedownWasOutside&&zn(e,t,l)&&setTimeout((()=>{Dn(e,l)&&a&&a(e)}),0)}(l,e,t),a=l=>{e._clickOutside.lastMousedownWasOutside=zn(l,e,t)}
jn(e,(e=>{e.addEventListener("click",l,!0),e.addEventListener("mousedown",a,!0)})),e._clickOutside||(e._clickOutside={lastMousedownWasOutside:!0}),e._clickOutside[t.instance.$.uid]={onClick:l,onMousedown:a}},unmounted(e,t){e._clickOutside&&(jn(e,(l=>{var a
if(!l||null==(a=e._clickOutside)||!a[t.instance.$.uid])return
const{onClick:o,onMousedown:n}=e._clickOutside[t.instance.$.uid]
l.removeEventListener("click",o,!0),l.removeEventListener("mousedown",n,!0)})),delete e._clickOutside[t.instance.$.uid])}}
function Wn(e){const{modelValue:l,color:a,...o}=e
return t.createVNode(t.Transition,{name:"fade-transition",appear:!0},{default:()=>[e.modelValue&&t.createVNode("div",t.mergeProps({class:["v-overlay__scrim",e.color.backgroundColorClasses.value],style:e.color.backgroundColorStyles.value},o),null)]})}const Un=De({absolute:Boolean,attach:[Boolean,String,Object],closeOnBack:{type:Boolean,default:!0},contained:Boolean,contentClass:null,contentProps:null,disabled:Boolean,noClickAnimation:Boolean,modelValue:Boolean,persistent:Boolean,scrim:{type:[String,Boolean],default:!0},zIndex:{type:[Number,String],default:2e3},...vn(),...al(),...fn(),...bn(),..._n(),...pt(),...sl()},"v-overlay"),Yn=He()({name:"VOverlay",directives:{ClickOutside:Hn},inheritAttrs:!1,props:{_disableGlobalStack:Boolean,...Un()},emits:{"click:outside":e=>!0,"update:modelValue":e=>!0,afterLeave:()=>!0},setup(e,a){let{slots:o,attrs:n,emit:r}=a
const i=Vt(e,"modelValue"),s=t.computed({get:()=>i.value,set:t=>{t&&e.disabled||(i.value=t)}}),{teleportTarget:u}=(c=t.computed((()=>e.attach||e.contained)),{teleportTarget:t.computed((()=>{const e=c.value
if(!0===e||!l)return
const a=!1===e?document.body:"string"==typeof e?document.querySelector(e):e
if(null==a)return void t.warn(`Unable to locate target ${e}`)
let o=a.querySelector(".v-overlay-container")
return o||(o=document.createElement("div"),o.className="v-overlay-container",a.appendChild(o)),o}))})
var c
const{themeClasses:d}=gt(e),{rtlClasses:v,isRtl:p}=Rt(),{hasContent:f,onAfterLeave:m}=mn(e,s),h=Sl(t.computed((()=>"string"==typeof e.scrim?e.scrim:null))),{globalTop:y,localTop:b,stackStyles:V}=function(e,l,a){const o=Ae("useStack"),n=!a,r=t.inject(On,void 0),i=t.reactive({activeChildren:new Set})
t.provide(On,i)
const s=t.ref(+l.value)
ze(e,(()=>{var e
const a=null==(e=Fn.at(-1))?void 0:e[1]
s.value=a?a+10:+l.value,n&&Fn.push([o.uid,s.value]),null==r||r.activeChildren.add(o.uid),t.onScopeDispose((()=>{if(n){const e=Fn.findIndex((e=>e[0]===o.uid))
Fn.splice(e,1)}null==r||r.activeChildren.delete(o.uid)}))}))
const u=t.ref(!0)
n&&t.watchEffect((()=>{var e
const t=(null==(e=Fn.at(-1))?void 0:e[0])===o.uid
setTimeout((()=>u.value=t))}))
const c=t.computed((()=>!i.activeChildren.size))
return{globalTop:t.readonly(u),localTop:c,stackStyles:t.computed((()=>({zIndex:s.value})))}}(s,t.toRef(e,"zIndex"),e._disableGlobalStack),{activatorEl:S,activatorRef:w,activatorEvents:k,contentEvents:x,scrimEvents:C}=pn(e,{isActive:s,isTop:b}),{dimensionStyles:N}=ol(e),_=Ln(),{scopeId:I}=Pn()
t.watch((()=>e.disabled),(e=>{e&&(s.value=!1)}))
const B=t.ref(),$=t.ref(),{contentStyles:A,updateLocation:E}=function(e,a){const o=t.ref({}),n=t.ref()
function r(e){var t
null==(t=n.value)||t.call(n,e)}return l&&(ze((()=>!(!a.isActive.value||!e.locationStrategy)),(l=>{var r,i
t.watch((()=>e.locationStrategy),l),t.onScopeDispose((()=>{n.value=void 0})),"function"==typeof e.locationStrategy?n.value=null==(r=e.locationStrategy(a,e,o))?void 0:r.updateLocation:n.value=null==(i=yn[e.locationStrategy](a,e,o))?void 0:i.updateLocation})),window.addEventListener("resize",r,{passive:!0}),t.onScopeDispose((()=>{window.removeEventListener("resize",r),n.value=void 0}))),{contentStyles:o,updateLocation:n}}(e,{isRtl:p,contentEl:$,activatorEl:S,isActive:s})
function R(t){r("click:outside",t),e.persistent?F():s.value=!1}function T(){return s.value&&y.value}function L(t){"Escape"===t.key&&y.value&&(e.persistent?F():s.value=!1)}!function(e,a){if(!l)return
let o
t.watchEffect((async()=>{var l
null==(l=o)||l.stop(),a.isActive.value&&e.scrollStrategy&&(o=t.effectScope(),await t.nextTick(),o.run((()=>{var t
"function"==typeof e.scrollStrategy?e.scrollStrategy(a,e,o):null==(t=Nn[e.scrollStrategy])||t.call(Nn,a,e,o)})))})),t.onScopeDispose((()=>{var e
null==(e=o)||e.stop()}))}(e,{root:B,contentEl:$,activatorEl:S,isActive:s,updateLocation:E}),l&&t.watch(s,(e=>{e?window.addEventListener("keydown",L):window.removeEventListener("keydown",L)}),{immediate:!0})
const P=Ra()
ze((()=>e.closeOnBack),(()=>{!function(e,a){let o,n,r=!1
function i(e){var t
null!=(t=e.state)&&t.replaced||(r=!0,setTimeout((()=>r=!1)))}l&&(t.nextTick((()=>{window.addEventListener("popstate",i),o=null==e?void 0:e.beforeEach(((e,t,l)=>{Pa?r?a(l):l():setTimeout((()=>r?a(l):l())),Pa=!0})),n=null==e?void 0:e.afterEach((()=>{Pa=!1}))})),t.onScopeDispose((()=>{var e,t
window.removeEventListener("popstate",i),null==(e=o)||e(),null==(t=n)||t()})))}(P,(t=>{y.value&&s.value?(t(!1),e.persistent?F():s.value=!1):t()}))}))
const O=t.ref()
function F(){e.noClickAnimation||$.value&&J($.value,[{transformOrigin:"center"},{transform:"scale(1.03)"},{transformOrigin:"center"}],{duration:150,easing:Ye})}return t.watch((()=>s.value&&(e.absolute||e.contained)&&null==u.value),(e=>{if(e){const e=Xe(B.value)
e&&e!==document.scrollingElement&&(O.value=e.scrollTop)}})),Ke((()=>{var l,a
return t.createVNode(t.Fragment,null,[null==(l=o.activator)?void 0:l.call(o,{isActive:s.value,props:t.mergeProps({ref:w},t.toHandlers(k.value),e.activatorProps)}),_.value&&t.createVNode(t.Teleport,{disabled:!u.value,to:u.value},{default:()=>[f.value&&t.createVNode("div",t.mergeProps({class:["v-overlay",{"v-overlay--absolute":e.absolute||e.contained,"v-overlay--active":s.value,"v-overlay--contained":e.contained},d.value,v.value],style:[V.value,{top:g(O.value)}],ref:B},I,n),[t.createVNode(Wn,t.mergeProps({color:h,modelValue:s.value&&!!e.scrim},t.toHandlers(C.value)),null),t.createVNode(ul,{appear:!0,persisted:!0,transition:e.transition,target:S.value,onAfterLeave:()=>{m(),r("afterLeave")}},{default:()=>[t.withDirectives(t.createVNode("div",t.mergeProps({ref:$,class:["v-overlay__content",e.contentClass],style:[N.value,A.value]},t.toHandlers(x.value),e.contentProps),[null==(a=o.default)?void 0:a.call(o,{isActive:s})]),[[t.vShow,s.value],[t.resolveDirective("click-outside"),{handler:R,closeConditional:T,include:()=>[S.value]}]])]})])]})])})),{activatorEl:S,animateClick:F,contentEl:$,globalTop:y,localTop:b,updateLocation:E}}})
function Xn(e){return S(e,Object.keys(Yn.props))}const Gn=He()({name:"VMenu",props:{id:String,...w(Un({closeDelay:250,closeOnContentClick:!0,locationStrategy:"connected",openDelay:300,scrim:!1,scrollStrategy:"reposition",transition:{component:Mt}}),["absolute"])},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),{scopeId:n}=Pn(),r=Le(),i=t.computed((()=>e.id||`v-menu-${r}`)),s=t.ref(),u=t.inject(dn,null)
let c=0
function d(){null==u||u.closeParents()}t.provide(dn,{register(){++c},unregister(){--c},closeParents(){setTimeout((()=>{c||(o.value=!1,null==u||u.closeParents())}),40)}}),t.watch(o,(e=>{e?null==u||u.register():null==u||u.unregister()}))
const v=t.computed((()=>t.mergeProps({"aria-haspopup":"menu","aria-expanded":String(o.value),"aria-owns":i.value},e.activatorProps)))
return Ke((()=>{const[l]=Xn(e)
return t.createVNode(Yn,t.mergeProps({ref:s,class:["v-menu"]},l,{modelValue:o.value,"onUpdate:modelValue":e=>o.value=e,absolute:!0,activatorProps:v.value,"onClick:outside":d},n),{activator:a.activator,default:function(){for(var e,l=arguments.length,o=new Array(l),n=0;n<l;n++)o[n]=arguments[n]
return t.createVNode(Lt,{root:!0},{default:()=>[null==(e=a.default)?void 0:e.call(a,...o)]})}})})),co({id:i},s)}}),qn=De({chips:Boolean,closableChips:Boolean,eager:Boolean,hideNoData:Boolean,hideSelected:Boolean,menu:Boolean,menuIcon:{type:Hl,default:"$dropdown"},menuProps:{type:Object},multiple:Boolean,noDataText:{type:String,default:"$vuetify.noDataText"},openOnClear:Boolean,valueComparator:{type:Function,default:v},...Jo({itemChildren:!1})},"v-select"),Kn=He()({name:"VSelect",props:{...qn(),...w(po({modelValue:null}),["validationValue","dirty","appendInnerIcon"]),...sl({transition:{component:Mt}})},emits:{"update:modelValue":e=>!0,"update:menu":e=>!0},setup(e,l){let{slots:a}=l
const{t:o}=At(),n=t.ref(),r=Vt(e,"menu"),{items:i,transformIn:s,transformOut:u}=tn(e),c=Vt(e,"modelValue",[],(e=>s(x(e))),(t=>{const l=u(t)
return e.multiple?l:l[0]??null})),d=lo(),v=t.computed((()=>c.value.map((t=>i.value.find((l=>e.valueComparator(l.value,t.value)))||t)))),p=t.computed((()=>v.value.map((e=>e.props.value)))),f=t.computed((()=>e.hideSelected?i.value.filter((e=>!v.value.some((t=>t===e)))):i.value)),m=t.ref()
function g(t){c.value=[],e.openOnClear&&(r.value=!0)}function h(){e.hideNoData&&!i.value.length||e.readonly||null!=d&&d.isReadonly.value||(r.value=!r.value)}function y(t){var l
if(!(e.readonly||null!=d&&d.isReadonly.value))if(["Enter"," ","ArrowDown","ArrowUp","Home","End"].includes(t.key)&&t.preventDefault(),["Enter","ArrowDown"," "].includes(t.key)&&(r.value=!0),["Escape","Tab"].includes(t.key)&&(r.value=!1),"ArrowDown"===t.key)null==(l=m.value)||l.focus("next")
else if("ArrowUp"===t.key){var a
null==(a=m.value)||a.focus("prev")}else if("Home"===t.key){var o
null==(o=m.value)||o.focus("first")}else if("End"===t.key){var n
null==(n=m.value)||n.focus("last")}}function b(t){if(e.multiple){const l=p.value.findIndex((l=>e.valueComparator(l,t.value)))
if(-1===l)c.value=[...c.value,t]
else{const e=[...c.value]
e.splice(l,1),c.value=e}}else c.value=[t],r.value=!1}function V(e){var t
null!=(t=m.value)&&t.$el.contains(e.relatedTarget)||(r.value=!1)}function S(e){var t
null==e.relatedTarget&&(null==(t=n.value)||t.focus())}return Ke((()=>{const l=!(!e.chips&&!a.chip),i=!!(!e.hideNoData||f.value.length||a.prepend||a.append||a["no-data"]),[s]=mo(e)
return t.createVNode(fo,t.mergeProps({ref:n},s,{modelValue:c.value.map((e=>e.props.value)).join(", "),"onUpdate:modelValue":e=>{null==e&&(c.value=[])},validationValue:c.externalValue,dirty:c.value.length>0,class:["v-select",{"v-select--active-menu":r.value,"v-select--chips":!!e.chips,["v-select--"+(e.multiple?"multiple":"single")]:!0,"v-select--selected":c.value.length}],appendInnerIcon:e.menuIcon,readonly:!0,"onClick:clear":g,"onClick:control":h,onBlur:V,onKeydown:y}),{...a,default:()=>{var n,s,u
return t.createVNode(t.Fragment,null,[t.createVNode(Gn,t.mergeProps({modelValue:r.value,"onUpdate:modelValue":e=>r.value=e,activator:"parent",contentClass:"v-select__content",eager:e.eager,maxHeight:310,openOnClick:!1,closeOnContentClick:!1,transition:e.transition},e.menuProps),{default:()=>[i&&t.createVNode(on,{ref:m,selected:p.value,selectStrategy:e.multiple?"independent":"single-independent",onMousedown:e=>e.preventDefault(),onFocusout:S},{default:()=>[!f.value.length&&!e.hideNoData&&((null==(n=a["no-data"])?void 0:n.call(a))??t.createVNode(qo,{title:o(e.noDataText)},null)),null==(s=a["prepend-item"])?void 0:s.call(a),f.value.map(((l,o)=>{var n
return a.item?null==(n=a.item)?void 0:n.call(a,{item:l,index:o,props:t.mergeProps(l.props,{onClick:()=>b(l)})}):t.createVNode(qo,t.mergeProps({key:o},l.props,{onClick:()=>b(l)}),{prepend:l=>{let{isSelected:a}=l
return e.multiple&&!e.hideSelected?t.createVNode(ko,{modelValue:a,ripple:!1},null):void 0}})})),null==(u=a["append-item"])?void 0:u.call(a)]})]}),v.value.map(((o,n)=>{const r={"onClick:close":function(e){e.stopPropagation(),e.preventDefault(),b(o)},modelValue:!0,"onUpdate:modelValue":void 0}
return t.createVNode("div",{key:o.value,class:"v-select__selection"},[l?t.createVNode(Lt,{defaults:{VChip:{closable:e.closableChips,size:"small",text:o.title}}},{default:()=>[a.chip?a.chip({item:o,index:n,props:r}):t.createVNode(Bo,r,null)]}):a.selection?a.selection({item:o,index:n}):t.createVNode("span",{class:"v-select__selection-text"},[o.title,e.multiple&&n<v.value.length-1&&t.createVNode("span",{class:"v-select__selection-comma"},[t.createTextVNode(",")])])])}))])}})})),co({menu:r,select:b},n)}}),Zn=(e,t,l)=>null==e||null==t?-1:e.toString().toLocaleLowerCase().indexOf(t.toString().toLocaleLowerCase()),Jn=De({customFilter:Function,customKeyFilter:Object,filterKeys:[Array,String],filterMode:{type:String,default:"intersection"},noFilter:Boolean},"filter")
function Qn(e,l,a,o){const n=t.computed((()=>"string"!=typeof(null==a?void 0:a.value)&&"number"!=typeof(null==a?void 0:a.value)?"":String(a.value))),r=t.ref([]),i=t.ref(new Map)
return t.watchEffect((()=>{r.value=[],i.value=new Map
const a=t.unref(l);(function(e,t,l){const a=[],o=(null==l?void 0:l.default)??Zn,n=!(null==l||!l.filterKeys)&&x(l.filterKeys),r=Object.keys((null==l?void 0:l.customKeyFilter)??{}).length
if(null==e||!e.length)return a
e:for(let s=0;s<e.length;s++){const u=e[s],c={},d={}
let v=-1
if(t&&(null==l||!l.noFilter)){if("object"==typeof u){const e=n||Object.keys(u)
for(const a of e){var i
const e=f(u,a,u),n=null==l||null==(i=l.customKeyFilter)?void 0:i[a]
if(v=n?n(e,t,u):o(e,t,u),-1!==v&&!1!==v)n?c[a]=v:d[a]=v
else if("every"===(null==l?void 0:l.filterMode))continue e}}else v=o(u,t,u),-1!==v&&!1!==v&&(d.title=v)
const e=Object.keys(d).length,a=Object.keys(c).length
if(!e&&!a)continue
if("union"===(null==l?void 0:l.filterMode)&&a!==r&&!e)continue
if("intersection"===(null==l?void 0:l.filterMode)&&(a!==r||!e))continue}a.push({index:s,matches:{...d,...c}})}return a})(a,n.value,{customKeyFilter:e.customKeyFilter,default:e.customFilter,filterKeys:t.unref(null==o?void 0:o.filterKeys)??e.filterKeys,filterMode:e.filterMode,noFilter:e.noFilter}).forEach((e=>{let{index:t,matches:l}=e
const o=a[t]
r.value.push(o),i.value.set(o.value,l)}))})),{filteredItems:r,filteredMatches:i,getMatches:function(e){return i.value.get(e.value)}}}const er=He()({name:"VAutocomplete",props:{search:String,...Jn({filterKeys:["title"]}),...qn(),...w(po({modelValue:null}),["validationValue","dirty","appendInnerIcon"]),...sl({transition:!1})},emits:{"update:search":e=>!0,"update:modelValue":e=>!0,"update:menu":e=>!0},setup(e,l){let{slots:a}=l
const{t:o}=At(),n=t.ref(),r=t.ref(!1),i=t.ref(!0),s=Vt(e,"menu"),{items:u,transformIn:c,transformOut:d}=tn(e),v=Vt(e,"search",""),p=Vt(e,"modelValue",[],(e=>c(x(e))),(t=>{const l=d(t)
return e.multiple?l:l[0]??null})),f=lo(),{filteredItems:m,getMatches:g}=Qn(e,u,t.computed((()=>i.value?void 0:v.value))),h=t.computed((()=>p.value.map((t=>u.value.find((l=>e.valueComparator(l.value,t.value)))||t)))),y=t.computed((()=>e.hideSelected?m.value.filter((e=>!h.value.some((t=>t.value===e.value)))):m.value)),b=t.computed((()=>h.value.map((e=>e.props.value)))),V=t.ref()
function S(t){p.value=[],e.openOnClear&&(s.value=!0),v.value=""}function w(){e.hideNoData&&!u.value.length||e.readonly||null!=f&&f.isReadonly.value||(s.value=!0)}function k(t){var l
if(!(e.readonly||null!=f&&f.isReadonly.value))if(["Enter","ArrowDown","ArrowUp"].includes(t.key)&&t.preventDefault(),["Enter","ArrowDown"].includes(t.key)&&(s.value=!0),["Escape"].includes(t.key)&&(s.value=!1),["Enter","Escape","Tab"].includes(t.key)&&(i.value=!0),"ArrowDown"===t.key)null==(l=V.value)||l.focus("next")
else if("ArrowUp"===t.key){var a
null==(a=V.value)||a.focus("prev")}}function C(e){v.value=e.target.value}function N(){r.value&&(i.value=!0)}function _(e){r.value=!0}function I(e){var t
null==e.relatedTarget&&(null==(t=n.value)||t.focus())}const B=t.ref(!1)
function $(l){if(e.multiple){const t=b.value.findIndex((t=>e.valueComparator(t,l.value)))
if(-1===t)p.value=[...p.value,l],v.value=""
else{const e=[...p.value]
e.splice(t,1),p.value=e}}else p.value=[l],B.value=!0,a.selection||(v.value=l.title),s.value=!1,i.value=!0,t.nextTick((()=>B.value=!1))}return t.watch(r,(l=>{var o
l?(B.value=!0,v.value=e.multiple||a.selection?"":String((null==(o=h.value.at(-1))?void 0:o.props.title)??""),i.value=!0,t.nextTick((()=>B.value=!1))):(s.value=!1,v.value="")})),t.watch(v,(e=>{r.value&&!B.value&&(e&&(s.value=!0),i.value=!e)})),Ke((()=>{const l=!(!e.chips&&!a.chip),u=!!(!e.hideNoData||y.value.length||a.prepend||a.append||a["no-data"]),[c]=mo(e)
return t.createVNode(fo,t.mergeProps({ref:n},c,{modelValue:v.value,"onUpdate:modelValue":e=>{null==e&&(p.value=[])},validationValue:p.externalValue,dirty:p.value.length>0,onInput:C,class:["v-autocomplete",{"v-autocomplete--active-menu":s.value,"v-autocomplete--chips":!!e.chips,["v-autocomplete--"+(e.multiple?"multiple":"single")]:!0,"v-autocomplete--selection-slot":!!a.selection}],appendInnerIcon:e.menuIcon,readonly:e.readonly,"onClick:clear":S,"onClick:control":w,"onClick:input":w,onFocus:()=>r.value=!0,onBlur:()=>r.value=!1,onKeydown:k}),{...a,default:()=>{var n,r,c
return t.createVNode(t.Fragment,null,[t.createVNode(Gn,t.mergeProps({modelValue:s.value,"onUpdate:modelValue":e=>s.value=e,activator:"parent",contentClass:"v-autocomplete__content",eager:e.eager,maxHeight:310,openOnClick:!1,closeOnContentClick:!1,transition:e.transition,onAfterLeave:N},e.menuProps),{default:()=>[u&&t.createVNode(on,{ref:V,selected:b.value,selectStrategy:e.multiple?"independent":"single-independent",onMousedown:e=>e.preventDefault(),onFocusin:_,onFocusout:I},{default:()=>[!y.value.length&&!e.hideNoData&&((null==(n=a["no-data"])?void 0:n.call(a))??t.createVNode(qo,{title:o(e.noDataText)},null)),null==(r=a["prepend-item"])?void 0:r.call(a),y.value.map(((l,o)=>{var n
return(null==(n=a.item)?void 0:n.call(a,{item:l,index:o,props:t.mergeProps(l.props,{onClick:()=>$(l)})}))??t.createVNode(qo,t.mergeProps({key:o},l.props,{onClick:()=>$(l)}),{prepend:l=>{let{isSelected:a}=l
return e.multiple&&!e.hideSelected?t.createVNode(ko,{modelValue:a,ripple:!1},null):void 0},title:()=>{var e,a
return i.value?l.title:function(e,l,a){if(null==l)return e
if(Array.isArray(l))throw new Error("Multiple matches is not implemented")
return"number"==typeof l&&~l?t.createVNode(t.Fragment,null,[t.createVNode("span",{class:"v-autocomplete__unmask"},[e.substr(0,l)]),t.createVNode("span",{class:"v-autocomplete__mask"},[e.substr(l,a)]),t.createVNode("span",{class:"v-autocomplete__unmask"},[e.substr(l+a)])]):e}(l.title,null==(e=g(l))?void 0:e.title,(null==(a=v.value)?void 0:a.length)??0)}})})),null==(c=a["append-item"])?void 0:c.call(a)]})]}),h.value.map(((o,n)=>{const r={"onClick:close":function(e){e.stopPropagation(),e.preventDefault(),$(o)},modelValue:!0,"onUpdate:modelValue":void 0}
return t.createVNode("div",{key:o.value,class:"v-autocomplete__selection"},[l?t.createVNode(Lt,{defaults:{VChip:{closable:e.closableChips,size:"small",text:o.title}}},{default:()=>[a.chip?a.chip({item:o,index:n,props:r}):t.createVNode(Bo,r,null)]}):a.selection?a.selection({item:o,index:n}):t.createVNode("span",{class:"v-autocomplete__selection-text"},[o.title,e.multiple&&n<h.value.length-1&&t.createVNode("span",{class:"v-autocomplete__selection-comma"},[t.createTextVNode(",")])])])}))])}})})),co({isFocused:r,isPristine:i,menu:s,search:v,filteredItems:m,select:$},n)}}),tr=je({name:"VBadge",inheritAttrs:!1,props:{bordered:Boolean,color:String,content:[Number,String],dot:Boolean,floating:Boolean,icon:Hl,inline:Boolean,label:{type:String,default:"$vuetify.badge"},max:[Number,String],modelValue:{type:Boolean,default:!0},offsetX:[Number,String],offsetY:[Number,String],textColor:String,...xa({location:"top end"}),...hl(),...dl(),...pt(),...sl({transition:"scale-rotate-transition"})},setup(e,l){const{backgroundColorClasses:a,backgroundColorStyles:o}=Sl(t.toRef(e,"color")),{roundedClasses:n}=yl(e),{t:r}=At(),{textColorClasses:i,textColorStyles:s}=Vl(t.toRef(e,"textColor")),{themeClasses:u}=ht(),{locationStyles:c}=Ca(e,!0,(t=>(e.floating?e.dot?2:4:e.dot?8:12)+(["top","bottom"].includes(t)?+(e.offsetY??0):["left","right"].includes(t)?+(e.offsetX??0):0)))
return Ke((()=>{var d,v,p,f
const m=Number(e.content),g=!e.max||isNaN(m)?e.content:m<=e.max?m:`${e.max}+`,[h,y]=S(l.attrs,["aria-atomic","aria-label","aria-live","role","title"])
return t.createVNode(e.tag,t.mergeProps({class:["v-badge",{"v-badge--bordered":e.bordered,"v-badge--dot":e.dot,"v-badge--floating":e.floating,"v-badge--inline":e.inline}]},y),{default:()=>[t.createVNode("div",{class:"v-badge__wrapper"},[null==(d=(v=l.slots).default)?void 0:d.call(v),t.createVNode(ul,{transition:e.transition},{default:()=>[t.withDirectives(t.createVNode("span",t.mergeProps({class:["v-badge__badge",u.value,a.value,n.value,i.value],style:[o.value,s.value,e.inline?{}:c.value],"aria-atomic":"true","aria-label":r(e.label,m),"aria-live":"polite",role:"status"},h),[e.dot?void 0:l.slots.badge?null==(p=(f=l.slots).badge)?void 0:p.call(f):e.icon?t.createVNode(la,{icon:e.icon},null):g]),[[t.vShow,e.modelValue]])]})])]})})),{}}}),lr=je({name:"VBannerActions",props:{color:String,density:String},setup(e,l){let{slots:a}=l
return Me({VBtn:{color:e.color,density:e.density,variant:"text"}}),Ke((()=>{var e
return t.createVNode("div",{class:"v-banner-actions"},[null==(e=a.default)?void 0:e.call(a)])})),{}}}),ar=We("v-banner-text"),or=je({name:"VBanner",props:{avatar:String,color:String,icon:Hl,lines:String,stacked:Boolean,sticky:Boolean,text:String,...pl(),..._l(),...al(),...ml(),...xa(),...Aa(),...hl(),...dl(),...pt()},setup(e,l){let{slots:a}=l
const{borderClasses:o}=fl(e),{densityClasses:n}=Il(e),{mobile:r}=Tn(),{dimensionStyles:i}=ol(e),{elevationClasses:s}=gl(e),{locationStyles:u}=Ca(e),{positionClasses:c}=Ea(e),{roundedClasses:d}=yl(e),{themeClasses:v}=gt(e),p=t.toRef(e,"color"),f=t.toRef(e,"density")
Me({VBannerActions:{color:p,density:f}}),Ke((()=>{var l
const m=!(!e.text&&!a.text),g=!!(a.prepend||e.avatar||e.icon)
return t.createVNode(e.tag,{class:["v-banner",{"v-banner--stacked":e.stacked||r.value,"v-banner--sticky":e.sticky,[`v-banner--${e.lines}-line`]:!!e.lines},o.value,n.value,s.value,c.value,d.value,v.value],style:[i.value,u.value],role:"banner"},{default:()=>[g&&t.createVNode(Lt,{key:"prepend",defaults:{VAvatar:{color:p.value,density:f.value,icon:e.icon,image:e.avatar}}},{default:()=>[t.createVNode("div",{class:"v-banner__prepend"},[a.prepend?a.prepend():(e.avatar||e.icon)&&t.createVNode(No,null,null)])]}),t.createVNode("div",{class:"v-banner__content"},[m&&t.createVNode(ar,{key:"text"},{default:()=>[a.text?a.text():e.text]}),null==(l=a.default)?void 0:l.call(a)]),a.actions&&t.createVNode(lr,null,{default:()=>[a.actions()]})]})}))}}),nr=je({name:"VBottomNavigation",props:{bgColor:String,color:String,grow:Boolean,mode:{type:String,validator:e=>!e||["horizontal","shift"].includes(e)},height:{type:[Number,String],default:56},active:{type:Boolean,default:!0},...pl(),..._l(),...ml(),...hl(),...et({name:"bottom-navigation"}),...dl({tag:"header"}),...Tl({modelValue:!0,selectedClass:"v-btn--selected"}),...pt()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{themeClasses:o}=ht(),{borderClasses:n}=fl(e),{backgroundColorClasses:r,backgroundColorStyles:i}=Sl(t.toRef(e,"bgColor")),{densityClasses:s}=Il(e),{elevationClasses:u}=gl(e),{roundedClasses:c}=yl(e),d=t.computed((()=>Number(e.height)-("comfortable"===e.density?8:0)-("compact"===e.density?16:0))),v=t.toRef(e,"active"),{layoutItemStyles:p}=lt({id:e.name,order:t.computed((()=>parseInt(e.order,10))),position:t.computed((()=>"bottom")),layoutSize:t.computed((()=>v.value?d.value:0)),elementSize:d,active:v,absolute:t.toRef(e,"absolute")})
return Ol(e,Ml),Me({VBtn:{color:t.toRef(e,"color"),density:t.toRef(e,"density"),stacked:t.computed((()=>"horizontal"!==e.mode)),variant:"text"}},{scoped:!0}),Ke((()=>t.createVNode(e.tag,{class:["v-bottom-navigation",{"v-bottom-navigation--active":v.value,"v-bottom-navigation--grow":e.grow,"v-bottom-navigation--shift":"shift"===e.mode},o.value,r.value,n.value,s.value,u.value,c.value],style:[i.value,p.value,{height:g(d.value),transform:`translateY(${g(v.value?0:100,"%")})`}]},{default:()=>[a.default&&t.createVNode("div",{class:"v-bottom-navigation__content"},[a.default()])]}))),{}}}),rr=je({name:"VBreadcrumbsDivider",props:{divider:[Number,String]},setup(e,l){let{slots:a}=l
return Ke((()=>{var l
return t.createVNode("li",{class:"v-breadcrumbs-divider"},[(null==a||null==(l=a.default)?void 0:l.call(a))??e.divider])})),{}}}),ir=je({name:"VBreadcrumbsItem",props:{active:Boolean,activeClass:String,activeColor:String,color:String,disabled:Boolean,title:String,...La(),...dl({tag:"li"})},setup(e,l){let{slots:a,attrs:o}=l
const n=Ta(e,o),r=t.computed((()=>{var t
return e.active||(null==(t=n.isActive)?void 0:t.value)})),i=t.computed((()=>r.value?e.activeColor:e.color)),{textColorClasses:s,textColorStyles:u}=Vl(i)
return Ke((()=>{var l
const o=n.isLink.value?"a":e.tag
return t.createVNode(o,{class:["v-breadcrumbs-item",{"v-breadcrumbs-item--active":r.value,"v-breadcrumbs-item--disabled":e.disabled,"v-breadcrumbs-item--link":n.isLink.value,[`${e.activeClass}`]:r.value&&e.activeClass},s.value],style:[u.value],href:n.href.value,"aria-current":r.value?"page":void 0,onClick:n.navigate},{default:()=>[(null==(l=a.default)?void 0:l.call(a))??e.title]})})),{}}}),sr=He()({name:"VBreadcrumbs",props:{activeClass:String,activeColor:String,bgColor:String,color:String,disabled:Boolean,divider:{type:String,default:"/"},icon:Hl,items:{type:Array,default:()=>[]},..._l(),...hl(),...dl({tag:"ul"})},setup(e,l){let{slots:a}=l
const{backgroundColorClasses:o,backgroundColorStyles:n}=Sl(t.toRef(e,"bgColor")),{densityClasses:r}=Il(e),{roundedClasses:i}=yl(e)
return Me({VBreadcrumbsDivider:{divider:t.toRef(e,"divider")},VBreadcrumbsItem:{activeClass:t.toRef(e,"activeClass"),activeColor:t.toRef(e,"activeColor"),color:t.toRef(e,"color"),disabled:t.toRef(e,"disabled")}}),Ke((()=>{var l
const s=!(!a.prepend&&!e.icon)
return t.createVNode(e.tag,{class:["v-breadcrumbs",o.value,r.value,i.value],style:n.value},{default:()=>[s&&t.createVNode(Lt,{key:"prepend",defaults:{VIcon:{icon:e.icon,start:!0}}},{default:()=>[t.createVNode("div",{class:"v-breadcrumbs__prepend"},[a.prepend?a.prepend():e.icon&&t.createVNode(la,null,null)])]}),e.items.map(((e,l,o)=>t.createVNode(t.Fragment,null,[t.createVNode(ir,t.mergeProps({key:l,disabled:l>=o.length-1},"string"==typeof e?{title:e}:e),{default:a.title?()=>{var t
return null==(t=a.title)?void 0:t.call(a,{item:e,index:l})}:void 0}),l<o.length-1&&t.createVNode(rr,null,{default:a.divider?()=>{var t
return null==(t=a.divider)?void 0:t.call(a,{item:e,index:l})}:void 0})]))),null==(l=a.default)?void 0:l.call(a)]})})),{}}}),ur=je({name:"VCardActions",setup(e,l){let{slots:a}=l
return Me({VBtn:{variant:"text"}}),Ke((()=>{var e
return t.createVNode("div",{class:"v-card-actions"},[null==(e=a.default)?void 0:e.call(a)])})),{}}}),cr=We("v-card-subtitle"),dr=We("v-card-title"),vr=je({name:"VCardItem",props:{appendAvatar:String,appendIcon:Hl,prependAvatar:String,prependIcon:Hl,subtitle:String,title:String,..._l()},setup(e,l){let{slots:a}=l
return Ke((()=>{var l,o,n,r,i
const s=!!(e.prependAvatar||e.prependIcon||a.prepend),u=!!(e.appendAvatar||e.appendIcon||a.append),c=!(!e.title&&!a.title),d=!(!e.subtitle&&!a.subtitle)
return t.createVNode("div",{class:"v-card-item"},[s&&t.createVNode(Lt,{key:"prepend",defaults:{VAvatar:{density:e.density,icon:e.prependIcon,image:e.prependAvatar},VIcon:{density:e.density,icon:e.prependIcon}}},{default:()=>[t.createVNode("div",{class:"v-card-item__prepend"},[(null==(l=a.prepend)?void 0:l.call(a))??t.createVNode(No,null,null)])]}),t.createVNode("div",{class:"v-card-item__content"},[c&&t.createVNode(dr,{key:"title"},{default:()=>[(null==(o=a.title)?void 0:o.call(a))??e.title]}),d&&t.createVNode(cr,{key:"subtitle"},{default:()=>[(null==(n=a.subtitle)?void 0:n.call(a))??e.subtitle]}),null==(r=a.default)?void 0:r.call(a)]),u&&t.createVNode(Lt,{key:"append",defaults:{VAvatar:{density:e.density,icon:e.appendIcon,image:e.appendAvatar},VIcon:{density:e.density,icon:e.appendIcon}}},{default:()=>[t.createVNode("div",{class:"v-card-item__append"},[(null==(i=a.append)?void 0:i.call(a))??t.createVNode(No,null,null)])]})])})),{}}}),pr=We("v-card-text"),fr=je({name:"VCard",directives:{Ripple:wa},props:{appendAvatar:String,appendIcon:Hl,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:Hl,ripple:{type:Boolean,default:!0},subtitle:String,text:String,title:String,...pt(),...pl(),..._l(),...al(),...ml(),..._a(),...xa(),...Aa(),...hl(),...La(),...dl(),...Al({variant:"elevated"})},setup(e,l){let{attrs:a,slots:o}=l
const{themeClasses:n}=gt(e),{borderClasses:r}=fl(e),{colorClasses:i,colorStyles:s,variantClasses:u}=El(e),{densityClasses:c}=Il(e),{dimensionStyles:d}=ol(e),{elevationClasses:v}=gl(e),{loaderClasses:p}=Ia(e),{locationStyles:f}=Ca(e),{positionClasses:m}=Ea(e),{roundedClasses:g}=yl(e),h=Ta(e,a),y=t.computed((()=>!1!==e.link&&h.isLink.value)),b=t.computed((()=>!e.disabled&&!1!==e.link&&(e.link||h.isClickable.value)))
return Ke((()=>{var l,a,V
const S=y.value?"a":e.tag,w=!(!o.title&&!e.title),k=!(!o.subtitle&&!e.subtitle),x=w||k,C=!!(o.append||e.appendAvatar||e.appendIcon),N=!!(o.prepend||e.prependAvatar||e.prependIcon),_=!(!o.image&&!e.image),I=x||N||C,B=!(!o.text&&!e.text)
return t.withDirectives(t.createVNode(S,{class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":b.value},n.value,r.value,i.value,c.value,v.value,p.value,m.value,g.value,u.value],style:[s.value,d.value,f.value],href:h.href.value,onClick:b.value&&h.navigate,tabindex:e.disabled?-1:void 0},{default:()=>[_&&t.createVNode(Lt,{key:"image",defaults:{VImg:{cover:!0,src:e.image}}},{default:()=>[t.createVNode("div",{class:"v-card__image"},[(null==(l=o.image)?void 0:l.call(o))??t.createVNode(cl,null,null)])]}),t.createVNode(Ba,{name:"v-card",active:!!e.loading,color:"boolean"==typeof e.loading?void 0:e.loading},{default:o.loader}),I&&t.createVNode(vr,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:o.item,prepend:o.prepend,title:o.title,subtitle:o.subtitle,append:o.append}),B&&t.createVNode(pr,{key:"text"},{default:()=>[(null==(a=o.text)?void 0:a.call(o))??e.text]}),null==(V=o.default)?void 0:V.call(o),o.actions&&t.createVNode(ur,null,{default:o.actions}),$l(b.value,"v-card")]}),[[t.resolveDirective("ripple"),b.value&&e.ripple]])})),{}}})
function mr(e,t){var l
const a=e.changedTouches[0]
t.touchstartX=a.clientX,t.touchstartY=a.clientY,null==(l=t.start)||l.call(t,{originalEvent:e,...t})}function gr(e,t){var l
const a=e.changedTouches[0]
t.touchendX=a.clientX,t.touchendY=a.clientY,null==(l=t.end)||l.call(t,{originalEvent:e,...t}),(e=>{const{touchstartX:t,touchendX:l,touchstartY:a,touchendY:o}=e
e.offsetX=l-t,e.offsetY=o-a,Math.abs(e.offsetY)<.5*Math.abs(e.offsetX)&&(e.left&&l<t-16&&e.left(e),e.right&&l>t+16&&e.right(e)),Math.abs(e.offsetX)<.5*Math.abs(e.offsetY)&&(e.up&&o<a-16&&e.up(e),e.down&&o>a+16&&e.down(e))})(t)}function hr(e,t){var l
const a=e.changedTouches[0]
t.touchmoveX=a.clientX,t.touchmoveY=a.clientY,null==(l=t.move)||l.call(t,{originalEvent:e,...t})}const yr={mounted:function(e,t){var l
const a=t.value,o=null!=a&&a.parent?e.parentElement:e,n=(null==a?void 0:a.options)??{passive:!0},r=null==(l=t.instance)?void 0:l.$.uid
if(!o||!r)return
const i=function(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{}
const t={touchstartX:0,touchstartY:0,touchendX:0,touchendY:0,touchmoveX:0,touchmoveY:0,offsetX:0,offsetY:0,left:e.left,right:e.right,up:e.up,down:e.down,start:e.start,move:e.move,end:e.end}
return{touchstart:e=>mr(e,t),touchend:e=>gr(e,t),touchmove:e=>hr(e,t)}}(t.value)
o._touchHandlers=o._touchHandlers??Object.create(null),o._touchHandlers[r]=i,V(i).forEach((e=>{o.addEventListener(e,i[e],n)}))},unmounted:function(e,t){var l,a
const o=null!=(l=t.value)&&l.parent?e.parentElement:e,n=null==(a=t.instance)?void 0:a.$.uid
if(null==o||!o._touchHandlers||!n)return
const r=o._touchHandlers[n]
V(r).forEach((e=>{o.removeEventListener(e,r[e])})),delete o._touchHandlers[n]}},br=Symbol.for("vuetify:v-window"),Vr=Symbol.for("vuetify:v-window-group"),Sr=He()({name:"VWindow",directives:{Touch:yr},props:{continuous:Boolean,nextIcon:{type:[Boolean,String,Function,Object],default:"$next"},prevIcon:{type:[Boolean,String,Function,Object],default:"$prev"},reverse:Boolean,showArrows:{type:[Boolean,String],validator:e=>"boolean"==typeof e||"hover"===e},touch:{type:[Object,Boolean],default:void 0},direction:{type:String,default:"horizontal"},modelValue:null,disabled:Boolean,selectedClass:{type:String,default:"v-window-item--active"},mandatory:{default:"force"},...dl(),...pt()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{isRtl:n}=Rt(),{t:r}=At(),i=Ol(e,Vr),s=t.ref(),u=t.computed((()=>n.value?!e.reverse:e.reverse)),c=t.ref(!1),d=t.computed((()=>`v-window-${"vertical"===e.direction?"y":"x"}${(u.value?!c.value:c.value)?"-reverse":""}-transition`)),v=t.ref(0),p=t.ref(void 0),f=t.computed((()=>i.items.value.findIndex((e=>i.selected.value.includes(e.id)))))
t.watch(f,((e,t)=>{const l=i.items.value.length,a=l-1
c.value=l<=2?e<t:e===a&&0===t||(0!==e||t!==a)&&e<t})),t.provide(br,{transition:d,isReversed:c,transitionCount:v,transitionHeight:p,rootRef:s})
const m=t.computed((()=>e.continuous||0!==f.value)),g=t.computed((()=>e.continuous||f.value!==i.items.value.length-1))
function h(){m.value&&i.prev()}function y(){g.value&&i.next()}const b=t.computed((()=>{const l=[],o={icon:n.value?e.nextIcon:e.prevIcon,class:"v-window__"+(u.value?"right":"left"),onClick:i.prev,ariaLabel:r("$vuetify.carousel.prev")}
l.push(m.value?a.prev?a.prev({props:o}):t.createVNode(Oa,o,null):t.createVNode("div",null,null))
const s={icon:n.value?e.prevIcon:e.nextIcon,class:"v-window__"+(u.value?"left":"right"),onClick:i.next,ariaLabel:r("$vuetify.carousel.next")}
return l.push(g.value?a.next?a.next({props:s}):t.createVNode(Oa,s,null):t.createVNode("div",null,null)),l})),V=t.computed((()=>{if(!1===e.touch)return e.touch
return{...{left:()=>{u.value?h():y()},right:()=>{u.value?y():h()},start:e=>{let{originalEvent:t}=e
t.stopPropagation()}},...!0===e.touch?{}:e.touch}}))
return Ke((()=>{var l,n
return t.withDirectives(t.createVNode(e.tag,{ref:s,class:["v-window",{"v-window--show-arrows-on-hover":"hover"===e.showArrows},o.value]},{default:()=>[t.createVNode("div",{class:"v-window__container",style:{height:p.value}},[null==(l=a.default)?void 0:l.call(a,{group:i}),!1!==e.showArrows&&t.createVNode("div",{class:"v-window__controls"},[b.value])]),null==(n=a.additional)?void 0:n.call(a,{group:i})]}),[[t.resolveDirective("touch"),V.value]])})),{group:i}}})
function wr(){const e=t.ref(!1)
t.onMounted((()=>{window.requestAnimationFrame((()=>{e.value=!0}))}))
return{ssrBootStyles:t.computed((()=>e.value?void 0:{transition:"none !important"})),isBooted:t.readonly(e)}}const kr=je({name:"VWindowItem",directives:{Touch:yr},props:{reverseTransition:{type:[Boolean,String],default:void 0},transition:{type:[Boolean,String],default:void 0},...Ll(),...fn()},emits:{"group:selected":e=>!0},setup(e,l){let{slots:a}=l
const o=t.inject(br),n=Pl(e,Vr),{isBooted:r}=wr()
if(!o||!n)throw new Error("[Vuetify] VWindowItem must be used inside VWindow")
const i=t.ref(!1),s=t.computed((()=>o.isReversed.value?!1!==e.reverseTransition:!1!==e.transition))
function u(){i.value&&o&&(i.value=!1,o.transitionCount.value>0&&(o.transitionCount.value-=1,0===o.transitionCount.value&&(o.transitionHeight.value=void 0)))}function c(){if(!i.value&&o){var e
if(i.value=!0,0===o.transitionCount.value)o.transitionHeight.value=g(null==(e=o.rootRef.value)?void 0:e.clientHeight)
o.transitionCount.value+=1}}function d(){u()}function v(e){i.value&&t.nextTick((()=>{s.value&&i.value&&o&&(o.transitionHeight.value=g(e.clientHeight))}))}const p=t.computed((()=>{const t=o.isReversed.value?e.reverseTransition:e.transition
return!!s.value&&{name:"string"!=typeof t?o.transition.value:t,onBeforeEnter:c,onAfterEnter:u,onEnterCancelled:d,onBeforeLeave:c,onAfterLeave:u,onLeaveCancelled:d,onEnter:v}})),{hasContent:f}=mn(e,n.isSelected)
return Ke((()=>{var e
return t.createVNode(ul,{transition:r.value&&p.value},{default:()=>[t.withDirectives(t.createVNode("div",{class:["v-window-item",n.selectedClass.value]},[f.value&&(null==(e=a.default)?void 0:e.call(a))]),[[t.vShow,n.isSelected.value]])]})})),{}}}),xr=je({name:"VCarousel",props:{color:String,cycle:Boolean,delimiterIcon:{type:Hl,default:"$delimiter"},height:{type:[Number,String],default:500},hideDelimiters:Boolean,hideDelimiterBackground:Boolean,interval:{type:[Number,String],default:6e3,validator:e=>e>0},modelValue:null,progress:[Boolean,String],showArrows:{type:[Boolean,String],default:!0,validator:e=>"boolean"==typeof e||"hover"===e},verticalDelimiters:[Boolean,String]},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),{t:n}=At(),r=t.ref()
let i=-1
function s(){e.cycle&&r.value&&(i=window.setTimeout(r.value.group.next,+e.interval>0?+e.interval:6e3))}function u(){window.clearTimeout(i),window.requestAnimationFrame(s)}return t.watch(o,u),t.watch((()=>e.interval),u),t.watch((()=>e.cycle),(e=>{e?u():window.clearTimeout(i)})),t.onMounted(s),Ke((()=>t.createVNode(Sr,{ref:r,modelValue:o.value,"onUpdate:modelValue":e=>o.value=e,class:["v-carousel",{"v-carousel--hide-delimiter-background":e.hideDelimiterBackground,"v-carousel--vertical-delimiters":e.verticalDelimiters}],style:{height:g(e.height)},continuous:!0,mandatory:"force",showArrows:e.showArrows},{default:a.default,additional:l=>{let{group:r}=l
return t.createVNode(t.Fragment,null,[!e.hideDelimiters&&t.createVNode("div",{class:"v-carousel__controls",style:{left:"left"===e.verticalDelimiters&&e.verticalDelimiters?0:"auto",right:"right"===e.verticalDelimiters?0:"auto"}},[r.items.value.length>0&&t.createVNode(Lt,{defaults:{VBtn:{color:e.color,icon:e.delimiterIcon,size:"x-small",variant:"text"}},scoped:!0},{default:()=>[r.items.value.map(((e,l)=>{const o={"aria-label":n("$vuetify.carousel.ariaLabel.delimiter",l+1,r.items.value.length),class:[r.isSelected(e.id)&&"v-btn--active"],onClick:()=>r.select(e.id,!0)}
return a.item?a.item({props:o,item:e}):t.createVNode(Oa,t.mergeProps(e,o),null)}))]})]),e.progress&&t.createVNode(Na,{class:"v-carousel__progress",color:"string"==typeof e.progress?e.progress:void 0,modelValue:(r.getItemIndex(o.value)+1)/r.items.value.length*100},null)])},prev:a.prev,next:a.next}))),{}}}),Cr=je({name:"VCarouselItem",inheritAttrs:!1,props:{value:null},setup(e,l){let{slots:a,attrs:o}=l
Ke((()=>t.createVNode(kr,{class:"v-carousel-item",value:e.value},{default:()=>[t.createVNode(cl,o,a)]})))}}),Nr=We("v-code"),_r=je({name:"VColorPickerCanvas",props:{color:{type:Object},disabled:Boolean,dotSize:{type:[Number,String],default:10},height:{type:[Number,String],default:150},width:{type:[Number,String],default:300}},emits:{"update:color":e=>!0,"update:position":e=>!0},setup(e,l){let{emit:a}=l
const o=t.ref(!1),n=t.ref(!1),r=t.ref({x:0,y:0}),i=t.computed((()=>{const{x:t,y:l}=r.value,a=parseInt(e.dotSize,10)/2
return{width:g(e.dotSize),height:g(e.dotSize),transform:`translate(${g(t-a)}, ${g(l-a)})`}})),s=t.ref()
function u(e,t,l){const{left:a,top:o,width:n,height:i}=l
r.value={x:C(e-a,0,n),y:C(t-o,0,i)}}function c(t){!e.disabled&&s.value&&u(t.clientX,t.clientY,s.value.getBoundingClientRect())}function d(t){t.preventDefault(),e.disabled||(o.value=!0,window.addEventListener("mousemove",v),window.addEventListener("mouseup",p),window.addEventListener("touchmove",v),window.addEventListener("touchend",p))}function v(t){if(e.disabled||!s.value)return
o.value=!0
const l=function(e){return"touches"in e?{clientX:e.touches[0].clientX,clientY:e.touches[0].clientY}:{clientX:e.clientX,clientY:e.clientY}}(t)
u(l.clientX,l.clientY,s.value.getBoundingClientRect())}function p(){window.removeEventListener("mousemove",v),window.removeEventListener("mouseup",p),window.removeEventListener("touchmove",v),window.removeEventListener("touchend",p)}function f(){var t
if(!s.value)return
const l=s.value,a=l.getContext("2d")
if(!a)return
const o=a.createLinearGradient(0,0,l.width,0)
o.addColorStop(0,"hsla(0, 0%, 100%, 1)"),o.addColorStop(1,`hsla(${(null==(t=e.color)?void 0:t.h)??0}, 100%, 50%, 1)`),a.fillStyle=o,a.fillRect(0,0,l.width,l.height)
const n=a.createLinearGradient(0,0,0,l.height)
n.addColorStop(0,"hsla(0, 0%, 100%, 0)"),n.addColorStop(1,"hsla(0, 0%, 0%, 1)"),a.fillStyle=n,a.fillRect(0,0,l.width,l.height)}return t.watch(r,(()=>{var t,l
if(n.value)return void(n.value=!1)
if(!s.value)return
const{width:o,height:i}=s.value.getBoundingClientRect(),{x:u,y:c}=r.value
a("update:color",{h:(null==(t=e.color)?void 0:t.h)??0,s:C(u,0,o)/o,v:1-C(c,0,i)/i,a:(null==(l=e.color)?void 0:l.a)??1})})),t.watch((()=>{var t
return null==(t=e.color)?void 0:t.h}),f,{immediate:!0}),t.watch((()=>e.color),(()=>{o.value?o.value=!1:e.color&&(n.value=!0,r.value={x:e.color.s*parseInt(e.width,10),y:(1-e.color.v)*parseInt(e.height,10)})}),{deep:!0,immediate:!0}),t.onMounted((()=>f())),Ke((()=>t.createVNode("div",{class:"v-color-picker-canvas",style:{width:g(e.width),height:g(e.height)},onClick:c,onMousedown:d,onTouchstart:d},[t.createVNode("canvas",{ref:s,width:e.width,height:e.height},null),t.createVNode("div",{class:["v-color-picker-canvas__dot",{"v-color-picker-canvas__dot--disabled":e.disabled}],style:i.value},null)]))),{}}})
var Ir
function Br(e,t){return t.every((t=>e.hasOwnProperty(t)))}function $r(e){if(!e)return null
let t=null
if("string"==typeof e){t=Ce(function(e){return e.startsWith("#")&&(e=e.slice(1)),3!==(e=e.replace(/([^0-9a-f])/gi,"F")).length&&4!==e.length||(e=e.split("").map((e=>e+e)).join("")),6===e.length?N(e,8,"F"):N(N(e,6),8,"F")}(e))}return"object"==typeof e&&(Br(e,["r","g","b"])?t=ye(e):Br(e,["h","s","l"])?t=Ve(e):Br(e,["h","s","v"])&&(t=e)),null!=t?{...t,a:t.a??1}:null}const Ar={h:0,s:0,v:1,a:1},Er={inputProps:{type:"number",min:0},inputs:[{label:"R",max:255,step:1,getValue:e=>Math.round(e.r),getColor:(e,t)=>({...e,r:Number(t)})},{label:"G",max:255,step:1,getValue:e=>Math.round(e.g),getColor:(e,t)=>({...e,g:Number(t)})},{label:"B",max:255,step:1,getValue:e=>Math.round(e.b),getColor:(e,t)=>({...e,b:Number(t)})},{label:"A",max:1,step:.01,getValue:e=>{let{a:t}=e
return t?Math.round(100*t)/100:1},getColor:(e,t)=>({...e,a:Number(t)})}],to:he,from:ye},Rr={inputProps:{type:"number",min:0},inputs:[{label:"H",max:360,step:1,getValue:e=>Math.round(e.h),getColor:(e,t)=>({...e,h:Number(t)})},{label:"S",max:1,step:.01,getValue:e=>Math.round(100*e.s)/100,getColor:(e,t)=>({...e,s:Number(t)})},{label:"L",max:1,step:.01,getValue:e=>Math.round(100*e.l)/100,getColor:(e,t)=>({...e,l:Number(t)})},{label:"A",max:1,step:.01,getValue:e=>{let{a:t}=e
return t?Math.round(100*t)/100:1},getColor:(e,t)=>({...e,a:Number(t)})}],to:be,from:Ve},Tr={inputProps:{type:"text"},inputs:[{label:"HEXA",getValue:e=>e,getColor:(e,t)=>t}],to:Ne,from:Ce},Lr={rgb:{...Er,inputs:null==(Ir=Er.inputs)?void 0:Ir.slice(0,3)},rgba:Er,hsl:{...Rr,inputs:Rr.inputs.slice(0,3)},hsla:Rr,hex:{...Tr,inputs:[{label:"HEX",getValue:e=>e.slice(0,7),getColor:(e,t)=>t}]},hexa:Tr},Pr=e=>{let{label:l,...a}=e
return t.createVNode("div",{class:"v-color-picker-edit__input"},[t.createVNode("input",a,null),t.createVNode("span",null,[l])])},Or=je({name:"VColorPickerEdit",props:{color:Object,disabled:Boolean,mode:{type:String,default:"rgba",validator:e=>Object.keys(Lr).includes(e)},modes:{type:Array,default:()=>Object.keys(Lr),validator:e=>Array.isArray(e)&&e.every((e=>Object.keys(Lr).includes(e)))}},emits:{"update:color":e=>!0,"update:mode":e=>!0},setup(e,l){let{emit:a}=l
const o=t.computed((()=>e.modes.map((e=>({...Lr[e],name:e}))))),n=t.computed((()=>{var t
const l=o.value.find((t=>t.name===e.mode))
if(!l)return[]
const n=e.color?l.to(e.color):{}
return null==(t=l.inputs)?void 0:t.map((t=>{let{getValue:o,getColor:r,...i}=t
return{...l.inputProps,...i,disabled:e.disabled,value:o(n),onChange:e=>{const t=e.target
t&&a("update:color",l.from(r(n,t.value)))}}}))}))
return Ke((()=>{var l
return t.createVNode("div",{class:"v-color-picker-edit"},[null==(l=n.value)?void 0:l.map((e=>t.createVNode(Pr,e,null))),o.value.length>1&&t.createVNode(Oa,{icon:"$unfold",size:"x-small",variant:"plain",onClick:()=>{const t=o.value.findIndex((t=>t.name===e.mode))
a("update:mode",o.value[(t+1)%o.value.length].name)}},null)])})),{}}}),Fr=Symbol.for("vuetify:v-slider")
function Mr(e,t,l){const a="vertical"===l,o=t.getBoundingClientRect(),n="touches"in e?e.touches[0]:e
return a?n.clientY-(o.top+o.height/2):n.clientX-(o.left+o.width/2)}const zr=De({disabled:Boolean,error:Boolean,readonly:Boolean,max:{type:[Number,String],default:100},min:{type:[Number,String],default:0},step:{type:[Number,String],default:0},thumbColor:String,thumbLabel:{type:[Boolean,String],default:void 0,validator:e=>"boolean"==typeof e||"always"===e},thumbSize:{type:[Number,String],default:20},showTicks:{type:[Boolean,String],default:!1,validator:e=>"boolean"==typeof e||"always"===e},ticks:{type:[Array,Object]},tickSize:{type:[Number,String],default:2},color:String,trackColor:String,trackFillColor:String,trackSize:{type:[Number,String],default:4},direction:{type:String,default:"horizontal",validator:e=>["vertical","horizontal"].includes(e)},reverse:Boolean,...hl(),...ml({elevation:2})},"slider"),Dr=e=>{let{props:l,handleSliderMouseUp:a,handleMouseMove:o,getActiveThumb:n}=e
const{isRtl:r}=Rt(),i=t.toRef(l,"reverse"),s=t.computed((()=>{let e=r.value?"rtl":"ltr"
return l.reverse&&(e="rtl"===e?"ltr":"rtl"),e})),u=t.computed((()=>parseFloat(l.min))),c=t.computed((()=>parseFloat(l.max))),d=t.computed((()=>l.step>0?parseFloat(l.step):0)),v=t.computed((()=>{const e=d.value.toString().trim()
return e.includes(".")?e.length-e.indexOf(".")-1:0})),p=t.computed((()=>parseInt(l.thumbSize,10))),f=t.computed((()=>parseInt(l.tickSize,10))),g=t.computed((()=>parseInt(l.trackSize,10))),h=t.computed((()=>(c.value-u.value)/d.value)),y=t.toRef(l,"disabled"),b=t.computed((()=>"vertical"===l.direction)),V=t.computed((()=>l.error||l.disabled?void 0:l.thumbColor??l.color)),S=t.computed((()=>l.error||l.disabled?void 0:l.trackColor??l.color)),w=t.computed((()=>l.error||l.disabled?void 0:l.trackFillColor??l.color)),k=t.ref(!1),x=t.ref(0),N=t.ref(),_=t.ref()
function I(e){if(d.value<=0)return e
const t=C(e,u.value,c.value),l=u.value%d.value,a=Math.round((t-l)/d.value)*d.value+l
return parseFloat(Math.min(a,c.value).toFixed(v.value))}function B(e){var t
const a="vertical"===l.direction,o=a?"top":"left",n=a?"height":"width",r=a?"clientY":"clientX",{[o]:i,[n]:d}=null==(t=N.value)?void 0:t.$el.getBoundingClientRect(),v=function(e,t){return"touches"in e&&e.touches.length?e.touches[0][t]:"changedTouches"in e&&e.changedTouches.length?e.changedTouches[0][t]:e[t]}(e,r)
let p=Math.min(Math.max((v-i-x.value)/d,0),1)||0
return(a||"rtl"===s.value)&&(p=1-p),I(u.value+p*(c.value-u.value))}let $=!1
const A=e=>{$||(x.value=0,a(B(e))),k.value=!1,$=!1,x.value=0},E=e=>{_.value=n(e),_.value&&(_.value.focus(),k.value=!0,_.value.contains(e.target)?($=!0,x.value=Mr(e,_.value,l.direction)):(x.value=0,o(B(e))))},R={passive:!0,capture:!0}
function T(e){$=!0,o(B(e))}function L(e){e.stopPropagation(),e.preventDefault(),A(e),window.removeEventListener("mousemove",T,R),window.removeEventListener("mouseup",L)}function P(e){var t
A(e),window.removeEventListener("touchmove",T,R),null==(t=e.target)||t.removeEventListener("touchend",P)}const O=e=>{const t=(e-u.value)/(c.value-u.value)*100
return C(isNaN(t)?0:t,0,100)},F=t.computed((()=>l.ticks?Array.isArray(l.ticks)?l.ticks.map((e=>({value:e,position:O(e),label:e.toString()}))):Object.keys(l.ticks).map((e=>({value:parseFloat(e),position:O(parseFloat(e)),label:l.ticks[e]}))):h.value!==1/0?m(h.value+1).map((e=>{const t=u.value+e*d.value
return{value:t,position:O(t)}})):[])),M=t.computed((()=>F.value.some((e=>{let{label:t}=e
return!!t})))),z={activeThumbRef:_,color:t.toRef(l,"color"),decimals:v,disabled:y,direction:t.toRef(l,"direction"),elevation:t.toRef(l,"elevation"),hasLabels:M,horizontalDirection:s,isReversed:i,min:u,max:c,mousePressed:k,numTicks:h,onSliderMousedown:function(e){e.preventDefault(),E(e),window.addEventListener("mousemove",T,R),window.addEventListener("mouseup",L,{passive:!1})},onSliderTouchstart:function(e){var t
E(e),window.addEventListener("touchmove",T,R),null==(t=e.target)||t.addEventListener("touchend",P,{passive:!1})},parsedTicks:F,parseMouseMove:B,position:O,readonly:t.toRef(l,"readonly"),rounded:t.toRef(l,"rounded"),roundValue:I,showTicks:t.toRef(l,"showTicks"),startOffset:x,step:d,thumbSize:p,thumbColor:V,thumbLabel:t.toRef(l,"thumbLabel"),ticks:t.toRef(l,"ticks"),tickSize:f,trackColor:S,trackContainerRef:N,trackFillColor:w,trackSize:g,vertical:b}
return t.provide(Fr,z),z},jr=je({name:"VSliderThumb",directives:{Ripple:wa},props:{focused:Boolean,max:{type:Number,required:!0},min:{type:Number,required:!0},modelValue:{type:Number,required:!0},position:{type:Number,required:!0},ripple:{type:Boolean,default:!0}},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a,emit:o}=l
const n=t.inject(Fr)
if(!n)throw new Error("[Vuetify] v-slider-thumb must be used inside v-slider or v-range-slider")
const{thumbColor:r,step:i,vertical:s,disabled:u,thumbSize:c,thumbLabel:d,direction:v,readonly:p,elevation:f,isReversed:m,horizontalDirection:h,mousePressed:y,decimals:V}=n,{textColorClasses:S,textColorStyles:w}=Vl(r),{pageup:k,pagedown:x,end:C,home:N,left:_,right:I,down:B,up:$}=b,A=[k,x,C,N,_,I,B,$],E=t.computed((()=>i.value?[1,2,3]:[1,5,10]))
function R(t){const l=function(t,l){if(!A.includes(t.key))return
t.preventDefault()
const a=i.value||.1,o=(e.max-e.min)/a
if([_,I,B,$].includes(t.key)){const e=("rtl"===h.value?[_,$]:[I,$]).includes(t.key)?1:-1,o=t.shiftKey?2:t.ctrlKey?1:0
l+=e*a*E.value[o]}else t.key===N?l=e.min:t.key===C?l=e.max:l-=(t.key===x?1:-1)*a*(o>100?o/10:10)
return Math.max(e.min,Math.min(e.max,l))}(t,e.modelValue)
null!=l&&o("update:modelValue",l)}return Ke((()=>{var l
const o=g(s.value||m.value?100-e.position:e.position,"%"),{elevationClasses:n}=gl(t.computed((()=>u.value?void 0:f.value)))
return t.createVNode("div",{class:["v-slider-thumb",{"v-slider-thumb--focused":e.focused,"v-slider-thumb--pressed":e.focused&&y.value}],style:{"--v-slider-thumb-position":o,"--v-slider-thumb-size":g(c.value)},role:"slider",tabindex:u.value?-1:0,"aria-valuemin":e.min,"aria-valuemax":e.max,"aria-valuenow":e.modelValue,"aria-readonly":p.value,"aria-orientation":v.value,onKeydown:p.value?void 0:R},[t.createVNode("div",{class:["v-slider-thumb__surface",S.value,n.value],style:{...w.value}},null),t.withDirectives(t.createVNode("div",{class:["v-slider-thumb__ripple",S.value],style:w.value},null),[[t.resolveDirective("ripple"),e.ripple,null,{circle:!0,center:!0}]]),t.createVNode(Yt,{origin:"bottom center"},{default:()=>[t.withDirectives(t.createVNode("div",{class:"v-slider-thumb__label-container"},[t.createVNode("div",{class:["v-slider-thumb__label"]},[t.createVNode("div",null,[(null==(l=a["thumb-label"])?void 0:l.call(a,{modelValue:e.modelValue}))??e.modelValue.toFixed(i.value?V.value:1)])])]),[[t.vShow,d.value&&e.focused||"always"===d.value]])]})])})),{}}}),Hr=je({name:"VSliderTrack",props:{start:{type:Number,required:!0},stop:{type:Number,required:!0}},emits:{},setup(e,l){let{slots:a}=l
const o=t.inject(Fr)
if(!o)throw new Error("[Vuetify] v-slider-track must be inside v-slider or v-range-slider")
const{color:n,horizontalDirection:r,parsedTicks:i,rounded:s,showTicks:u,tickSize:c,trackColor:d,trackFillColor:v,trackSize:p,vertical:f,min:m,max:h}=o,{roundedClasses:y}=yl(s),{backgroundColorClasses:b,backgroundColorStyles:V}=Sl(v),{backgroundColorClasses:S,backgroundColorStyles:w}=Sl(d),k=t.computed((()=>"inset-"+(f.value?"block-end":"inline-start"))),x=t.computed((()=>f.value?"height":"width")),C=t.computed((()=>({[k.value]:"0%",[x.value]:"100%"}))),N=t.computed((()=>e.stop-e.start)),_=t.computed((()=>({[k.value]:g(e.start,"%"),[x.value]:g(N.value,"%")}))),I=t.computed((()=>(f.value?i.value.slice().reverse():i.value).map(((l,o)=>{var n
const r=f.value?"bottom":"margin-inline-start",i=l.value!==m.value&&l.value!==h.value?g(l.position,"%"):void 0
return t.createVNode("div",{key:l.value,class:["v-slider-track__tick",{"v-slider-track__tick--filled":l.position>=e.start&&l.position<=e.stop,"v-slider-track__tick--first":l.value===m.value,"v-slider-track__tick--last":l.value===h.value}],style:{[r]:i}},[(l.label||a["tick-label"])&&t.createVNode("div",{class:"v-slider-track__tick-label"},[(null==(n=a["tick-label"])?void 0:n.call(a,{tick:l,index:o}))??l.label])])}))))
return Ke((()=>t.createVNode("div",{class:["v-slider-track",y.value],style:{"--v-slider-track-size":g(p.value),"--v-slider-tick-size":g(c.value),direction:f.value?void 0:r.value}},[t.createVNode("div",{class:["v-slider-track__background",S.value,{"v-slider-track__background--opacity":!!n.value||!v.value}],style:{...C.value,...w.value}},null),t.createVNode("div",{class:["v-slider-track__fill",b.value],style:{..._.value,...V.value}},null),u.value&&t.createVNode("div",{class:["v-slider-track__ticks",{"v-slider-track__ticks--always-show":"always"===u.value}]},[I.value])]))),{}}}),Wr=je({name:"VSlider",props:{...Xa(),...zr(),...no(),modelValue:{type:[Number,String],default:0}},emits:{"update:focused":e=>!0,"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=t.ref(),{min:n,max:r,mousePressed:i,roundValue:s,onSliderMousedown:u,onSliderTouchstart:c,trackContainerRef:d,position:v,hasLabels:p,readonly:f}=Dr({props:e,handleSliderMouseUp:e=>m.value=s(e),handleMouseMove:e=>m.value=s(e),getActiveThumb:()=>{var e
return null==(e=o.value)?void 0:e.$el}}),m=Vt(e,"modelValue",void 0,(e=>{const t="string"==typeof e?parseFloat(e):null==e?n.value:e
return s(t)})),{isFocused:g,focus:h,blur:y}=Ga(e),b=t.computed((()=>v(m.value)))
return Ke((()=>{const[l,s]=io(e),v=!!(e.label||a.label||a.prepend)
return t.createVNode(ro,t.mergeProps({class:["v-slider",{"v-slider--has-labels":!!a["tick-label"]||p.value,"v-slider--focused":g.value,"v-slider--pressed":i.value,"v-slider--disabled":e.disabled}]},l,{focused:g.value}),{...a,prepend:v?l=>{var o,n
return t.createVNode(t.Fragment,null,[(null==(o=a.label)?void 0:o.call(a,l))??e.label?t.createVNode(Ua,{id:l.id,class:"v-slider__label",text:e.label},null):void 0,null==(n=a.prepend)?void 0:n.call(a,l)])}:void 0,default:l=>{let{id:i,messagesId:s}=l
return t.createVNode("div",{class:"v-slider__container",onMousedown:f.value?void 0:u,onTouchstartPassive:f.value?void 0:c},[t.createVNode("input",{id:i.value,name:e.name||i.value,disabled:e.disabled,readonly:e.readonly,tabindex:"-1",value:m.value},null),t.createVNode(Hr,{ref:d,start:0,stop:b.value},{"tick-label":a["tick-label"]}),t.createVNode(jr,{ref:o,"aria-describedby":s.value,focused:g.value,min:n.value,max:r.value,modelValue:m.value,"onUpdate:modelValue":e=>m.value=e,position:b.value,elevation:e.elevation,onFocus:h,onBlur:y},{"thumb-label":a["thumb-label"]})])}})})),{}}}),Ur=je({name:"VColorPickerPreview",props:{color:{type:Object},disabled:Boolean,hideAlpha:Boolean},emits:{"update:color":e=>!0},setup(e,l){let{emit:a}=l
return Ke((()=>{var l,o
return t.createVNode("div",{class:["v-color-picker-preview",{"v-color-picker-preview--hide-alpha":e.hideAlpha}]},[t.createVNode("div",{class:"v-color-picker-preview__dot"},[t.createVNode("div",{style:{background:Se(e.color??Ar)}},null)]),t.createVNode("div",{class:"v-color-picker-preview__sliders"},[t.createVNode(Wr,{class:"v-color-picker-preview__track v-color-picker-preview__hue",modelValue:null==(l=e.color)?void 0:l.h,"onUpdate:modelValue":t=>a("update:color",{...e.color??Ar,h:t}),step:0,min:0,max:360,disabled:e.disabled,thumbSize:14,trackSize:8,trackFillColor:"white",hideDetails:!0},null),!e.hideAlpha&&t.createVNode(Wr,{class:"v-color-picker-preview__track v-color-picker-preview__alpha",modelValue:null==(o=e.color)?void 0:o.a,"onUpdate:modelValue":t=>a("update:color",{...e.color??Ar,a:t}),step:0,min:0,max:1,disabled:e.disabled,thumbSize:14,trackSize:8,trackFillColor:"white",hideDetails:!0},null)])])})),{}}}),Yr=Object.freeze({base:"#f44336",lighten5:"#ffebee",lighten4:"#ffcdd2",lighten3:"#ef9a9a",lighten2:"#e57373",lighten1:"#ef5350",darken1:"#e53935",darken2:"#d32f2f",darken3:"#c62828",darken4:"#b71c1c",accent1:"#ff8a80",accent2:"#ff5252",accent3:"#ff1744",accent4:"#d50000"}),Xr=Object.freeze({base:"#e91e63",lighten5:"#fce4ec",lighten4:"#f8bbd0",lighten3:"#f48fb1",lighten2:"#f06292",lighten1:"#ec407a",darken1:"#d81b60",darken2:"#c2185b",darken3:"#ad1457",darken4:"#880e4f",accent1:"#ff80ab",accent2:"#ff4081",accent3:"#f50057",accent4:"#c51162"}),Gr=Object.freeze({base:"#9c27b0",lighten5:"#f3e5f5",lighten4:"#e1bee7",lighten3:"#ce93d8",lighten2:"#ba68c8",lighten1:"#ab47bc",darken1:"#8e24aa",darken2:"#7b1fa2",darken3:"#6a1b9a",darken4:"#4a148c",accent1:"#ea80fc",accent2:"#e040fb",accent3:"#d500f9",accent4:"#aa00ff"}),qr=Object.freeze({base:"#673ab7",lighten5:"#ede7f6",lighten4:"#d1c4e9",lighten3:"#b39ddb",lighten2:"#9575cd",lighten1:"#7e57c2",darken1:"#5e35b1",darken2:"#512da8",darken3:"#4527a0",darken4:"#311b92",accent1:"#b388ff",accent2:"#7c4dff",accent3:"#651fff",accent4:"#6200ea"}),Kr=Object.freeze({base:"#3f51b5",lighten5:"#e8eaf6",lighten4:"#c5cae9",lighten3:"#9fa8da",lighten2:"#7986cb",lighten1:"#5c6bc0",darken1:"#3949ab",darken2:"#303f9f",darken3:"#283593",darken4:"#1a237e",accent1:"#8c9eff",accent2:"#536dfe",accent3:"#3d5afe",accent4:"#304ffe"}),Zr=Object.freeze({base:"#2196f3",lighten5:"#e3f2fd",lighten4:"#bbdefb",lighten3:"#90caf9",lighten2:"#64b5f6",lighten1:"#42a5f5",darken1:"#1e88e5",darken2:"#1976d2",darken3:"#1565c0",darken4:"#0d47a1",accent1:"#82b1ff",accent2:"#448aff",accent3:"#2979ff",accent4:"#2962ff"}),Jr=Object.freeze({base:"#03a9f4",lighten5:"#e1f5fe",lighten4:"#b3e5fc",lighten3:"#81d4fa",lighten2:"#4fc3f7",lighten1:"#29b6f6",darken1:"#039be5",darken2:"#0288d1",darken3:"#0277bd",darken4:"#01579b",accent1:"#80d8ff",accent2:"#40c4ff",accent3:"#00b0ff",accent4:"#0091ea"}),Qr=Object.freeze({base:"#00bcd4",lighten5:"#e0f7fa",lighten4:"#b2ebf2",lighten3:"#80deea",lighten2:"#4dd0e1",lighten1:"#26c6da",darken1:"#00acc1",darken2:"#0097a7",darken3:"#00838f",darken4:"#006064",accent1:"#84ffff",accent2:"#18ffff",accent3:"#00e5ff",accent4:"#00b8d4"}),ei=Object.freeze({base:"#009688",lighten5:"#e0f2f1",lighten4:"#b2dfdb",lighten3:"#80cbc4",lighten2:"#4db6ac",lighten1:"#26a69a",darken1:"#00897b",darken2:"#00796b",darken3:"#00695c",darken4:"#004d40",accent1:"#a7ffeb",accent2:"#64ffda",accent3:"#1de9b6",accent4:"#00bfa5"}),ti=Object.freeze({base:"#4caf50",lighten5:"#e8f5e9",lighten4:"#c8e6c9",lighten3:"#a5d6a7",lighten2:"#81c784",lighten1:"#66bb6a",darken1:"#43a047",darken2:"#388e3c",darken3:"#2e7d32",darken4:"#1b5e20",accent1:"#b9f6ca",accent2:"#69f0ae",accent3:"#00e676",accent4:"#00c853"}),li=Object.freeze({base:"#8bc34a",lighten5:"#f1f8e9",lighten4:"#dcedc8",lighten3:"#c5e1a5",lighten2:"#aed581",lighten1:"#9ccc65",darken1:"#7cb342",darken2:"#689f38",darken3:"#558b2f",darken4:"#33691e",accent1:"#ccff90",accent2:"#b2ff59",accent3:"#76ff03",accent4:"#64dd17"}),ai=Object.freeze({base:"#cddc39",lighten5:"#f9fbe7",lighten4:"#f0f4c3",lighten3:"#e6ee9c",lighten2:"#dce775",lighten1:"#d4e157",darken1:"#c0ca33",darken2:"#afb42b",darken3:"#9e9d24",darken4:"#827717",accent1:"#f4ff81",accent2:"#eeff41",accent3:"#c6ff00",accent4:"#aeea00"}),oi=Object.freeze({base:"#ffeb3b",lighten5:"#fffde7",lighten4:"#fff9c4",lighten3:"#fff59d",lighten2:"#fff176",lighten1:"#ffee58",darken1:"#fdd835",darken2:"#fbc02d",darken3:"#f9a825",darken4:"#f57f17",accent1:"#ffff8d",accent2:"#ffff00",accent3:"#ffea00",accent4:"#ffd600"}),ni=Object.freeze({base:"#ffc107",lighten5:"#fff8e1",lighten4:"#ffecb3",lighten3:"#ffe082",lighten2:"#ffd54f",lighten1:"#ffca28",darken1:"#ffb300",darken2:"#ffa000",darken3:"#ff8f00",darken4:"#ff6f00",accent1:"#ffe57f",accent2:"#ffd740",accent3:"#ffc400",accent4:"#ffab00"}),ri=Object.freeze({base:"#ff9800",lighten5:"#fff3e0",lighten4:"#ffe0b2",lighten3:"#ffcc80",lighten2:"#ffb74d",lighten1:"#ffa726",darken1:"#fb8c00",darken2:"#f57c00",darken3:"#ef6c00",darken4:"#e65100",accent1:"#ffd180",accent2:"#ffab40",accent3:"#ff9100",accent4:"#ff6d00"}),ii=Object.freeze({base:"#ff5722",lighten5:"#fbe9e7",lighten4:"#ffccbc",lighten3:"#ffab91",lighten2:"#ff8a65",lighten1:"#ff7043",darken1:"#f4511e",darken2:"#e64a19",darken3:"#d84315",darken4:"#bf360c",accent1:"#ff9e80",accent2:"#ff6e40",accent3:"#ff3d00",accent4:"#dd2c00"}),si=Object.freeze({base:"#795548",lighten5:"#efebe9",lighten4:"#d7ccc8",lighten3:"#bcaaa4",lighten2:"#a1887f",lighten1:"#8d6e63",darken1:"#6d4c41",darken2:"#5d4037",darken3:"#4e342e",darken4:"#3e2723"}),ui=Object.freeze({base:"#607d8b",lighten5:"#eceff1",lighten4:"#cfd8dc",lighten3:"#b0bec5",lighten2:"#90a4ae",lighten1:"#78909c",darken1:"#546e7a",darken2:"#455a64",darken3:"#37474f",darken4:"#263238"}),ci=Object.freeze({base:"#9e9e9e",lighten5:"#fafafa",lighten4:"#f5f5f5",lighten3:"#eeeeee",lighten2:"#e0e0e0",lighten1:"#bdbdbd",darken1:"#757575",darken2:"#616161",darken3:"#424242",darken4:"#212121"}),di=Object.freeze({black:"#000000",white:"#ffffff",transparent:"#ffffff00"})
var vi=Object.freeze({red:Yr,pink:Xr,purple:Gr,deepPurple:qr,indigo:Kr,blue:Zr,lightBlue:Jr,cyan:Qr,teal:ei,green:ti,lightGreen:li,lime:ai,yellow:oi,amber:ni,orange:ri,deepOrange:ii,brown:si,blueGrey:ui,grey:ci,shades:di})
const pi=je({name:"VColorPickerSwatches",props:{swatches:{type:Array,default:()=>function(e){return Object.keys(e).map((t=>{const l=e[t]
return l.base?[l.base,l.darken4,l.darken3,l.darken2,l.darken1,l.lighten1,l.lighten2,l.lighten3,l.lighten4,l.lighten5]:[l.black,l.white,l.transparent]}))}(vi)},disabled:Boolean,color:Object,maxHeight:[Number,String]},emits:{"update:color":e=>!0},setup(e,l){let{emit:a}=l
return Ke((()=>t.createVNode("div",{class:"v-color-picker-swatches",style:{maxHeight:g(e.maxHeight)}},[t.createVNode("div",null,[e.swatches.map((l=>t.createVNode("div",{class:"v-color-picker-swatches__swatch"},[l.map((l=>{const o=$r(l)
return t.createVNode("div",{class:"v-color-picker-swatches__color",onClick:()=>o&&a("update:color",o)},[t.createVNode("div",{style:{background:l}},[e.color&&v(e.color,o)?t.createVNode(la,{size:"x-small",icon:"$success",color:$e(l,"#FFFFFF")>2?"white":"black"},null):void 0])])}))])))])]))),{}}}),fi=je({name:"VSheet",props:{color:String,...pl(),...al(),...ml(),...xa(),...Aa(),...hl(),...dl(),...pt()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{backgroundColorClasses:n,backgroundColorStyles:r}=Sl(t.toRef(e,"color")),{borderClasses:i}=fl(e),{dimensionStyles:s}=ol(e),{elevationClasses:u}=gl(e),{locationStyles:c}=Ca(e),{positionClasses:d}=Ea(e),{roundedClasses:v}=yl(e)
return()=>t.createVNode(e.tag,{class:["v-sheet",o.value,n.value,i.value,u.value,d.value,v.value],style:[r.value,s.value,c.value]},a)}}),mi=je({name:"VColorPicker",props:{canvasHeight:{type:[String,Number],default:150},disabled:Boolean,dotSize:{type:[Number,String],default:10},hideCanvas:Boolean,hideSliders:Boolean,hideInputs:Boolean,mode:{type:String,default:"rgba",validator:e=>Object.keys(Lr).includes(e)},modes:{type:Array,default:()=>Object.keys(Lr),validator:e=>Array.isArray(e)&&e.every((e=>Object.keys(Lr).includes(e)))},showSwatches:Boolean,swatches:Array,swatchesMaxHeight:{type:[Number,String],default:150},modelValue:{type:[Object,String]},width:{type:[Number,String],default:300},...ml(),...hl(),...pt()},emits:{"update:modelValue":e=>!0,"update:mode":e=>!0},setup(e){const l=Vt(e,"mode"),a=t.ref(null),o=Vt(e,"modelValue",void 0,(e=>{let t=$r(e)
return t?(a.value&&(t={...t,h:a.value.h},a.value=null),t):null}),(t=>t?function(e,t){if(null==t||"string"==typeof t){const t=Ne(e)
return 1===e.a?t.slice(0,7):t}if("object"==typeof t){let l
return Br(t,["r","g","b"])?l=he(e):Br(t,["h","s","l"])?l=be(e):Br(t,["h","s","v"])&&(l=e),function(e,t){if(t){const{a:t,...l}=e
return l}return e}(l,!Br(t,["a"]))}return e}(t,e.modelValue):null)),n=e=>{o.value=e,a.value=e}
return t.onMounted((()=>{e.modes.includes(l.value)||(l.value=e.modes[0])})),Ke((()=>t.createVNode(fi,{rounded:e.rounded,elevation:e.elevation,theme:e.theme,class:["v-color-picker"],style:{"--v-color-picker-color-hsv":Se({...o.value??Ar,a:1})},maxWidth:e.width},{default:()=>[!e.hideCanvas&&t.createVNode(_r,{key:"canvas",color:o.value,"onUpdate:color":n,disabled:e.disabled,dotSize:e.dotSize,width:e.width,height:e.canvasHeight},null),(!e.hideSliders||!e.hideInputs)&&t.createVNode("div",{key:"controls",class:"v-color-picker__controls"},[!e.hideSliders&&t.createVNode(Ur,{key:"preview",color:o.value,"onUpdate:color":n,hideAlpha:!l.value.endsWith("a"),disabled:e.disabled},null),!e.hideInputs&&t.createVNode(Or,{key:"edit",modes:e.modes,mode:l.value,"onUpdate:mode":e=>l.value=e,color:o.value,"onUpdate:color":n,disabled:e.disabled},null)]),e.showSwatches&&t.createVNode(pi,{key:"swatches",color:o.value,"onUpdate:color":n,maxHeight:e.swatchesMaxHeight,swatches:e.swatches,disabled:e.disabled},null)]}))),{}}})
const gi=He()({name:"VCombobox",props:{delimiters:Array,...Jn({filterKeys:["title"]}),...qn({hideNoData:!0,returnObject:!0}),...w(po({modelValue:null}),["validationValue","dirty","appendInnerIcon"]),...sl({transition:!1})},emits:{"update:modelValue":e=>!0,"update:search":e=>!0,"update:menu":e=>!0},setup(e,l){var a
let{emit:o,slots:n}=l
const{t:r}=At(),i=t.ref(),s=t.ref(!1),u=t.ref(!0),c=Vt(e,"menu"),d=t.ref(-1),v=t.computed((()=>{var e
return null==(e=i.value)?void 0:e.color})),{items:p,transformIn:f,transformOut:m}=tn(e),{textColorClasses:g,textColorStyles:h}=Vl(v),y=Vt(e,"modelValue",[],(e=>f(x(e||[]))),(t=>{const l=m(t)
return e.multiple?l:l[0]??null})),b=lo(),V=t.ref(e.multiple?"":(null==(a=y.value[0])?void 0:a.title)??""),S=t.computed({get:()=>V.value,set:t=>{var l
if(V.value=t,e.multiple||(y.value=[Qo(e,t)]),t&&e.multiple&&null!=(l=e.delimiters)&&l.length){const l=t.split(new RegExp(`(?:${e.delimiters.join("|")})+`))
l.length>1&&(l.forEach((t=>{(t=t.trim())&&T(Qo(e,t))})),V.value="")}t||(d.value=-1),s.value&&(c.value=!0),u.value=!t}})
t.watch(V,(e=>{o("update:search",e)})),t.watch(y,(t=>{var l
e.multiple||(V.value=(null==(l=t[0])?void 0:l.title)??"")}))
const{filteredItems:w,getMatches:k}=Qn(e,p,t.computed((()=>u.value?void 0:S.value))),C=t.computed((()=>y.value.map((t=>p.value.find((l=>e.valueComparator(l.value,t.value)))||t)))),N=t.computed((()=>e.hideSelected?w.value.filter((e=>!C.value.some((t=>t.value===e.value)))):w.value)),_=t.computed((()=>C.value.map((e=>e.props.value)))),I=t.computed((()=>C.value[d.value])),B=t.ref()
function $(t){y.value=[],e.openOnClear&&(c.value=!0)}function A(){e.hideNoData&&!p.value.length||e.readonly||null!=b&&b.isReadonly.value||(c.value=!0)}function E(l){if(e.readonly||null!=b&&b.isReadonly.value)return
const a=i.value.selectionStart,o=_.value.length
var n
if((d.value>-1||["Enter","ArrowDown","ArrowUp"].includes(l.key))&&l.preventDefault(),["Enter","ArrowDown"].includes(l.key)&&(c.value=!0),["Escape"].includes(l.key)&&(c.value=!1),["Enter","Escape","Tab"].includes(l.key)&&(u.value=!0),"ArrowDown"===l.key)null==(n=B.value)||n.focus("next")
else if("ArrowUp"===l.key){var r
null==(r=B.value)||r.focus("prev")}if(e.multiple){if(["Backspace","Delete"].includes(l.key)){if(d.value<0)return void("Backspace"!==l.key||S.value||(d.value=o-1))
T(I.value),t.nextTick((()=>!I.value&&(d.value=o-2)))}if("ArrowLeft"===l.key){if(d.value<0&&a>0)return
const e=d.value>-1?d.value-1:o-1
C.value[e]?d.value=e:(d.value=-1,i.value.setSelectionRange(S.value.length,S.value.length))}if("ArrowRight"===l.key){if(d.value<0)return
const e=d.value+1
C.value[e]?d.value=e:(d.value=-1,i.value.setSelectionRange(0,0))}"Enter"===l.key&&S.value&&(T(Qo(e,S.value)),S.value="")}}function R(){s.value&&(u.value=!0)}function T(l){if(e.multiple){const t=_.value.findIndex((t=>e.valueComparator(t,l.value)))
if(-1===t)y.value=[...y.value,l]
else{const e=[...y.value]
e.splice(t,1),y.value=e}S.value=""}else y.value=[l],V.value=l.title,t.nextTick((()=>{c.value=!1,u.value=!0}))}function L(e){s.value=!0}function P(e){var t
null==e.relatedTarget&&(null==(t=i.value)||t.focus())}return t.watch(w,(t=>{!t.length&&e.hideNoData&&(c.value=!1)})),t.watch(s,(t=>{if(t)d.value=-1
else{if(c.value=!1,!e.multiple||!S.value)return
y.value=[...y.value,Qo(e,S.value)],S.value=""}})),Ke((()=>{const l=!(!e.chips&&!n.chip),a=!!(!e.hideNoData||N.value.length||n.prepend||n.append||n["no-data"]),[o]=mo(e)
return t.createVNode(fo,t.mergeProps({ref:i},o,{modelValue:S.value,"onUpdate:modelValue":[e=>S.value=e,e=>{null==e&&(y.value=[])}],validationValue:y.externalValue,dirty:y.value.length>0,class:["v-combobox",{"v-combobox--active-menu":c.value,"v-combobox--chips":!!e.chips,"v-combobox--selecting-index":d.value>-1,["v-combobox--"+(e.multiple?"multiple":"single")]:!0}],appendInnerIcon:e.items.length?e.menuIcon:void 0,readonly:e.readonly,"onClick:clear":$,"onClick:control":A,"onClick:input":A,onFocus:()=>s.value=!0,onBlur:()=>s.value=!1,onKeydown:E}),{...n,default:()=>{var o,i,s
return t.createVNode(t.Fragment,null,[t.createVNode(Gn,t.mergeProps({modelValue:c.value,"onUpdate:modelValue":e=>c.value=e,activator:"parent",contentClass:"v-combobox__content",eager:e.eager,maxHeight:310,openOnClick:!1,closeOnContentClick:!1,transition:e.transition,onAfterLeave:R},e.menuProps),{default:()=>[a&&t.createVNode(on,{ref:B,selected:_.value,selectStrategy:e.multiple?"independent":"single-independent",onMousedown:e=>e.preventDefault(),onFocusin:L,onFocusout:P},{default:()=>[!N.value.length&&!e.hideNoData&&((null==(o=n["no-data"])?void 0:o.call(n))??t.createVNode(qo,{title:r(e.noDataText)},null)),null==(i=n["prepend-item"])?void 0:i.call(n),N.value.map(((l,a)=>{var o
return(null==(o=n.item)?void 0:o.call(n,{item:l,index:a,props:t.mergeProps(l.props,{onClick:()=>T(l)})}))??t.createVNode(qo,t.mergeProps({key:a},l.props,{onClick:()=>T(l)}),{prepend:l=>{let{isSelected:a}=l
return e.multiple&&!e.hideSelected?t.createVNode(ko,{modelValue:a,ripple:!1},null):void 0},title:()=>{var e,a
return u.value?l.title:function(e,l,a){if(null==l)return e
if(Array.isArray(l))throw new Error("Multiple matches is not implemented")
return"number"==typeof l&&~l?t.createVNode(t.Fragment,null,[t.createVNode("span",{class:"v-combobox__unmask"},[e.substr(0,l)]),t.createVNode("span",{class:"v-combobox__mask"},[e.substr(l,a)]),t.createVNode("span",{class:"v-combobox__unmask"},[e.substr(l+a)])]):e}(l.title,null==(e=k(l))?void 0:e.title,(null==(a=S.value)?void 0:a.length)??0)}})})),null==(s=n["append-item"])?void 0:s.call(n)]})]}),C.value.map(((a,o)=>{const r={"onClick:close":function(e){e.stopPropagation(),e.preventDefault(),T(a)},modelValue:!0,"onUpdate:modelValue":void 0}
return t.createVNode("div",{key:a.value,class:["v-combobox__selection",o===d.value&&["v-combobox__selection--selected",g.value]],style:o===d.value?h.value:{}},[l?t.createVNode(Lt,{defaults:{VChip:{closable:e.closableChips,size:"small",text:a.title}}},{default:()=>[n.chip?n.chip({item:a,index:o,props:r}):t.createVNode(Bo,r,null)]}):n.selection?n.selection({item:a,index:o}):t.createVNode("span",{class:"v-combobox__selection-text"},[a.title,e.multiple&&o<C.value.length-1&&t.createVNode("span",{class:"v-combobox__selection-comma"},[t.createTextVNode(",")])])])}))])}})})),co({isFocused:s,isPristine:u,menu:c,search:S,selectionIndex:d,filteredItems:w,select:T},i)}}),hi=He()({name:"VDialog",props:{fullscreen:Boolean,retainFocus:{type:Boolean,default:!0},scrollable:Boolean,...Un({origin:"center center",scrollStrategy:"block",transition:{component:Mt},zIndex:2400})},emits:{"update:modelValue":e=>!0},setup(e,a){let{slots:o}=a
const n=Vt(e,"modelValue"),{scopeId:r}=Pn(),i=t.ref()
function s(e){var t,l
const a=e.relatedTarget,o=e.target
if(a!==o&&null!=(t=i.value)&&t.contentEl&&null!=(l=i.value)&&l.globalTop&&![document,i.value.contentEl].includes(o)&&!i.value.contentEl.contains(o)){const e=[...i.value.contentEl.querySelectorAll('button, [href], input:not([type="hidden"]), select, textarea, [tabindex]:not([tabindex="-1"])')].filter((e=>!e.hasAttribute("disabled")&&!e.matches('[tabindex="-1"]')))
if(!e.length)return
const t=e[0],l=e[e.length-1]
a===t?l.focus():t.focus()}}l&&t.watch((()=>n.value&&e.retainFocus),(e=>{e?document.addEventListener("focusin",s):document.removeEventListener("focusin",s)}),{immediate:!0}),t.watch(n,(async e=>{var l,a;(await t.nextTick(),e)?null==(l=i.value.contentEl)||l.focus({preventScroll:!0}):null==(a=i.value.activatorEl)||a.focus({preventScroll:!0})}))
const u=t.computed((()=>t.mergeProps({"aria-haspopup":"dialog","aria-expanded":String(n.value)},e.activatorProps)))
return Ke((()=>{const[l]=Xn(e)
return t.createVNode(Yn,t.mergeProps({ref:i,class:["v-dialog",{"v-dialog--fullscreen":e.fullscreen,"v-dialog--scrollable":e.scrollable}]},l,{modelValue:n.value,"onUpdate:modelValue":e=>n.value=e,"aria-role":"dialog","aria-modal":"true",activatorProps:u.value},r),{activator:o.activator,default:function(){for(var e,l=arguments.length,a=new Array(l),n=0;n<l;n++)a[n]=arguments[n]
return t.createVNode(Lt,{root:!0},{default:()=>[null==(e=o.default)?void 0:e.call(o,...a)]})}})})),co({},i)}}),yi=Symbol.for("vuetify:v-expansion-panel"),bi=["default","accordion","inset","popout"],Vi=je({name:"VExpansionPanels",props:{color:String,variant:{type:String,default:"default",validator:e=>bi.includes(e)},readonly:Boolean,...Tl(),...dl(),...pt()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
Ol(e,yi)
const{themeClasses:o}=gt(e),n=t.computed((()=>e.variant&&`v-expansion-panels--variant-${e.variant}`))
return Me({VExpansionPanel:{color:t.toRef(e,"color")},VExpansionPanelTitle:{readonly:t.toRef(e,"readonly")}}),Ke((()=>t.createVNode(e.tag,{class:["v-expansion-panels",o.value,n.value]},a))),{}}}),Si=De({color:String,expandIcon:{type:Hl,default:"$expand"},collapseIcon:{type:Hl,default:"$collapse"},hideActions:Boolean,ripple:{type:[Boolean,Object],default:!1},readonly:Boolean},"v-expansion-panel-title"),wi=je({name:"VExpansionPanelTitle",directives:{Ripple:wa},props:{...Si()},setup(e,l){let{slots:a}=l
const o=t.inject(yi)
if(!o)throw new Error("[Vuetify] v-expansion-panel-title needs to be placed inside v-expansion-panel")
const{backgroundColorClasses:n,backgroundColorStyles:r}=Sl(e,"color"),i=t.computed((()=>({collapseIcon:e.collapseIcon,disabled:o.disabled.value,expanded:o.isSelected.value,expandIcon:e.expandIcon,readonly:e.readonly})))
return Ke((()=>{var l
return t.withDirectives(t.createVNode("button",{class:["v-expansion-panel-title",{"v-expansion-panel-title--active":o.isSelected.value},n.value],style:r.value,type:"button",tabindex:o.disabled.value?-1:void 0,disabled:o.disabled.value,"aria-expanded":o.isSelected.value,onClick:e.readonly?void 0:o.toggle},[t.createVNode("span",{class:"v-expansion-panel-title__overlay"},null),null==(l=a.default)?void 0:l.call(a,i.value),!e.hideActions&&t.createVNode("span",{class:"v-expansion-panel-title__icon"},[a.actions?a.actions(i.value):t.createVNode(la,{icon:o.isSelected.value?e.collapseIcon:e.expandIcon},null)])]),[[t.resolveDirective("ripple"),e.ripple]])})),{}}}),ki=je({name:"VExpansionPanelText",props:{...fn()},setup(e,l){let{slots:a}=l
const o=t.inject(yi)
if(!o)throw new Error("[Vuetify] v-expansion-panel-text needs to be placed inside v-expansion-panel")
const{hasContent:n,onAfterLeave:r}=mn(e,o.isSelected)
return Ke((()=>{var e
return t.createVNode(tl,{onAfterLeave:r},{default:()=>[t.withDirectives(t.createVNode("div",{class:"v-expansion-panel-text"},[a.default&&n.value&&t.createVNode("div",{class:"v-expansion-panel-text__wrapper"},[null==(e=a.default)?void 0:e.call(a)])]),[[t.vShow,o.isSelected.value]])]})})),{}}}),xi=je({name:"VExpansionPanel",props:{title:String,text:String,bgColor:String,...ml(),...Ll(),...fn(),...hl(),...dl(),...Si()},emits:{"group:selected":e=>!0},setup(e,l){let{slots:a}=l
const o=Pl(e,yi),{backgroundColorClasses:n,backgroundColorStyles:r}=Sl(e,"bgColor"),{elevationClasses:i}=gl(e),{roundedClasses:s}=yl(e),u=t.computed((()=>(null==o?void 0:o.disabled.value)||e.disabled)),c=t.computed((()=>o.group.items.value.reduce(((e,t,l)=>(o.group.selected.value.includes(t.id)&&e.push(l),e)),[]))),d=t.computed((()=>{const e=o.group.items.value.findIndex((e=>e.id===o.id))
return!o.isSelected.value&&c.value.some((t=>t-e==1))})),v=t.computed((()=>{const e=o.group.items.value.findIndex((e=>e.id===o.id))
return!o.isSelected.value&&c.value.some((t=>t-e==-1))}))
return t.provide(yi,o),Ke((()=>{var l
const c=!(!a.text&&!e.text),p=!(!a.title&&!e.title)
return t.createVNode(e.tag,{class:["v-expansion-panel",{"v-expansion-panel--active":o.isSelected.value,"v-expansion-panel--before-active":d.value,"v-expansion-panel--after-active":v.value,"v-expansion-panel--disabled":u.value},s.value,n.value],style:r.value,"aria-expanded":o.isSelected.value},{default:()=>[t.createVNode("div",{class:["v-expansion-panel__shadow",...i.value]},null),p&&t.createVNode(wi,{key:"title",collapseIcon:e.collapseIcon,color:e.color,expandIcon:e.expandIcon,hideActions:e.hideActions,ripple:e.ripple},{default:()=>[a.title?a.title():e.title]}),c&&t.createVNode(ki,{key:"text",eager:e.eager},{default:()=>[a.text?a.text():e.text]}),null==(l=a.default)?void 0:l.call(a)]})})),{}}}),Ci=je({name:"VFileInput",inheritAttrs:!1,props:{chips:Boolean,counter:Boolean,counterSizeString:{type:String,default:"$vuetify.fileInput.counterSize"},counterString:{type:String,default:"$vuetify.fileInput.counter"},multiple:Boolean,hint:String,persistentHint:Boolean,placeholder:String,showSize:{type:[Boolean,Number],default:!1,validator:e=>"boolean"==typeof e||[1e3,1024].includes(e)},...no({prependIcon:"$file"}),modelValue:{type:Array,default:()=>[],validator:e=>x(e).every((e=>null!=e&&"object"==typeof e))},...Ka({clearable:!0})},emits:{"click:control":e=>!0,"update:modelValue":e=>!0},setup(e,l){let{attrs:a,emit:o,slots:n}=l
const{t:r}=At(),i=Vt(e,"modelValue"),s=t.computed((()=>"boolean"!=typeof e.showSize?e.showSize:void 0)),u=t.computed((()=>(i.value??[]).reduce(((e,t)=>{let{size:l=0}=t
return e+l}),0))),c=t.computed((()=>_(u.value,s.value))),d=t.computed((()=>(i.value??[]).map((t=>{const{name:l="",size:a=0}=t
return e.showSize?`${l} (${_(a,s.value)})`:l})))),v=t.computed((()=>{var t
const l=(null==(t=i.value)?void 0:t.length)??0
return e.showSize?r(e.counterSizeString,l,c.value):r(e.counterString,l)})),p=t.ref(),f=t.ref(),m=t.ref(!1),g=t.ref(),h=t.computed((()=>e.messages.length?e.messages:e.persistentHint?e.hint:""))
function y(){var e
g.value!==document.activeElement&&(null==(e=g.value)||e.focus())
m.value||(m.value=!0)}function b(t){z(e["onClick:prepend"],t),V(t)}function V(e){var t
null==(t=g.value)||t.click(),o("click:control",e)}function S(l){l.stopPropagation(),y(),t.nextTick((()=>{i.value=[],z(e["onClick:clear"],l)}))}return t.watch(i,(e=>{(!Array.isArray(e)||!e.length)&&g.value&&(g.value.value="")})),Ke((()=>{const l=!(!n.counter&&!e.counter),o=!(!l&&!n.details),[r,s]=k(a),[{modelValue:w,...x}]=io(e),[C]=Ja(e)
return t.createVNode(ro,t.mergeProps({ref:p,modelValue:i.value,"onUpdate:modelValue":e=>i.value=e,class:"v-file-input","onClick:prepend":b,"onClick:append":e["onClick:append"]},r,x,{focused:m.value,messages:h.value}),{...n,default:l=>{let{id:a,isDisabled:o,isDirty:r,isReadonly:v,isValid:p}=l
return t.createVNode(Za,t.mergeProps({ref:f,"prepend-icon":e.prependIcon,"onClick:control":V,"onClick:clear":S,"onClick:prependInner":e["onClick:prependInner"],"onClick:appendInner":e["onClick:appendInner"]},C,{id:a.value,active:r.value||m.value,dirty:r.value,focused:m.value,error:!1===p.value}),{...n,default:l=>{var a
let{props:{class:r,...p}}=l
return t.createVNode(t.Fragment,null,[t.createVNode("input",t.mergeProps({ref:g,type:"file",readonly:v.value,disabled:o.value,multiple:e.multiple,name:e.name,onClick:e=>{e.stopPropagation(),y()},onChange:e=>{if(!e.target)return
const t=e.target
i.value=[...t.files??[]]},onFocus:y,onBlur:()=>m.value=!1},p,s),null),t.createVNode("div",{class:r},[!(null==(a=i.value)||!a.length)&&(n.selection?n.selection({fileNames:d.value,totalBytes:u.value,totalBytesReadable:c.value}):e.chips?d.value.map((l=>t.createVNode(Bo,{key:l,size:"small",color:e.color},{default:()=>[l]}))):d.value.join(", "))])])}})},details:o?e=>{var a,o
return t.createVNode(t.Fragment,null,[null==(a=n.details)?void 0:a.call(n,e),l&&t.createVNode(t.Fragment,null,[t.createVNode("span",null,null),t.createVNode(so,{active:!(null==(o=i.value)||!o.length),value:v.value},n.counter)])])}:void 0})})),co({},p,f,g)}}),Ni=je({name:"VFooter",props:{app:Boolean,color:String,height:{type:[Number,String],default:"auto"},...pl(),...ml(),...et(),...hl(),...dl({tag:"footer"}),...pt()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{backgroundColorClasses:n,backgroundColorStyles:i}=Sl(t.toRef(e,"color")),{borderClasses:s}=fl(e),{elevationClasses:u}=gl(e),{roundedClasses:c}=yl(e),d=t.ref(32),{resizeRef:v}=r((e=>{e.length&&(d.value=e[0].target.clientHeight)})),p=t.computed((()=>"auto"===e.height?d.value:parseInt(e.height,10))),{layoutItemStyles:f}=lt({id:e.name,order:t.computed((()=>parseInt(e.order,10))),position:t.computed((()=>"bottom")),layoutSize:p,elementSize:t.computed((()=>"auto"===e.height?void 0:p.value)),active:t.computed((()=>e.app)),absolute:t.toRef(e,"absolute")})
return Ke((()=>t.createVNode(e.tag,{ref:v,class:["v-footer",o.value,n.value,s.value,u.value,c.value],style:[i.value,e.app?f.value:void 0]},a))),{}}}),_i=je({name:"VForm",props:{...to()},emits:{"update:modelValue":e=>!0,submit:e=>!0},setup(e,l){let{slots:a,emit:o}=l
const n=function(e){const l=Vt(e,"modelValue"),a=t.computed((()=>e.disabled)),o=t.computed((()=>e.readonly)),n=t.ref(!1),r=t.ref([]),i=t.ref([])
return t.watch(r,(()=>{let e=0,t=0
const a=[]
for(const l of r.value)!1===l.isValid?(t++,a.push({id:l.id,errorMessages:l.errorMessages})):!0===l.isValid&&e++
i.value=a,l.value=!(t>0)&&(e===r.value.length||null)}),{deep:!0}),t.provide(eo,{register:e=>{let{id:t,validate:l,reset:a,resetValidation:o}=e
r.value.some((e=>e.id===t))&&ee(`Duplicate input name "${t}"`),r.value.push({id:t,validate:l,reset:a,resetValidation:o,isValid:null,errorMessages:[]})},unregister:e=>{r.value=r.value.filter((t=>t.id!==e))},update:(e,t,l)=>{const a=r.value.find((t=>t.id===e))
a&&(a.isValid=t,a.errorMessages=l)},isDisabled:a,isReadonly:o,isValidating:n,items:r,validateOn:t.toRef(e,"validateOn")}),{errors:i,isDisabled:a,isReadonly:o,isValidating:n,items:r,validate:async function(){const t=[]
let l=!0
i.value=[],n.value=!0
for(const a of r.value){const o=await a.validate()
if(o.length>0&&(l=!1,t.push({id:a.id,errorMessages:o})),!l&&e.fastFail)break}return i.value=t,n.value=!1,{valid:l,errors:i.value}},reset:function(){r.value.forEach((e=>e.reset())),l.value=null},resetValidation:function(){r.value.forEach((e=>e.resetValidation())),i.value=[],l.value=null}}}(e),r=t.ref()
function i(e){e.preventDefault(),n.reset()}function s(e){const t=e,l=n.validate()
t.then=l.then.bind(l),t.catch=l.catch.bind(l),t.finally=l.finally.bind(l),o("submit",t),t.defaultPrevented||l.then((e=>{let{valid:t}=e
var l
t&&(null==(l=r.value)||l.submit())})),t.preventDefault()}return Ke((()=>{var e
return t.createVNode("form",{ref:r,class:"v-form",novalidate:!0,onReset:i,onSubmit:s},[null==(e=a.default)?void 0:e.call(a,n)])})),co(n,r)}}),Ii=je({name:"VContainer",props:{fluid:{type:Boolean,default:!1},...dl()},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(e.tag,{class:["v-container",{"v-container--fluid":e.fluid}]},a))),{}}}),Bi=["sm","md","lg","xl","xxl"],$i=Bi.reduce(((e,t)=>(e[t]={type:[Boolean,String,Number],default:!1},e)),{}),Ai=Bi.reduce(((e,l)=>(e["offset"+t.capitalize(l)]={type:[String,Number],default:null},e)),{}),Ei=Bi.reduce(((e,l)=>(e["order"+t.capitalize(l)]={type:[String,Number],default:null},e)),{}),Ri={col:Object.keys($i),offset:Object.keys(Ai),order:Object.keys(Ei)}
function Ti(e,t,l){let a=e
if(null!=l&&!1!==l){if(t){a+=`-${t.replace(e,"")}`}return"col"===e&&(a="v-"+a),"col"!==e||""!==l&&!0!==l?(a+=`-${l}`,a.toLowerCase()):a.toLowerCase()}}const Li=["auto","start","end","center","baseline","stretch"],Pi=je({name:"VCol",props:{cols:{type:[Boolean,String,Number],default:!1},...$i,offset:{type:[String,Number],default:null},...Ai,order:{type:[String,Number],default:null},...Ei,alignSelf:{type:String,default:null,validator:e=>Li.includes(e)},...dl()},setup(e,l){let{slots:a}=l
const o=t.computed((()=>{const t=[]
let l
for(l in Ri)Ri[l].forEach((a=>{const o=e[a],n=Ti(l,a,o)
n&&t.push(n)}))
const a=t.some((e=>e.startsWith("v-col-")))
return t.push({"v-col":!a||!e.cols,[`v-col-${e.cols}`]:e.cols,[`offset-${e.offset}`]:e.offset,[`order-${e.order}`]:e.order,[`align-self-${e.alignSelf}`]:e.alignSelf}),t}))
return()=>{var l
return t.h(e.tag,{class:o.value},null==(l=a.default)?void 0:l.call(a))}}}),Oi=["sm","md","lg","xl","xxl"],Fi=["start","end","center"],Mi=["space-between","space-around","space-evenly"]
function zi(e,l){return Oi.reduce(((a,o)=>(a[e+t.capitalize(o)]=l(),a)),{})}const Di=[...Fi,"baseline","stretch"],ji=e=>Di.includes(e),Hi=zi("align",(()=>({type:String,default:null,validator:ji}))),Wi=[...Fi,...Mi],Ui=e=>Wi.includes(e),Yi=zi("justify",(()=>({type:String,default:null,validator:Ui}))),Xi=[...Fi,...Mi,"stretch"],Gi=e=>Xi.includes(e),qi=zi("alignContent",(()=>({type:String,default:null,validator:Gi}))),Ki={align:Object.keys(Hi),justify:Object.keys(Yi),alignContent:Object.keys(qi)},Zi={align:"align",justify:"justify",alignContent:"align-content"}
function Ji(e,t,l){let a=Zi[e]
if(null!=l){if(t){a+=`-${t.replace(e,"")}`}return a+=`-${l}`,a.toLowerCase()}}const Qi=je({name:"VRow",props:{dense:Boolean,noGutters:Boolean,align:{type:String,default:null,validator:ji},...Hi,justify:{type:String,default:null,validator:Ui},...Yi,alignContent:{type:String,default:null,validator:Gi},...qi,...dl()},setup(e,l){let{slots:a}=l
const o=t.computed((()=>{const t=[]
let l
for(l in Ki)Ki[l].forEach((a=>{const o=e[a],n=Ji(l,a,o)
n&&t.push(n)}))
return t.push({"v-row--no-gutters":e.noGutters,"v-row--dense":e.dense,[`align-${e.align}`]:e.align,[`justify-${e.justify}`]:e.justify,[`align-content-${e.alignContent}`]:e.alignContent}),t}))
return()=>{var l
return t.h(e.tag,{class:["v-row",o.value]},null==(l=a.default)?void 0:l.call(a))}}}),es=We("flex-grow-1","div","VSpacer"),ts=je({name:"VHover",props:{disabled:Boolean,modelValue:{type:Boolean,default:void 0},...un()},emits:{"update:modelValue":e=>!0},setup(e,t){let{slots:l}=t
const a=Vt(e,"modelValue"),{runOpenDelay:o,runCloseDelay:n}=cn(e,(t=>!e.disabled&&(a.value=t)))
return()=>{var e
return null==(e=l.default)?void 0:e.call(l,{isHovering:a.value,props:{onMouseenter:o,onMouseleave:n}})}}}),ls=Symbol.for("vuetify:v-item-group"),as=je({name:"VItemGroup",props:{...Tl({selectedClass:"v-item--selected"}),...dl(),...pt()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{isSelected:n,select:r,next:i,prev:s,selected:u}=Ol(e,ls)
return()=>{var l
return t.createVNode(e.tag,{class:["v-item-group",o.value]},{default:()=>[null==(l=a.default)?void 0:l.call(a,{isSelected:n,select:r,next:i,prev:s,selected:u.value})]})}}}),os=He()({name:"VItem",props:Ll(),emits:{"group:selected":e=>!0},setup(e,t){let{slots:l}=t
const{isSelected:a,select:o,toggle:n,selectedClass:r,value:i,disabled:s}=Pl(e,ls)
return()=>{var e
return null==(e=l.default)?void 0:e.call(l,{isSelected:a.value,selectedClass:r.value,select:o,toggle:n,value:i.value,disabled:s.value})}}}),ns=We("v-kbd"),rs=je({name:"VLayout",props:Qe(),setup(e,l){let{slots:a}=l
const{layoutClasses:o,layoutStyles:n,getLayoutItem:r,items:i,layoutRef:s}=at(e)
return Ke((()=>{var e
return t.createVNode("div",{ref:s,class:o.value,style:n.value},[null==(e=a.default)?void 0:e.call(a)])})),{getLayoutItem:r,items:i}}}),is=je({name:"VLayoutItem",props:{position:{type:String,required:!0},size:{type:[Number,String],default:300},modelValue:Boolean,...et()},setup(e,l){let{slots:a}=l
const{layoutItemStyles:o}=lt({id:e.name,order:t.computed((()=>parseInt(e.order,10))),position:t.toRef(e,"position"),elementSize:t.toRef(e,"size"),layoutSize:t.toRef(e,"size"),active:t.toRef(e,"modelValue"),absolute:t.toRef(e,"absolute")})
return()=>{var e
return t.createVNode("div",{class:["v-layout-item"],style:o.value},[null==(e=a.default)?void 0:e.call(a)])}}}),ss=je({name:"VLazy",directives:{intersect:il},props:{modelValue:Boolean,options:{type:Object,default:()=>({root:void 0,rootMargin:void 0,threshold:void 0})},...al(),...dl(),...sl({transition:"fade-transition"})},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{dimensionStyles:o}=ol(e),n=Vt(e,"modelValue")
function r(e){n.value||(n.value=e)}return Ke((()=>{var l
return t.withDirectives(t.createVNode(e.tag,{class:"v-lazy",style:o.value},{default:()=>[n.value&&t.createVNode(ul,{transition:e.transition,appear:!0},{default:()=>[null==(l=a.default)?void 0:l.call(a)]})]}),[[t.resolveDirective("intersect"),r,e.options]])})),{}}}),us=je({name:"VLocaleProvider",props:{locale:String,fallbackLocale:String,messages:Object,rtl:{type:Boolean,default:void 0}},setup(e,l){let{slots:a}=l
const{rtlClasses:o}=Et(e)
return Ke((()=>{var e
return t.createVNode("div",{class:["v-locale-provider",o.value]},[null==(e=a.default)?void 0:e.call(a)])})),{}}}),cs=je({name:"VMain",props:{scrollable:Boolean,...dl({tag:"main"})},setup(e,l){let{slots:a}=l
const{mainStyles:o}=tt(),{ssrBootStyles:n}=wr()
return Ke((()=>{var l,r
return t.createVNode(e.tag,{class:["v-main",{"v-main--scrollable":e.scrollable}],style:[o.value,n.value]},{default:()=>[e.scrollable?t.createVNode("div",{class:"v-main__scroller"},[null==(l=a.default)?void 0:l.call(a)]):null==(r=a.default)?void 0:r.call(a)]})})),{}}})
function ds(e){return(e<0?-1:1)*Math.sqrt(Math.abs(e))*1.41421356237}function vs(e){if(e.length<2)return 0
if(2===e.length)return e[1].t===e[0].t?0:(e[1].d-e[0].d)/(e[1].t-e[0].t)
let t=0
for(let l=e.length-1;l>0;l--){if(e[l].t===e[l-1].t)continue
const a=ds(t),o=(e[l].d-e[l-1].d)/(e[l].t-e[l-1].t)
t+=(o-a)*Math.abs(o),l===e.length-1&&(t*=.5)}return 1e3*ds(t)}function ps(){const e={}
return{addMovement:function(t){Array.from(t.changedTouches).forEach((l=>{(e[l.identifier]??(e[l.identifier]=new R(20))).push([t.timeStamp,l])}))},endTouch:function(t){Array.from(t.changedTouches).forEach((t=>{delete e[t.identifier]}))},getVelocity:function(t){var l
const a=null==(l=e[t])?void 0:l.values().reverse()
if(!a)throw new Error(`No samples for touch id ${t}`)
const o=a[0],n=[],r=[]
for(const e of a){if(o[0]-e[0]>100)break
n.push({t:e[0],d:e[1].clientX}),r.push({t:e[0],d:e[1].clientY})}return{x:vs(n),y:vs(r),get direction(){const{x:e,y:t}=this,[l,a]=[Math.abs(e),Math.abs(t)]
return l>a&&e>=0?"right":l>a&&e<=0?"left":a>l&&t>=0?"down":a>l&&t<=0?"up":function(){throw new Error}()}}}}}function fs(){throw new Error}const ms=["start","end","left","right","top","bottom"],gs=je({name:"VNavigationDrawer",props:{color:String,disableResizeWatcher:Boolean,disableRouteWatcher:Boolean,expandOnHover:Boolean,floating:Boolean,modelValue:{type:Boolean,default:null},permanent:Boolean,rail:{type:Boolean,default:null},railWidth:{type:[Number,String],default:56},scrim:{type:[String,Boolean],default:!0},image:String,temporary:Boolean,touchless:Boolean,width:{type:[Number,String],default:256},location:{type:String,default:"start",validator:e=>ms.includes(e)},sticky:Boolean,...pl(),...ml(),...et(),...hl(),...dl({tag:"nav"}),...pt()},emits:{"update:modelValue":e=>!0,"update:rail":e=>!0},setup(e,l){let{attrs:a,emit:o,slots:n}=l
const{isRtl:r}=Rt(),{themeClasses:i}=gt(e),{borderClasses:s}=fl(e),{backgroundColorClasses:u,backgroundColorStyles:c}=Sl(t.toRef(e,"color")),{elevationClasses:d}=gl(e),{mobile:v}=Tn(),{roundedClasses:p}=yl(e),f=Ra(),m=Vt(e,"modelValue",null,(e=>!!e)),{ssrBootStyles:h}=wr(),y=t.ref(),b=t.ref(!1),V=t.computed((()=>e.rail&&e.expandOnHover&&b.value?Number(e.width):Number(e.rail?e.railWidth:e.width))),S=t.computed((()=>W(e.location,r.value))),w=t.computed((()=>!e.permanent&&(v.value||e.temporary))),k=t.computed((()=>e.sticky&&!w.value&&"bottom"!==S.value))
e.expandOnHover&&null!=e.rail&&t.watch(b,(e=>o("update:rail",!e))),e.disableResizeWatcher||t.watch(w,(l=>!e.permanent&&t.nextTick((()=>m.value=!l)))),!e.disableRouteWatcher&&f&&t.watch(f.currentRoute,(()=>w.value&&(m.value=!1))),t.watch((()=>e.permanent),(e=>{e&&(m.value=!0)})),t.onBeforeMount((()=>{null!=e.modelValue||w.value||(m.value=e.permanent||!v.value)}))
const{isDragging:x,dragProgress:C,dragStyles:N}=function(e){let{isActive:l,isTemporary:a,width:o,touchless:n,position:r}=e
t.onMounted((()=>{window.addEventListener("touchstart",y,{passive:!0}),window.addEventListener("touchmove",b,{passive:!1}),window.addEventListener("touchend",V,{passive:!0})})),t.onBeforeUnmount((()=>{window.removeEventListener("touchstart",y),window.removeEventListener("touchmove",b),window.removeEventListener("touchend",V)}))
const i=t.computed((()=>["left","right"].includes(r.value))),{addMovement:s,endTouch:u,getVelocity:c}=ps()
let d=!1
const v=t.ref(!1),p=t.ref(0),f=t.ref(0)
let m
function g(e,t){return("left"===r.value?e:"right"===r.value?document.documentElement.clientWidth-e:"top"===r.value?e:"bottom"===r.value?document.documentElement.clientHeight-e:fs())-(t?o.value:0)}function h(e){let t=!(arguments.length>1&&void 0!==arguments[1])||arguments[1]
const l="left"===r.value?(e-f.value)/o.value:"right"===r.value?(document.documentElement.clientWidth-e-f.value)/o.value:"top"===r.value?(e-f.value)/o.value:"bottom"===r.value?(document.documentElement.clientHeight-e-f.value)/o.value:fs()
return t?Math.max(0,Math.min(1,l)):l}function y(e){if(n.value)return
const t=e.changedTouches[0].clientX,c=e.changedTouches[0].clientY,v="left"===r.value?t<25:"right"===r.value?t>document.documentElement.clientWidth-25:"top"===r.value?c<25:"bottom"===r.value?c>document.documentElement.clientHeight-25:fs(),y=l.value&&("left"===r.value?t<o.value:"right"===r.value?t>document.documentElement.clientWidth-o.value:"top"===r.value?c<o.value:"bottom"===r.value?c>document.documentElement.clientHeight-o.value:fs());(v||y||l.value&&a.value)&&(d=!0,m=[t,c],f.value=g(i.value?t:c,l.value),p.value=h(i.value?t:c),u(e),s(e))}function b(e){const t=e.changedTouches[0].clientX,l=e.changedTouches[0].clientY
if(d){if(!e.cancelable)return void(d=!1)
const a=Math.abs(t-m[0]),o=Math.abs(l-m[1]);(i.value?a>o&&a>3:o>a&&o>3)?(v.value=!0,d=!1):(i.value?o:a)>3&&(d=!1)}if(!v.value)return
e.preventDefault(),s(e)
const a=h(i.value?t:l,!1)
p.value=Math.max(0,Math.min(1,a)),a>1?f.value=g(i.value?t:l,!0):a<0&&(f.value=g(i.value?t:l,!1))}function V(e){if(d=!1,!v.value)return
s(e),v.value=!1
const t=c(e.changedTouches[0].identifier),a=Math.abs(t.x),o=Math.abs(t.y),n=i.value?a>o&&a>400:o>a&&o>3
l.value=n?t.direction===({left:"right",right:"left",top:"down",bottom:"up"}[r.value]||fs()):p.value>.5}const S=t.computed((()=>v.value?{transform:"left"===r.value?`translateX(calc(-100% + ${p.value*o.value}px))`:"right"===r.value?`translateX(calc(100% - ${p.value*o.value}px))`:"top"===r.value?`translateY(calc(-100% + ${p.value*o.value}px))`:"bottom"===r.value?`translateY(calc(100% - ${p.value*o.value}px))`:fs(),transition:"none"}:void 0))
return{isDragging:v,dragProgress:p,dragStyles:S}}({isActive:m,isTemporary:w,width:V,touchless:t.toRef(e,"touchless"),position:S}),_=t.computed((()=>{const t=w.value?0:e.rail&&e.expandOnHover?Number(e.railWidth):V.value
return x.value?t*C.value:t})),{layoutItemStyles:I,layoutRect:B,layoutItemScrimStyles:$}=lt({id:e.name,order:t.computed((()=>parseInt(e.order,10))),position:S,layoutSize:_,elementSize:V,active:t.computed((()=>m.value||x.value)),disableTransitions:t.computed((()=>x.value)),absolute:t.computed((()=>e.absolute||k.value&&"string"!=typeof A.value))}),{isStuck:A,stickyStyles:E}=function(e){let{rootEl:l,isSticky:a,layoutItemStyles:o}=e
const n=t.ref(!1),r=t.ref(0),i=t.computed((()=>{const e="boolean"==typeof n.value?"top":n.value
return[a.value?{top:"auto",bottom:"auto",height:void 0}:void 0,n.value?{[e]:g(r.value)}:{top:o.value.top}]}))
t.onMounted((()=>{t.watch(a,(e=>{e?window.addEventListener("scroll",u,{passive:!0}):window.removeEventListener("scroll",u)}),{immediate:!0})})),t.onBeforeUnmount((()=>{document.removeEventListener("scroll",u)}))
let s=0
function u(){const e=s>window.scrollY?"up":"down",t=l.value.getBoundingClientRect(),a=parseFloat(o.value.top??0),i=window.scrollY-Math.max(0,r.value-a),u=t.height+Math.max(r.value,a)-window.scrollY-window.innerHeight
t.height<window.innerHeight-a?(n.value="top",r.value=a):"up"===e&&"bottom"===n.value||"down"===e&&"top"===n.value?(r.value=window.scrollY+t.top,n.value=!0):"down"===e&&u<=0?(r.value=0,n.value="bottom"):"up"===e&&i<=0&&(r.value=t.top+i,n.value="top"),s=window.scrollY}return{isStuck:n,stickyStyles:i}}({rootEl:y,isSticky:k,layoutItemStyles:I}),R=Sl(t.computed((()=>"string"==typeof e.scrim?e.scrim:null))),T=t.computed((()=>({...x.value?{opacity:.2*C.value,transition:"none"}:void 0,...B.value?{left:g(B.value.left),right:g(B.value.right),top:g(B.value.top),bottom:g(B.value.bottom)}:void 0,...$.value})))
return Me({VList:{bgColor:"transparent"}}),Ke((()=>{var l,o,r,v
const f=n.image||e.image
return t.createVNode(t.Fragment,null,[t.createVNode(e.tag,t.mergeProps({ref:y,onMouseenter:()=>b.value=!0,onMouseleave:()=>b.value=!1,class:["v-navigation-drawer",`v-navigation-drawer--${S.value}`,{"v-navigation-drawer--expand-on-hover":e.expandOnHover,"v-navigation-drawer--floating":e.floating,"v-navigation-drawer--is-hovering":b.value,"v-navigation-drawer--rail":e.rail,"v-navigation-drawer--temporary":w.value,"v-navigation-drawer--active":m.value,"v-navigation-drawer--sticky":k.value},i.value,u.value,s.value,d.value,p.value],style:[c.value,I.value,N.value,h.value,E.value]},a),{default:()=>[f&&t.createVNode("div",{key:"image",class:"v-navigation-drawer__img"},[n.image?null==(l=n.image)?void 0:l.call(n,{image:e.image}):t.createVNode("img",{src:e.image,alt:""},null)]),n.prepend&&t.createVNode("div",{class:"v-navigation-drawer__prepend"},[null==(o=n.prepend)?void 0:o.call(n)]),t.createVNode("div",{class:"v-navigation-drawer__content"},[null==(r=n.default)?void 0:r.call(n)]),n.append&&t.createVNode("div",{class:"v-navigation-drawer__append"},[null==(v=n.append)?void 0:v.call(n)])]}),t.createVNode(t.Transition,{name:"fade-transition"},{default:()=>[w.value&&(x.value||m.value)&&!!e.scrim&&t.createVNode("div",{class:["v-navigation-drawer__scrim",R.backgroundColorClasses.value],style:[T.value,R.backgroundColorStyles.value],onClick:()=>m.value=!1},null)]})])})),{isStuck:A}}}),hs=je({name:"VNoSsr",setup(e,t){let{slots:l}=t
const a=Ln()
return()=>{var e
return a.value&&(null==(e=l.default)?void 0:e.call(l))}}})
const ys=je({name:"VPagination",props:{activeColor:String,start:{type:[Number,String],default:1},modelValue:{type:Number,default:e=>e.start},disabled:Boolean,length:{type:[Number,String],default:1,validator:e=>e%1==0},totalVisible:[Number,String],firstIcon:{type:Hl,default:"$first"},prevIcon:{type:Hl,default:"$prev"},nextIcon:{type:Hl,default:"$next"},lastIcon:{type:Hl,default:"$last"},ariaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.root"},pageAriaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.page"},currentPageAriaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.currentPage"},firstAriaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.first"},previousAriaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.previous"},nextAriaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.next"},lastAriaLabel:{type:String,default:"$vuetify.pagination.ariaLabel.last"},ellipsis:{type:String,default:"..."},showFirstLastPage:Boolean,...pl(),..._l(),...ml(),...hl(),...Ql(),...dl({tag:"nav"}),...pt(),...Al({variant:"text"})},emits:{"update:modelValue":e=>!0,first:e=>!0,prev:e=>!0,next:e=>!0,last:e=>!0},setup(e,l){let{slots:a,emit:o}=l
const n=Vt(e,"modelValue"),{t:i,n:s}=At(),{isRtl:u}=Rt(),{themeClasses:c}=gt(e),{width:d}=Tn(),v=t.ref(-1)
Me(void 0,{scoped:!0})
const{resizeRef:p}=r((e=>{if(!e.length)return
const{target:t,contentRect:l}=e[0],a=t.querySelector(".v-pagination__list > *")
if(!a)return
const o=l.width,n=a.offsetWidth+2*parseFloat(getComputedStyle(a).marginRight)
v.value=y(o,n)})),f=t.computed((()=>parseInt(e.length,10))),g=t.computed((()=>parseInt(e.start,10))),h=t.computed((()=>e.totalVisible?parseInt(e.totalVisible,10):v.value>=0?v.value:y(d.value,58)))
function y(t,l){const a=e.showFirstLastPage?5:3
return Math.max(0,Math.floor(+((t-l*a)/l).toFixed(2)))}const V=t.computed((()=>{if(f.value<=0||isNaN(f.value)||f.value>Number.MAX_SAFE_INTEGER)return[]
if(h.value<=1)return[n.value]
if(f.value<=h.value)return m(f.value,g.value)
const t=h.value%2==0,l=t?h.value/2:Math.floor(h.value/2),a=t?l:l+1,o=f.value-l
if(a-n.value>=0)return[...m(Math.max(1,h.value-1),g.value),e.ellipsis,f.value]
if(n.value-o>=(t?1:0)){const t=h.value-1,l=f.value-t+g.value
return[g.value,e.ellipsis,...m(t,l)]}{const t=Math.max(1,h.value-3),l=1===t?n.value:n.value-Math.ceil(t/2)+g.value
return[g.value,e.ellipsis,...m(t,l),e.ellipsis,f.value]}}))
function S(e,t,l){e.preventDefault(),n.value=t,l&&o(l,t)}const{refs:w,updateRef:k}=function(){const e=t.ref([])
return t.onBeforeUpdate((()=>e.value=[])),{refs:e,updateRef:function(t,l){e.value[l]=t}}}()
Me({VPaginationBtn:{color:t.toRef(e,"color"),border:t.toRef(e,"border"),density:t.toRef(e,"density"),size:t.toRef(e,"size"),variant:t.toRef(e,"variant"),rounded:t.toRef(e,"rounded"),elevation:t.toRef(e,"elevation")}})
const x=t.computed((()=>V.value.map(((t,l)=>{const a=e=>k(e,l)
if("string"==typeof t)return{isActive:!1,key:`ellipsis-${l}`,page:t,props:{ref:a,ellipsis:!0,icon:!0,disabled:!0}}
{const l=t===n.value
return{isActive:l,key:t,page:s(t),props:{ref:a,ellipsis:!1,icon:!0,disabled:!!e.disabled||e.length<2,color:l?e.activeColor:e.color,ariaCurrent:l,ariaLabel:i(l?e.currentPageAriaLabel:e.pageAriaLabel,t),onClick:e=>S(e,t)}}}})))),C=t.computed((()=>{const t=!!e.disabled||n.value<=g.value,l=!!e.disabled||n.value>=g.value+f.value-1
return{first:e.showFirstLastPage?{icon:u.value?e.lastIcon:e.firstIcon,onClick:e=>S(e,g.value,"first"),disabled:t,ariaLabel:i(e.firstAriaLabel),ariaDisabled:t}:void 0,prev:{icon:u.value?e.nextIcon:e.prevIcon,onClick:e=>S(e,n.value-1,"prev"),disabled:t,ariaLabel:i(e.previousAriaLabel),ariaDisabled:t},next:{icon:u.value?e.prevIcon:e.nextIcon,onClick:e=>S(e,n.value+1,"next"),disabled:l,ariaLabel:i(e.nextAriaLabel),ariaDisabled:l},last:e.showFirstLastPage?{icon:u.value?e.firstIcon:e.lastIcon,onClick:e=>S(e,g.value+f.value-1,"last"),disabled:l,ariaLabel:i(e.lastAriaLabel),ariaDisabled:l}:void 0}}))
function N(){var e
const t=n.value-g.value
null==(e=w.value[t])||e.$el.focus()}function _(l){l.key===b.left&&!e.disabled&&n.value>e.start?(n.value=n.value-1,t.nextTick(N)):l.key===b.right&&!e.disabled&&n.value<g.value+f.value-1&&(n.value=n.value+1,t.nextTick(N))}return Ke((()=>t.createVNode(e.tag,{ref:p,class:["v-pagination",c.value],role:"navigation","aria-label":i(e.ariaLabel),onKeydown:_,"data-test":"v-pagination-root"},{default:()=>[t.createVNode("ul",{class:"v-pagination__list"},[e.showFirstLastPage&&t.createVNode("li",{key:"first",class:"v-pagination__first","data-test":"v-pagination-first"},[a.first?a.first(C.value.first):t.createVNode(Oa,t.mergeProps({_as:"VPaginationBtn"},C.value.first),null)]),t.createVNode("li",{key:"prev",class:"v-pagination__prev","data-test":"v-pagination-prev"},[a.prev?a.prev(C.value.prev):t.createVNode(Oa,t.mergeProps({_as:"VPaginationBtn"},C.value.prev),null)]),x.value.map(((e,l)=>t.createVNode("li",{key:e.key,class:["v-pagination__item",{"v-pagination__item--is-active":e.isActive}],"data-test":"v-pagination-item"},[a.item?a.item(e):t.createVNode(Oa,t.mergeProps({_as:"VPaginationBtn"},e.props),{default:()=>[e.page]})]))),t.createVNode("li",{key:"next",class:"v-pagination__next","data-test":"v-pagination-next"},[a.next?a.next(C.value.next):t.createVNode(Oa,t.mergeProps({_as:"VPaginationBtn"},C.value.next),null)]),e.showFirstLastPage&&t.createVNode("li",{key:"last",class:"v-pagination__last","data-test":"v-pagination-last"},[a.last?a.last(C.value.last):t.createVNode(Oa,t.mergeProps({_as:"VPaginationBtn"},C.value.last),null)])])]}))),{}}})
const bs=je({name:"VParallax",props:{scale:{type:[Number,String],default:.5}},setup(e,l){let{slots:a}=l
const{intersectionRef:o,isIntersecting:n}=aa(),{resizeRef:i,contentRect:s}=r(),{height:u}=Tn(),c=t.ref()
let d
t.watchEffect((()=>{var e
o.value=i.value=null==(e=c.value)?void 0:e.$el})),t.watch(n,(e=>{e?(d=Xe(o.value),d=d===document.scrollingElement?document:d,d.addEventListener("scroll",f,{passive:!0}),f()):d.removeEventListener("scroll",f)})),t.onBeforeUnmount((()=>{var e
null==(e=d)||e.removeEventListener("scroll",f)})),t.watch(u,f),t.watch((()=>{var e
return null==(e=s.value)?void 0:e.height}),f)
const v=t.computed((()=>1-C(+e.scale)))
let p=-1
function f(){n.value&&(cancelAnimationFrame(p),p=requestAnimationFrame((()=>{var e
const t=(null==(e=c.value)?void 0:e.$el).querySelector(".v-img__img")
if(!t)return
const l=d.clientHeight??document.documentElement.clientHeight,a=d.scrollTop??window.scrollY,n=o.value.offsetTop,r=s.value.height,i=(u=(a-(n+(r-l)/2))*v.value,Math.floor(Math.abs(u))*Math.sign(u))
var u
const p=Math.max(1,(v.value*(l-r)+r)/r)
t.style.setProperty("transform",`translateY(${i}px) scale(${p})`)})))}return Ke((()=>t.createVNode(cl,{class:["v-parallax",{"v-parallax--active":n.value}],ref:c,cover:!0,onLoadstart:f,onLoad:f},a))),{}}}),Vs=je({name:"VRadio",props:{...bo({falseIcon:"$radioOff",trueIcon:"$radioOn"})},setup(e,l){let{slots:a}=l
return Ke((()=>t.createVNode(Vo,t.mergeProps(e,{class:"v-radio",type:"radio"}),a))),{}}}),Ss=je({name:"VRadioGroup",inheritAttrs:!1,props:{height:{type:[Number,String],default:"auto"},...no(),...w(ho(),["multiple"]),trueIcon:{type:Hl,default:"$radioOn"},falseIcon:{type:Hl,default:"$radioOff"},type:{type:String,default:"radio"}},emits:{"update:modelValue":e=>!0},setup(e,l){let{attrs:a,slots:o}=l
const n=Le(),r=t.computed((()=>e.id||`radio-group-${n}`)),i=Vt(e,"modelValue")
return Ke((()=>{const[l,n]=k(a),[s,u]=io(e),[c,d]=So({...e,multiple:!1}),v=o.label?o.label({label:e.label,props:{for:r.value}}):e.label
return t.createVNode(ro,t.mergeProps({class:"v-radio-group"},l,s,{modelValue:i.value,"onUpdate:modelValue":e=>i.value=e,id:r.value}),{...o,default:l=>{let{id:a,messagesId:r,isDisabled:s,isReadonly:u}=l
return t.createVNode(t.Fragment,null,[v&&t.createVNode(Ua,{id:a.value},{default:()=>[v]}),t.createVNode(yo,t.mergeProps(c,{id:a.value,"aria-describedby":r.value,defaultsTarget:"VRadio",trueIcon:e.trueIcon,falseIcon:e.falseIcon,type:e.type,disabled:s.value,readonly:u.value,"aria-labelledby":v?a.value:void 0},n,{modelValue:i.value,"onUpdate:modelValue":e=>i.value=e}),o)])}})})),{}}}),ws=je({name:"VRangeSlider",props:{...Xa(),...no(),...zr(),strict:Boolean,modelValue:{type:Array,default:()=>[0,0]}},emits:{"update:focused":e=>!0,"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=t.ref(),n=t.ref(),r=t.ref()
const{activeThumbRef:i,hasLabels:s,max:u,min:c,mousePressed:d,onSliderMousedown:v,onSliderTouchstart:p,position:f,roundValue:m,trackContainerRef:g}=Dr({props:e,handleSliderMouseUp:e=>{var t
h.value=i.value===(null==(t=o.value)?void 0:t.$el)?[e,h.value[1]]:[h.value[0],e]},handleMouseMove:t=>{var l
const[a,r]=h.value
var s,u,d
e.strict||a!==r||a===c.value||(i.value=t>a?null==(s=n.value)?void 0:s.$el:null==(u=o.value)?void 0:u.$el,null==(d=i.value)||d.focus())
i.value===(null==(l=o.value)?void 0:l.$el)?h.value=[Math.min(t,r),r]:h.value=[a,Math.max(a,t)]},getActiveThumb:function(t){if(!o.value||!n.value)return
const l=Mr(t,o.value.$el,e.direction),a=Mr(t,n.value.$el,e.direction),r=Math.abs(l),i=Math.abs(a)
return r<i||r===i&&l<0?o.value.$el:n.value.$el}}),h=Vt(e,"modelValue",void 0,(e=>e&&e.length?e.map((e=>m(e))):[0,0])),{isFocused:y,focus:b,blur:V}=Ga(e),S=t.computed((()=>f(h.value[0]))),w=t.computed((()=>f(h.value[1])))
return Ke((()=>{const[l,f]=io(e),m=!!(e.label||a.label||a.prepend)
return t.createVNode(ro,t.mergeProps({class:["v-slider","v-range-slider",{"v-slider--has-labels":!!a["tick-label"]||s.value,"v-slider--focused":y.value,"v-slider--pressed":d.value,"v-slider--disabled":e.disabled}],ref:r},l,{focused:y.value}),{...a,prepend:m?l=>{var o,n
return t.createVNode(t.Fragment,null,[(null==(o=a.label)?void 0:o.call(a,l))??e.label?t.createVNode(Ua,{class:"v-slider__label",text:e.label},null):void 0,null==(n=a.prepend)?void 0:n.call(a,l)])}:void 0,default:l=>{var r,s
let{id:d,messagesId:f}=l
return t.createVNode("div",{class:"v-slider__container",onMousedown:v,onTouchstartPassive:p},[t.createVNode("input",{id:`${d.value}_start`,name:e.name||d.value,disabled:e.disabled,readonly:e.readonly,tabindex:"-1",value:h.value[0]},null),t.createVNode("input",{id:`${d.value}_stop`,name:e.name||d.value,disabled:e.disabled,readonly:e.readonly,tabindex:"-1",value:h.value[1]},null),t.createVNode(Hr,{ref:g,start:S.value,stop:w.value},{"tick-label":a["tick-label"]}),t.createVNode(jr,{ref:o,"aria-describedby":f.value,focused:y&&i.value===(null==(r=o.value)?void 0:r.$el),modelValue:h.value[0],"onUpdate:modelValue":e=>h.value=[e,h.value[1]],onFocus:e=>{var t,l,a,r;(b(),i.value=null==(t=o.value)?void 0:t.$el,h.value[0]===h.value[1]&&h.value[1]===c.value&&e.relatedTarget!==(null==(l=n.value)?void 0:l.$el))&&(null==(a=o.value)||a.$el.blur(),null==(r=n.value)||r.$el.focus())},onBlur:()=>{V(),i.value=void 0},min:c.value,max:h.value[1],position:S.value},{"thumb-label":a["thumb-label"]}),t.createVNode(jr,{ref:n,"aria-describedby":f.value,focused:y&&i.value===(null==(s=n.value)?void 0:s.$el),modelValue:h.value[1],"onUpdate:modelValue":e=>h.value=[h.value[0],e],onFocus:e=>{var t,l,a,r;(b(),i.value=null==(t=n.value)?void 0:t.$el,h.value[0]===h.value[1]&&h.value[0]===u.value&&e.relatedTarget!==(null==(l=o.value)?void 0:l.$el))&&(null==(a=n.value)||a.$el.blur(),null==(r=o.value)||r.$el.focus())},onBlur:()=>{V(),i.value=void 0},min:h.value[0],max:u.value,position:w.value},{"thumb-label":a["thumb-label"]})])}})})),{}}}),ks=He()({name:"VRating",props:{name:String,itemAriaLabel:{type:String,default:"$vuetify.rating.ariaLabel.item"},activeColor:String,color:String,clearable:Boolean,disabled:Boolean,emptyIcon:{type:Hl,default:"$ratingEmpty"},fullIcon:{type:Hl,default:"$ratingFull"},halfIncrements:Boolean,hover:Boolean,length:{type:[Number,String],default:5},readonly:Boolean,modelValue:{type:[Number,String],default:0},itemLabels:Array,itemLabelPosition:{type:String,default:"top",validator:e=>["top","bottom"].includes(e)},ripple:Boolean,..._l(),...Ql(),...dl(),...pt()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const{t:o}=At(),{themeClasses:n}=gt(e),r=Vt(e,"modelValue"),i=t.computed((()=>C(parseFloat(r.value),0,+e.length))),s=t.computed((()=>m(Number(e.length),1))),u=t.computed((()=>s.value.flatMap((t=>e.halfIncrements?[t-.5,t]:[t])))),c=t.ref(-1),d=t.ref(-1),v=t.ref()
let p=!1
const f=t.computed((()=>u.value.map((t=>{const l=e.hover&&c.value>-1,a=i.value>=t,o=c.value>=t,n=(l?o:a)?e.fullIcon:e.emptyIcon,r=e.activeColor??e.color
return{isFilled:a,isHovered:o,icon:n,color:a||o?r:e.color}})))),g=t.computed((()=>[0,...u.value].map((t=>({onMouseenter:e.hover?function(){c.value=t}:void 0,onMouseleave:e.hover?function(){c.value=-1}:void 0,onFocus:function(){var e
0===t&&0===i.value?null==(e=v.value)||e.focus():d.value=t},onBlur:function(){p||(d.value=-1)},onClick:function(){e.disabled||e.readonly||(r.value=i.value===t&&e.clearable?0:t)}})))))
function h(){p=!0}function y(){p=!1}const b=t.computed((()=>e.name??`v-rating-${Le()}`))
function V(l){var n,r
let{value:s,index:u,showStar:c=!0}=l
const{onMouseenter:d,onMouseleave:p,onFocus:m,onBlur:V,onClick:S}=g.value[u+1],w=`${b.value}-${String(s).replace(".","-")}`,k={color:null==(n=f.value[u])?void 0:n.color,density:e.density,disabled:e.disabled,icon:null==(r=f.value[u])?void 0:r.icon,ripple:e.ripple,size:e.size,tag:"span",variant:"plain"}
return t.createVNode(t.Fragment,null,[t.createVNode("label",{for:w,class:{"v-rating__item--half":e.halfIncrements&&s%1>0,"v-rating__item--full":e.halfIncrements&&s%1==0},onMousedown:h,onMouseup:y,onMouseenter:d,onMouseleave:p},[t.createVNode("span",{class:"v-rating__hidden"},[o(e.itemAriaLabel,s,e.length)]),c?a.item?a.item({...f.value[u],props:k,value:s,index:u}):t.createVNode(Oa,k,null):void 0]),t.createVNode("input",{class:"v-rating__hidden",name:b.value,id:w,type:"radio",value:s,checked:i.value===s,onClick:S,onFocus:m,onBlur:V,ref:0===u?v:void 0,readonly:e.readonly,disabled:e.disabled},null)])}function S(e){return a["item-label"]?a["item-label"](e):e.label?t.createVNode("span",null,[e.label]):t.createVNode("span",null,[t.createTextVNode(" ")])}return Ke((()=>{var l
const o=!(null==(l=e.itemLabels)||!l.length)||a["item-label"]
return t.createVNode(e.tag,{class:["v-rating",{"v-rating--hover":e.hover,"v-rating--readonly":e.readonly},n.value]},{default:()=>[t.createVNode(V,{value:0,index:-1,showStar:!1},null),s.value.map(((l,a)=>{var n,r
return t.createVNode("div",{class:"v-rating__wrapper"},[o&&"top"===e.itemLabelPosition?S({value:l,index:a,label:null==(n=e.itemLabels)?void 0:n[a]}):void 0,t.createVNode("div",{class:["v-rating__item",{"v-rating__item--focused":Math.ceil(d.value)===l}]},[e.halfIncrements?t.createVNode(t.Fragment,null,[t.createVNode(V,{value:l-.5,index:2*a},null),t.createVNode(V,{value:l,index:2*a+1},null)]):t.createVNode(V,{value:l,index:a},null)]),o&&"bottom"===e.itemLabelPosition?S({value:l,index:a,label:null==(r=e.itemLabels)?void 0:r[a]}):void 0])}))]})})),{}}})
function xs(e){const t=Math.abs(e)
return Math.sign(e)*(t/((1/.501-2)*(1-t)+1))}function Cs(e){let{selectedElement:t,containerSize:l,contentSize:a,isRtl:o,currentScrollOffset:n,isHorizontal:r}=e
const i=r?t.clientWidth:t.clientHeight,s=r?t.offsetLeft:t.offsetTop,u=o&&r?a-s-i:s,c=l+n,d=i+u,v=.4*i
return u<=n?n=Math.max(u-v,0):c<=d&&(n=Math.min(n-(c-d-v),a-l)),n}const Ns=Symbol.for("vuetify:v-slide-group"),_s=He()({name:"VSlideGroup",props:{centerActive:Boolean,direction:{type:String,default:"horizontal"},symbol:{type:null,default:Ns},nextIcon:{type:Hl,default:"$next"},prevIcon:{type:Hl,default:"$prev"},showArrows:{type:[Boolean,String],validator:e=>"boolean"==typeof e||["always","desktop","mobile"].includes(e)},...dl(),...Tl({selectedClass:"v-slide-group-item--active"})},emits:{"update:modelValue":e=>!0},setup(e,a){let{slots:o}=a
const{isRtl:n}=Rt(),{mobile:i}=Tn(),s=Ol(e,e.symbol),u=t.ref(!1),c=t.ref(0),d=t.ref(0),v=t.ref(0),p=t.computed((()=>"horizontal"===e.direction)),{resizeRef:f,contentRect:m}=r(),{resizeRef:g,contentRect:h}=r(),y=t.computed((()=>s.selected.value.length?s.items.value.findIndex((e=>e.id===s.selected.value[0])):-1)),b=t.computed((()=>s.selected.value.length?s.items.value.findIndex((e=>e.id===s.selected.value[s.selected.value.length-1])):-1))
if(l){let l=-1
t.watch((()=>[s.selected.value,m.value,h.value,p.value]),(()=>{cancelAnimationFrame(l),l=requestAnimationFrame((()=>{if(m.value&&h.value){const e=p.value?"width":"height"
d.value=m.value[e],v.value=h.value[e],u.value=d.value+1<v.value}if(y.value>=0&&g.value){const t=g.value.children[b.value]
0!==y.value&&u.value?e.centerActive?c.value=function(e){let{selectedElement:t,containerSize:l,contentSize:a,isRtl:o,isHorizontal:n}=e
const r=n?t.clientWidth:t.clientHeight,i=n?t.offsetLeft:t.offsetTop,s=o&&n?a-i-r/2-l/2:i+r/2-l/2
return Math.min(a-l,Math.max(0,s))}({selectedElement:t,containerSize:d.value,contentSize:v.value,isRtl:n.value,isHorizontal:p.value}):u.value&&(c.value=Cs({selectedElement:t,containerSize:d.value,contentSize:v.value,isRtl:n.value,currentScrollOffset:c.value,isHorizontal:p.value})):c.value=0}}))}))}const V=t.ref(!1)
let S=0,w=0
function k(e){const t=p.value?"clientX":"clientY",l=n.value&&p.value?-1:1
w=l*c.value,S=e.touches[0][t],V.value=!0}function x(e){if(!u.value)return
const t=p.value?"clientX":"clientY",l=n.value&&p.value?-1:1
c.value=l*(w+S-e.touches[0][t])}function N(e){const t=v.value-d.value
c.value<0||!u.value?c.value=0:c.value>=t&&(c.value=t),V.value=!1}function _(){f.value&&(f.value[p.value?"scrollLeft":"scrollTop"]=0)}const I=t.ref(!1)
function B(e){if(I.value=!0,u.value&&g.value)for(const t of e.composedPath())for(const e of g.value.children)if(e===t)return void(c.value=Cs({selectedElement:e,containerSize:d.value,contentSize:v.value,isRtl:n.value,currentScrollOffset:c.value,isHorizontal:p.value}))}function $(e){I.value=!1}function A(e){var t
I.value||e.relatedTarget&&null!=(t=g.value)&&t.contains(e.relatedTarget)||R()}function E(e){g.value&&(p.value?"ArrowRight"===e.key?R(n.value?"prev":"next"):"ArrowLeft"===e.key&&R(n.value?"next":"prev"):"ArrowDown"===e.key?R("next"):"ArrowUp"===e.key&&R("prev"),"Home"===e.key?R("first"):"End"===e.key&&R("last"))}function R(e){if(g.value)if(e){if("next"===e){var t
const e=null==(t=g.value.querySelector(":focus"))?void 0:t.nextElementSibling
e?e.focus():R("first")}else if("prev"===e){var l
const e=null==(l=g.value.querySelector(":focus"))?void 0:l.previousElementSibling
e?e.focus():R("last")}else if("first"===e){var a
null==(a=g.value.firstElementChild)||a.focus()}else if("last"===e){var o
null==(o=g.value.lastElementChild)||o.focus()}}else{var n
null==(n=[...g.value.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')].filter((e=>!e.hasAttribute("disabled")))[0])||n.focus()}}function T(e){const t=c.value+("prev"===e?-1:1)*d.value
c.value=C(t,0,v.value-d.value)}const L=t.computed((()=>{let e=c.value>v.value-d.value?-(v.value-d.value)+xs(v.value-d.value-c.value):-c.value
c.value<=0&&(e=xs(-c.value))
const t=n.value&&p.value?-1:1
return{transform:`translate${p.value?"X":"Y"}(${t*e}px)`,transition:V.value?"none":"",willChange:V.value?"transform":""}})),P=t.computed((()=>({next:s.next,prev:s.prev,select:s.select,isSelected:s.isSelected}))),O=t.computed((()=>{switch(e.showArrows){case"always":return!0
case"desktop":return!i.value
case!0:return u.value||Math.abs(c.value)>0
case"mobile":return i.value||u.value||Math.abs(c.value)>0
default:return!i.value&&(u.value||Math.abs(c.value)>0)}})),F=t.computed((()=>Math.abs(c.value)>0)),M=t.computed((()=>v.value>Math.abs(c.value)+d.value))
return Ke((()=>{var l,a,r
return t.createVNode(e.tag,{class:["v-slide-group",{"v-slide-group--vertical":!p.value,"v-slide-group--has-affixes":O.value,"v-slide-group--is-overflowing":u.value}],tabindex:I.value||s.selected.value.length?-1:0,onFocus:A},{default:()=>[O.value&&t.createVNode("div",{key:"prev",class:["v-slide-group__prev",{"v-slide-group__prev--disabled":!F.value}],onClick:()=>T("prev")},[(null==(l=o.prev)?void 0:l.call(o,P.value))??t.createVNode(Ut,null,{default:()=>[t.createVNode(la,{icon:n.value?e.nextIcon:e.prevIcon},null)]})]),t.createVNode("div",{key:"container",ref:f,class:"v-slide-group__container",onScroll:_},[t.createVNode("div",{ref:g,class:"v-slide-group__content",style:L.value,onTouchstartPassive:k,onTouchmovePassive:x,onTouchendPassive:N,onFocusin:B,onFocusout:$,onKeydown:E},[null==(a=o.default)?void 0:a.call(o,P.value)])]),O.value&&t.createVNode("div",{key:"next",class:["v-slide-group__next",{"v-slide-group__next--disabled":!M.value}],onClick:()=>T("next")},[(null==(r=o.next)?void 0:r.call(o,P.value))??t.createVNode(Ut,null,{default:()=>[t.createVNode(la,{icon:n.value?e.prevIcon:e.nextIcon},null)]})])]})})),{selected:s.selected,scrollTo:T,scrollOffset:c,focus:R}}}),Is=He()({name:"VSlideGroupItem",props:{...Ll()},emits:{"group:selected":e=>!0},setup(e,t){let{slots:l}=t
const a=Pl(e,Ns)
return()=>{var e
return null==(e=l.default)?void 0:e.call(l,{isSelected:a.isSelected.value,select:a.select,toggle:a.toggle,selectedClass:a.selectedClass.value})}}}),Bs=He()({name:"VSnackbar",props:{multiLine:Boolean,timeout:{type:[Number,String],default:5e3},vertical:Boolean,...xa({location:"bottom"}),...Aa(),...hl(),...Al(),...pt(),...w(Un({transition:"v-snackbar-transition"}),["persistent","noClickAnimation","scrim","scrollStrategy"])},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),{locationStyles:n}=Ca(e),{positionClasses:r}=Ea(e),{scopeId:i}=Pn(),{themeClasses:s}=gt(e),{colorClasses:u,colorStyles:c,variantClasses:d}=El(e),{roundedClasses:v}=yl(e),p=t.ref()
t.watch(o,m),t.watch((()=>e.timeout),m),t.onMounted((()=>{o.value&&m()}))
let f=-1
function m(){window.clearTimeout(f)
const t=Number(e.timeout)
o.value&&-1!==t&&(f=window.setTimeout((()=>{o.value=!1}),t))}function g(){window.clearTimeout(f)}return Ke((()=>{const[l]=Xn(e)
return t.createVNode(Yn,t.mergeProps({ref:p,class:["v-snackbar",{"v-snackbar--active":o.value,"v-snackbar--multi-line":e.multiLine&&!e.vertical,"v-snackbar--vertical":e.vertical},r.value]},l,{modelValue:o.value,"onUpdate:modelValue":e=>o.value=e,contentProps:t.mergeProps({style:n.value},l.contentProps),persistent:!0,noClickAnimation:!0,scrim:!1,scrollStrategy:"none"},i),{default:()=>[t.createVNode("div",{class:["v-snackbar__wrapper",s.value,u.value,v.value,d.value],style:[c.value],onPointerenter:g,onPointerleave:m},[$l(!1,"v-snackbar"),a.default&&t.createVNode("div",{class:"v-snackbar__content",role:"status","aria-live":"polite"},[a.default()]),a.actions&&t.createVNode(Lt,{defaults:{VBtn:{variant:"text",ripple:!1}}},{default:()=>[t.createVNode("div",{class:"v-snackbar__actions"},[a.actions()])]})])],activator:a.activator})})),co({},p)}}),$s=je({name:"VSwitch",inheritAttrs:!1,props:{indeterminate:Boolean,inset:Boolean,flat:Boolean,loading:{type:[Boolean,String],default:!1},...no(),...bo()},emits:{"update:focused":e=>!0,"update:modelValue":()=>!0,"update:indeterminate":e=>!0},setup(e,l){let{attrs:a,slots:o}=l
const n=Vt(e,"indeterminate"),r=Vt(e,"modelValue"),{loaderClasses:i}=Ia(e),{isFocused:s,focus:u,blur:c}=Ga(e),d=t.computed((()=>"string"==typeof e.loading&&""!==e.loading?e.loading:e.color)),v=Le(),p=t.computed((()=>e.id||`switch-${v}`))
function f(){n.value&&(n.value=!1)}return Ke((()=>{const[l,v]=k(a),[m,g]=io(e),[h,y]=So(e),b=t.ref()
function V(){var e,t
null==(e=b.value)||null==(t=e.input)||t.click()}return t.createVNode(ro,t.mergeProps({class:["v-switch",{"v-switch--inset":e.inset},{"v-switch--indeterminate":n.value},i.value]},l,m,{id:p.value,focused:s.value}),{...o,default:l=>{let{id:a,messagesId:i,isDisabled:s,isReadonly:p,isValid:m}=l
return t.createVNode(Vo,t.mergeProps({ref:b},h,{modelValue:r.value,"onUpdate:modelValue":[e=>r.value=e,f],id:a.value,"aria-describedby":i.value,type:"checkbox","aria-checked":n.value?"mixed":void 0,disabled:s.value,readonly:p.value,onFocus:u,onBlur:c},v),{...o,default:()=>t.createVNode("div",{class:"v-switch__track",onClick:V},null),input:l=>{let{textColorClasses:a,textColorStyles:n}=l
return t.createVNode("div",{class:["v-switch__thumb",a.value],style:n.value},[e.loading&&t.createVNode(Ba,{name:"v-switch",active:!0,color:!1===m.value?void 0:d.value},{default:e=>o.loader?o.loader(e):t.createVNode(oa,{active:e.isActive,color:e.color,indeterminate:!0,size:"16",width:"2"},null)})])}})}})})),{}}}),As=je({name:"VSystemBar",props:{color:String,height:[Number,String],window:Boolean,...ml(),...et(),...hl(),...dl(),...pt()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{backgroundColorClasses:n,backgroundColorStyles:r}=Sl(t.toRef(e,"color")),{elevationClasses:i}=gl(e),{roundedClasses:s}=yl(e),u=t.computed((()=>e.height??(e.window?32:24))),{layoutItemStyles:c}=lt({id:e.name,order:t.computed((()=>parseInt(e.order,10))),position:t.ref("top"),layoutSize:u,elementSize:u,active:t.computed((()=>!0)),absolute:t.toRef(e,"absolute")})
return Ke((()=>t.createVNode(e.tag,{class:["v-system-bar",{"v-system-bar--window":e.window},o.value,n.value,i.value,s.value],style:[r.value,c.value]},a))),{}}}),Es=Symbol.for("vuetify:v-tabs"),Rs=je({name:"VTab",props:{fixed:Boolean,icon:[Boolean,String,Function,Object],prependIcon:Hl,appendIcon:Hl,stacked:Boolean,title:String,ripple:{type:Boolean,default:!0},color:String,sliderColor:String,hideSlider:Boolean,direction:{type:String,default:"horizontal"},...dl(),...La(),...Ll({selectedClass:"v-tab--selected"}),...pt()},setup(e,l){let{slots:a,attrs:o}=l
const{textColorClasses:n,textColorStyles:r}=Vl(e,"sliderColor"),i=t.computed((()=>"horizontal"===e.direction)),s=t.ref(!1),u=t.ref(),c=t.ref()
function d(e){let{value:t}=e
if(s.value=t,t){var l,a
const e=null==(l=u.value)||null==(a=l.$el.parentElement)?void 0:a.querySelector(".v-tab--selected .v-tab__slider"),t=c.value
if(!e||!t)return
const o=getComputedStyle(e).color,n=e.getBoundingClientRect(),r=t.getBoundingClientRect(),s=i.value?"x":"y",d=i.value?"X":"Y",v=i.value?"right":"bottom",p=i.value?"width":"height",f=n[s]>r[s]?n[v]-r[v]:n[s]-r[s],m=Math.sign(f)>0?i.value?"right":"bottom":Math.sign(f)<0?i.value?"left":"top":"center",g=(Math.abs(f)+(Math.sign(f)<0?n[p]:r[p]))/Math.max(n[p],r[p]),h=1.5
J(t,{backgroundColor:[o,""],transform:[`translate${d}(${f}px) scale${d}(${n[p]/r[p]})`,`translate${d}(${f/h}px) scale${d}(${(g-1)/h+1})`,""],transformOrigin:Array(3).fill(m)},{duration:225,easing:Ye})}}return Ke((()=>{const[l]=S(e,["href","to","replace","icon","stacked","prependIcon","appendIcon","ripple","theme","disabled","selectedClass","value","color"])
return t.createVNode(Oa,t.mergeProps({_as:"VTab",symbol:Es,ref:u,class:["v-tab"],tabindex:s.value?0:-1,role:"tab","aria-selected":String(s.value),active:!1,block:e.fixed,maxWidth:e.fixed?300:void 0,variant:"text",rounded:0},l,o,{"onGroup:selected":d}),{default:()=>[a.default?a.default():e.title,!e.hideSlider&&t.createVNode("div",{ref:c,class:["v-tab__slider",n.value],style:r.value},null)]})})),{}}})
const Ts=je({name:"VTabs",props:{alignTabs:{type:String,default:"start"},color:String,direction:{type:String,default:"horizontal"},fixedTabs:Boolean,items:{type:Array,default:()=>[]},stacked:Boolean,bgColor:String,grow:Boolean,height:{type:[Number,String],default:void 0},hideSlider:Boolean,sliderColor:String,modelValue:null,mandatory:{type:[Boolean,String],default:"force"},..._l(),...dl()},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),n=t.computed((()=>{return(t=e.items)?t.map((e=>"string"==typeof e?{title:e,value:e}:e)):[]
var t})),{densityClasses:r}=Il(e),{backgroundColorClasses:i,backgroundColorStyles:s}=Sl(t.toRef(e,"bgColor"))
return Me({VTab:{color:t.toRef(e,"color"),direction:t.toRef(e,"direction"),stacked:t.toRef(e,"stacked"),fixed:t.toRef(e,"fixedTabs"),sliderColor:t.toRef(e,"sliderColor"),hideSlider:t.toRef(e,"hideSlider")}}),Ke((()=>t.createVNode(_s,{modelValue:o.value,"onUpdate:modelValue":e=>o.value=e,class:["v-tabs",`v-tabs--${e.direction}`,`v-tabs--align-tabs-${e.alignTabs}`,{"v-tabs--fixed-tabs":e.fixedTabs,"v-tabs--grow":e.grow,"v-tabs--stacked":e.stacked},r.value,i.value],style:[{"--v-tabs-height":g(e.height)},s.value],role:"tablist",symbol:Es,mandatory:e.mandatory,direction:e.direction},{default:()=>[a.default?a.default():n.value.map((e=>t.createVNode(Rs,t.mergeProps(e,{key:e.title}),null)))]}))),{}}}),Ls=je({name:"VTable",props:{fixedHeader:Boolean,fixedFooter:Boolean,height:[Number,String],hover:Boolean,..._l(),...dl(),...pt()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{densityClasses:n}=Il(e)
return Ke((()=>{var l,r,i
return t.createVNode(e.tag,{class:["v-table",{"v-table--fixed-height":!!e.height,"v-table--fixed-header":e.fixedHeader,"v-table--fixed-footer":e.fixedFooter,"v-table--has-top":!!a.top,"v-table--has-bottom":!!a.bottom,"v-table--hover":e.hover},o.value,n.value]},{default:()=>[null==(l=a.top)?void 0:l.call(a),a.default?t.createVNode("div",{class:"v-table__wrapper",style:{height:g(e.height)}},[t.createVNode("table",null,[a.default()])]):null==(r=a.wrapper)?void 0:r.call(a),null==(i=a.bottom)?void 0:i.call(a)]})})),{}}}),Ps=je({name:"VTextarea",directives:{Intersect:il},inheritAttrs:!1,props:{autoGrow:Boolean,autofocus:Boolean,counter:[Boolean,Number,String],counterValue:Function,hint:String,persistentHint:Boolean,prefix:String,placeholder:String,persistentPlaceholder:Boolean,persistentCounter:Boolean,noResize:Boolean,rows:{type:[Number,String],default:5,validator:e=>!isNaN(parseFloat(e))},maxRows:{type:[Number,String],validator:e=>!isNaN(parseFloat(e))},suffix:String,...no(),...Ka()},emits:{"click:control":e=>!0,"update:focused":e=>!0,"update:modelValue":e=>!0},setup(e,l){let{attrs:a,emit:o,slots:n}=l
const r=Vt(e,"modelValue"),{isFocused:i,focus:s,blur:u}=Ga(e),c=t.computed((()=>"function"==typeof e.counterValue?e.counterValue(r.value):(r.value||"").toString().length)),d=t.computed((()=>a.maxlength?a.maxlength:!e.counter||"number"!=typeof e.counter&&"string"!=typeof e.counter?void 0:e.counter))
function v(t,l){var a,o
e.autofocus&&t&&(null==(a=l[0].target)||null==(o=a.focus)||o.call(a))}const p=t.ref(),f=t.ref(),m=t.ref(""),h=t.ref(),y=t.computed((()=>i.value||e.persistentPlaceholder)),b=t.computed((()=>e.messages.length?e.messages:y.value||e.persistentHint?e.hint:""))
function V(){var e
h.value!==document.activeElement&&(null==(e=h.value)||e.focus())
i.value||s()}function S(e){V(),o("click:control",e)}function w(l){l.stopPropagation(),V(),t.nextTick((()=>{r.value="",z(e["onClick:clear"],l)}))}function x(e){r.value=e.target.value}const N=t.ref()
function _(){e.autoGrow&&t.nextTick((()=>{if(!N.value||!f.value)return
const t=getComputedStyle(N.value),l=getComputedStyle(f.value.$el),a=parseFloat(t.getPropertyValue("--v-field-padding-top"))+parseFloat(t.getPropertyValue("--v-input-padding-top"))+parseFloat(t.getPropertyValue("--v-field-padding-bottom")),o=N.value.scrollHeight,n=parseFloat(t.lineHeight),r=Math.max(parseFloat(e.rows)*n+a,parseFloat(l.getPropertyValue("--v-input-control-height"))),i=parseFloat(e.maxRows)*n+a||1/0
m.value=g(C(o??0,r,i))}))}let I
return t.onMounted(_),t.watch(r,_),t.watch((()=>e.rows),_),t.watch((()=>e.maxRows),_),t.watch((()=>e.density),_),t.watch(N,(e=>{var t
e?(I=new ResizeObserver(_),I.observe(N.value)):null==(t=I)||t.disconnect()})),t.onBeforeUnmount((()=>{var e
null==(e=I)||e.disconnect()})),Ke((()=>{const l=!!(n.counter||e.counter||e.counterValue),o=!(!l&&!n.details),[s,g]=k(a),[{modelValue:C,..._}]=io(e),[I]=Ja(e)
return t.createVNode(ro,t.mergeProps({ref:p,modelValue:r.value,"onUpdate:modelValue":e=>r.value=e,class:["v-textarea v-text-field",{"v-textarea--prefixed":e.prefix,"v-textarea--suffixed":e.suffix,"v-text-field--prefixed":e.prefix,"v-text-field--suffixed":e.suffix,"v-textarea--auto-grow":e.autoGrow,"v-textarea--no-resize":e.noResize||e.autoGrow,"v-text-field--flush-details":["plain","underlined"].includes(e.variant)}],"onClick:prepend":e["onClick:prepend"],"onClick:append":e["onClick:append"]},s,_,{focused:i.value,messages:b.value}),{...n,default:l=>{let{isDisabled:a,isDirty:o,isReadonly:s,isValid:c}=l
return t.createVNode(Za,t.mergeProps({ref:f,style:{"--v-textarea-control-height":m.value},"onClick:control":S,"onClick:clear":w,"onClick:prependInner":e["onClick:prependInner"],"onClick:appendInner":e["onClick:appendInner"],role:"textbox"},I,{active:y.value||o.value,dirty:o.value||e.dirty,focused:i.value,error:!1===c.value}),{...n,default:l=>{let{props:{class:o,...n}}=l
return t.createVNode(t.Fragment,null,[e.prefix&&t.createVNode("span",{class:"v-text-field__prefix"},[e.prefix]),t.withDirectives(t.createVNode("textarea",t.mergeProps({ref:h,class:o,value:r.value,onInput:x,autofocus:e.autofocus,readonly:s.value,disabled:a.value,placeholder:e.placeholder,rows:e.rows,name:e.name,onFocus:V,onBlur:u},n,g),null),[[t.resolveDirective("intersect"),{handler:v},null,{once:!0}]]),e.autoGrow&&t.withDirectives(t.createVNode("textarea",{class:[o,"v-textarea__sizer"],"onUpdate:modelValue":e=>r.value=e,ref:N,readonly:!0,"aria-hidden":"true"},null),[[t.vModelText,r.value]]),e.suffix&&t.createVNode("span",{class:"v-text-field__suffix"},[e.suffix])])}})},details:o?a=>{var o
return t.createVNode(t.Fragment,null,[null==(o=n.details)?void 0:o.call(n,a),l&&t.createVNode(t.Fragment,null,[t.createVNode("span",null,null),t.createVNode(so,{active:e.persistentCounter||i.value,value:c.value,max:d.value},n.counter)])])}:void 0})})),co({},p,f,h)}}),Os=je({name:"VThemeProvider",props:{withBackground:Boolean,...pt(),...dl()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e)
return()=>{var l,n
return e.withBackground?t.createVNode(e.tag,{class:["v-theme-provider",o.value]},{default:()=>[null==(n=a.default)?void 0:n.call(a)]}):null==(l=a.default)?void 0:l.call(a)}}}),Fs=je({name:"VTimeline",props:{align:{type:String,default:"center",validator:e=>["center","start"].includes(e)},direction:{type:String,default:"vertical",validator:e=>["vertical","horizontal"].includes(e)},justify:{type:String,default:"auto",validator:e=>["auto","center"].includes(e)},side:{type:String,validator:e=>null==e||["start","end"].includes(e)},lineInset:{type:[String,Number],default:0},lineThickness:{type:[String,Number],default:2},lineColor:String,truncateLine:{type:String,validator:e=>["start","end","both"].includes(e)},..._l(),...dl(),...pt()},setup(e,l){let{slots:a}=l
const{themeClasses:o}=gt(e),{densityClasses:n}=Il(e)
Me({VTimelineDivider:{lineColor:t.toRef(e,"lineColor")},VTimelineItem:{density:t.toRef(e,"density"),lineInset:t.toRef(e,"lineInset")}})
const r=t.computed((()=>{const t=e.side?e.side:"default"!==e.density?"end":null
return t&&`v-timeline--side-${t}`})),i=t.computed((()=>{const t=["v-timeline--truncate-line-start","v-timeline--truncate-line-end"]
switch(e.truncateLine){case"both":return t
case"start":return t[0]
case"end":return t[1]
default:return null}}))
return Ke((()=>t.createVNode(e.tag,{class:["v-timeline",`v-timeline--${e.direction}`,`v-timeline--align-${e.align}`,`v-timeline--justify-${e.justify}`,i.value,{"v-timeline--inset-line":!!e.lineInset},o.value,n.value,r.value],style:{"--v-timeline-line-thickness":g(e.lineThickness)}},a))),{}}}),Ms=je({name:"VTimelineDivider",props:{dotColor:String,fillDot:Boolean,hideDot:Boolean,icon:Hl,iconColor:String,lineColor:String,...hl(),...Ql(),...ml()},setup(e,l){let{slots:a}=l
const{sizeClasses:o,sizeStyles:n}=ea(e,"v-timeline-divider__dot"),{backgroundColorStyles:r,backgroundColorClasses:i}=Sl(t.toRef(e,"dotColor")),{roundedClasses:s}=yl(e,"v-timeline-divider__dot"),{elevationClasses:u}=gl(e),{backgroundColorClasses:c,backgroundColorStyles:d}=Sl(t.toRef(e,"lineColor"))
return Me({VIcon:{color:t.toRef(e,"iconColor"),icon:t.toRef(e,"icon"),size:t.toRef(e,"size")}}),Ke((()=>{var l
return t.createVNode("div",{class:["v-timeline-divider",{"v-timeline-divider--fill-dot":e.fillDot}]},[t.createVNode("div",{class:["v-timeline-divider__before",c.value],style:d.value},null),!e.hideDot&&t.createVNode("div",{key:"dot",class:["v-timeline-divider__dot",u.value,s.value,o.value],style:n.value},[t.createVNode("div",{class:["v-timeline-divider__inner-dot",i.value,s.value],style:r.value},[(null==(l=a.default)?void 0:l.call(a))??(e.icon?t.createVNode(la,null,null):void 0)])]),t.createVNode("div",{class:["v-timeline-divider__after",c.value],style:d.value},null)])})),{}}}),zs=je({name:"VTimelineItem",props:{density:String,dotColor:String,fillDot:Boolean,hideDot:Boolean,hideOpposite:{type:Boolean,default:void 0},icon:Hl,iconColor:String,lineInset:[Number,String],...hl(),...ml(),...Ql(),...dl(),...al()},setup(e,l){let{slots:a}=l
const{dimensionStyles:o}=ol(e),n=t.ref(0),r=t.ref()
return t.watch(r,(e=>{var t
e&&(n.value=(null==(t=e.$el.querySelector(".v-timeline-divider__dot"))?void 0:t.getBoundingClientRect().width)??0)}),{flush:"post"}),Ke((()=>{var l,i
return t.createVNode("div",{class:["v-timeline-item",{"v-timeline-item--fill-dot":e.fillDot}],style:{"--v-timeline-dot-size":g(n.value),"--v-timeline-line-inset":e.lineInset?`calc(var(--v-timeline-dot-size) / 2 + ${g(e.lineInset)})`:g(0)}},[t.createVNode("div",{class:"v-timeline-item__body",style:o.value},[null==(l=a.default)?void 0:l.call(a)]),t.createVNode(Ms,{ref:r,hideDot:e.hideDot,icon:e.icon,iconColor:e.iconColor,size:e.size,elevation:e.elevation,dotColor:e.dotColor,fillDot:e.fillDot,rounded:e.rounded},{default:a.icon}),"compact"!==e.density&&t.createVNode("div",{class:"v-timeline-item__opposite"},[!e.hideOpposite&&(null==(i=a.opposite)?void 0:i.call(a))])])})),{}}}),Ds=He()({name:"VTooltip",props:{id:String,text:String,...w(Un({closeOnBack:!1,location:"end",locationStrategy:"connected",minWidth:0,offset:10,openOnClick:!1,openOnHover:!0,origin:"auto",scrim:!1,scrollStrategy:"reposition",transition:!1}),["absolute","persistent","eager"])},emits:{"update:modelValue":e=>!0},setup(e,l){let{slots:a}=l
const o=Vt(e,"modelValue"),{scopeId:n}=Pn(),r=Le(),i=t.computed((()=>e.id||`v-tooltip-${r}`)),s=t.ref(),u=t.computed((()=>e.location.split(" ").length>1?e.location:e.location+" center")),c=t.computed((()=>"auto"===e.origin||"overlap"===e.origin||e.origin.split(" ").length>1||e.location.split(" ").length>1?e.origin:e.origin+" center")),d=t.computed((()=>e.transition?e.transition:o.value?"scale-transition":"fade-transition")),v=t.computed((()=>t.mergeProps({"aria-describedby":i.value},e.activatorProps)))
return Ke((()=>{const[l]=Xn(e)
return t.createVNode(Yn,t.mergeProps({ref:s,class:["v-tooltip"],id:i.value},l,{modelValue:o.value,"onUpdate:modelValue":e=>o.value=e,transition:d.value,absolute:!0,location:u.value,origin:c.value,persistent:!0,role:"tooltip",eager:!0,activatorProps:v.value,_disableGlobalStack:!0},n),{activator:a.activator,default:function(){for(var t,l=arguments.length,o=new Array(l),n=0;n<l;n++)o[n]=arguments[n]
return(null==(t=a.default)?void 0:t.call(a,...o))??e.text}})})),co({},s)}}),js=je({name:"VValidation",props:{...ao()},emits:{"update:modelValue":e=>!0},setup(e,t){let{slots:l}=t
const a=oo(e,"validation")
return()=>{var e
return null==(e=l.default)?void 0:e.call(l,a)}}})
var Hs=Object.freeze({__proto__:null,VApp:Tt,VAppBar:Cl,VAppBarNavIcon:Fa,VAppBarTitle:za,VAlert:Ha,VAlertTitle:Da,VAutocomplete:er,VAvatar:No,VBadge:tr,VBanner:or,VBannerActions:lr,VBannerText:ar,VBottomNavigation:nr,VBreadcrumbs:sr,VBreadcrumbsItem:ir,VBreadcrumbsDivider:rr,VBtn:Oa,VBtnGroup:Rl,VBtnToggle:zl,VCard:fr,VCardActions:ur,VCardItem:vr,VCardSubtitle:cr,VCardText:pr,VCardTitle:dr,VCarousel:xr,VCarouselItem:Cr,VCheckbox:xo,VCheckboxBtn:ko,VChip:Bo,VChipGroup:Io,VCode:Nr,VColorPicker:mi,VCombobox:gi,VCounter:so,VDefaultsProvider:Lt,VDialog:hi,VDivider:$o,VExpansionPanels:Vi,VExpansionPanel:xi,VExpansionPanelText:ki,VExpansionPanelTitle:wi,VField:Za,VFieldLabel:Ya,VFileInput:Ci,VFooter:Ni,VForm:_i,VContainer:Ii,VCol:Pi,VRow:Qi,VSpacer:es,VHover:ts,VIcon:la,VComponentIcon:Yl,VSvgIcon:Xl,VLigatureIcon:Gl,VClassIcon:ql,VImg:cl,VInput:ro,VItemGroup:as,VItem:os,VKbd:ns,VLabel:Ua,VLayout:rs,VLayoutItem:is,VLazy:ss,VList:on,VListGroup:Yo,VListImg:nn,VListItem:qo,VListItemAction:rn,VListItemMedia:sn,VListItemSubtitle:Xo,VListItemTitle:Go,VListSubheader:Ko,VLocaleProvider:us,VMain:cs,VMenu:Gn,VMessages:Qa,VNavigationDrawer:gs,VNoSsr:hs,VOverlay:Yn,VPagination:ys,VParallax:bs,VProgressCircular:oa,VProgressLinear:Na,VRadio:Vs,VRadioGroup:Ss,VRangeSlider:ws,VRating:ks,VResponsive:nl,VSelect:Kn,VSelectionControl:Vo,VSelectionControlGroup:yo,VSheet:fi,VSlideGroup:_s,VSlideGroupItem:Is,VSlider:Wr,VSnackbar:Bs,VSwitch:$s,VSystemBar:As,VTabs:Ts,VTab:Rs,VTable:Ls,VTextarea:Ps,VTextField:fo,VThemeProvider:Os,VTimeline:Fs,VTimelineItem:zs,VToolbar:xl,VToolbarTitle:vl,VToolbarItems:Ma,VTooltip:Ds,VValidation:js,VWindow:Sr,VWindowItem:kr,VDialogTransition:Mt,VFabTransition:jt,VDialogBottomTransition:Ht,VDialogTopTransition:Wt,VFadeTransition:Ut,VScaleTransition:Yt,VScrollXTransition:Xt,VScrollXReverseTransition:Gt,VScrollYTransition:qt,VScrollYReverseTransition:Kt,VSlideXTransition:Zt,VSlideXReverseTransition:Jt,VSlideYTransition:Qt,VSlideYReverseTransition:el,VExpandTransition:tl,VExpandXTransition:ll})
function Ws(e,t){var l
null!=(l=e._mutate)&&l[t.instance.$.uid]&&(e._mutate[t.instance.$.uid].observer.disconnect(),delete e._mutate[t.instance.$.uid])}const Us={mounted:function(e,t){const l=t.modifiers||{},a=t.value,{once:o,immediate:n,...r}=l,i=!Object.keys(r).length,{handler:s,options:u}="object"==typeof a?a:{handler:a,options:{attributes:(null==r?void 0:r.attr)??i,characterData:(null==r?void 0:r.char)??i,childList:(null==r?void 0:r.child)??i,subtree:(null==r?void 0:r.sub)??i}},c=new MutationObserver((function(){let l=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],a=arguments.length>1?arguments[1]:void 0
null==s||s(l,a),o&&Ws(e,t)}))
n&&(null==s||s([],c)),e._mutate=Object(e._mutate),e._mutate[t.instance.$.uid]={observer:c},c.observe(e,u)},unmounted:Ws}
const Ys={mounted:function(e,t){var l,a
const o=t.value,n={passive:!(null!=(l=t.modifiers)&&l.active)}
window.addEventListener("resize",o,n),e._onResize=Object(e._onResize),e._onResize[t.instance.$.uid]={handler:o,options:n},null!=(a=t.modifiers)&&a.quiet||o()},unmounted:function(e,t){var l
if(null==(l=e._onResize)||!l[t.instance.$.uid])return
const{handler:a,options:o}=e._onResize[t.instance.$.uid]
window.removeEventListener("resize",a,o),delete e._onResize[t.instance.$.uid]}}
function Xs(e,t){const{self:l=!1}=t.modifiers??{},a=t.value,o="object"==typeof a&&a.options||{passive:!0},n="function"==typeof a||"handleEvent"in a?a:a.handler,r=l?e:t.arg?document.querySelector(t.arg):window
r&&(r.addEventListener("scroll",n,o),e._onScroll=Object(e._onScroll),e._onScroll[t.instance.$.uid]={handler:n,options:o,target:l?void 0:r})}function Gs(e,t){var l
if(null==(l=e._onScroll)||!l[t.instance.$.uid])return
const{handler:a,options:o,target:n=e}=e._onScroll[t.instance.$.uid]
n.removeEventListener("scroll",a,o),delete e._onScroll[t.instance.$.uid]}const qs={mounted:Xs,unmounted:Gs,updated:function(e,t){t.value!==t.oldValue&&(Gs(e,t),Xs(e,t))}}
var Ks=Object.freeze({__proto__:null,ClickOutside:Hn,Intersect:il,Mutate:Us,Resize:Ys,Ripple:wa,Scroll:qs,Touch:yr})
function Zs(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{}
const{blueprint:a,...o}=e,n=I(a,o),{aliases:r={},components:i={},directives:s={}}=n,u=Oe(n.defaults),c=Rn(n.display,n.ssr),d=mt(n.theme),v=Zl(n.icons),p=$t(n.locale),f=e=>{for(const t in s)e.directive(t,s[t])
for(const t in i)e.component(t,i[t])
for(const t in r)e.component(t,je({...r[t],name:t,aliasName:r[t].name}))
if(d.install(e),e.provide(Pe,u),e.provide(Bn,c),e.provide(vt,d),e.provide(Wl,v),e.provide(Bt,p),l&&n.ssr)if(e.$nuxt)e.$nuxt.hook("app:suspense:resolve",(()=>{c.update()}))
else{const{mount:l}=e
e.mount=function(){const a=l(...arguments)
return t.nextTick((()=>c.update())),e.mount=l,a}}Le.reset(),("boolean"!=typeof __VUE_OPTIONS_API__||__VUE_OPTIONS_API__)&&e.mixin({computed:{$vuetify(){return t.reactive({defaults:Js.call(this,Pe),display:Js.call(this,Bn),theme:Js.call(this,vt),icons:Js.call(this,Wl),locale:Js.call(this,Bt)})}}})}
return{install:f,defaults:u,display:c,theme:d,icons:v,locale:p}}function Js(e){var t,l
const a=this.$,o=(null==(t=a.parent)?void 0:t.provides)??(null==(l=a.vnode.appContext)?void 0:l.provides)
if(o&&e in o)return o[e]}Zs.version="3.1.3"
const Qs=function(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{}
return Zs({components:Hs,directives:Ks,...e})},eu="3.1.3"
Qs.version=eu,e.components=Hs,e.createVuetify=Qs,e.directives=Ks,e.useDisplay=Tn,e.useLayout=tt,e.useLocale=At,e.useRtl=Rt,e.useTheme=ht,e.version=eu,Object.defineProperty(e,"__esModule",{value:!0})}))
//# sourceMappingURL=vuetify.min.js.map
